@@ -99,7 +99,7 @@ const sal_Char* getSdbcScheme( SdbcScheme _eScheme )
 // -----------------------------------------------------------------------------
 ::rtl::OUString OConnection::getDriverImplementationName()
 {
-    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(MOZAB_DRIVER_IMPL_NAME));
+    return rtl::OUString(MOZAB_DRIVER_IMPL_NAME);
 }
 
 // -----------------------------------------------------------------------------
@@ -157,7 +157,7 @@ void OConnection::construct(const ::rtl::OUString& url,const Sequence< PropertyV
     //
     sal_Int32 nLen = url.indexOf(':');
     nLen = url.indexOf(':',nLen+1);
-    OSL_ENSURE( url.copy( 0, nLen ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "sdbc:address" ) ), "OConnection::construct: invalid start of the URI - should never have survived XDriver::acceptsURL!" );
+    OSL_ENSURE( url.copy( 0, nLen ) == "sdbc:address", "OConnection::construct: invalid start of the URI - should never have survived XDriver::acceptsURL!" );
 
     ::rtl::OUString aAddrbookURI(url.copy(nLen+1));
     // Get Scheme
@@ -167,7 +167,7 @@ void OConnection::construct(const ::rtl::OUString& url,const Sequence< PropertyV
     if ( nLen == -1 )
     {
         // There isn't any subschema: - but could be just subschema
-        if ( aAddrbookURI.getLength() > 0 )
+        if ( !aAddrbookURI.isEmpty() )
         {
             aAddrbookScheme= aAddrbookURI;
         }
@@ -200,14 +200,14 @@ void OConnection::construct(const ::rtl::OUString& url,const Sequence< PropertyV
     // * for windows system address book
     //      "sdbc:address:outlookexp:"     -> aboutlookdirectory://oe/
     //
-        m_sBindDN   = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(""));
-        m_sPassword = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(""));
+        m_sBindDN   = rtl::OUString( "");
+        m_sPassword = rtl::OUString( "");
         m_bUseSSL   = sal_False;
 
     if ( aAddrbookScheme.compareToAscii( getSdbcScheme( SDBC_MOZILLA ) ) == 0 ) {
         m_sMozillaURI = rtl::OUString::createFromAscii( getSchemeURI( SCHEME_MOZILLA ) );
         m_eSDBCAddressType = SDBCAddress::Mozilla;
-        if(sAdditionalInfo.getLength())
+        if(!sAdditionalInfo.isEmpty())
             m_sMozillaProfile = sAdditionalInfo;
     }
     else
@@ -215,7 +215,7 @@ void OConnection::construct(const ::rtl::OUString& url,const Sequence< PropertyV
         //Yes. I am sure it is SCHEME_MOZILLA
         m_sMozillaURI = rtl::OUString::createFromAscii( getSchemeURI( SCHEME_MOZILLA ) );
         m_eSDBCAddressType = SDBCAddress::ThunderBird;
-        if(sAdditionalInfo.getLength())
+        if(!sAdditionalInfo.isEmpty())
             m_sMozillaProfile = sAdditionalInfo;
     }
     else if ( aAddrbookScheme.compareToAscii( getSdbcScheme( SDBC_LDAP ) ) == 0 ) {
@@ -225,10 +225,10 @@ void OConnection::construct(const ::rtl::OUString& url,const Sequence< PropertyV
         m_sMozillaURI = rtl::OUString::createFromAscii( getSchemeURI( SCHEME_LDAP ) );
         m_eSDBCAddressType = SDBCAddress::LDAP;
 
-        if ( !m_sHostName.getLength() )
+        if ( m_sHostName.isEmpty() )
         {
             // see whether the URI contains a hostname/port
-            if ( sAdditionalInfo.getLength() )
+            if ( !sAdditionalInfo.isEmpty() )
             {
                 sal_Int32 nPortSeparator = sAdditionalInfo.indexOf( ':' );
                 if ( nPortSeparator == -1 )
@@ -281,26 +281,26 @@ void OConnection::construct(const ::rtl::OUString& url,const Sequence< PropertyV
             }
         }
 
-        if ( m_sHostName.getLength() != 0 ) {
+        if ( !m_sHostName.isEmpty() ) {
             m_sMozillaURI += m_sHostName;
         }
         else
             throwSQLException( STR_NO_HOSTNAME, *this );
 
         if ( nPortNumber > 0 ) {
-            m_sMozillaURI += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(":") );
+            m_sMozillaURI += rtl::OUString( ":" );
             m_sMozillaURI += rtl::OUString::valueOf( nPortNumber );
         }
 
-        if ( sBaseDN.getLength() != 0 ) {
-            m_sMozillaURI += rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("/") );
+        if ( !sBaseDN.isEmpty() ) {
+            m_sMozillaURI += rtl::OUString( "/" );
             m_sMozillaURI += sBaseDN;
         }
         else
             throwSQLException( STR_NO_BASEDN, *this );
 
         // Addition of a fake query to enable the Mozilla LDAP directory to work correctly.
-        m_sMozillaURI += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("?(or(DisplayName,=,DontDoThisAtHome)))"));
+        m_sMozillaURI += ::rtl::OUString( "?(or(DisplayName,=,DontDoThisAtHome)))");
 
     }
     else if ( aAddrbookScheme.compareToAscii( getSdbcScheme( SDBC_OUTLOOK_MAPI ) ) == 0 ) {
@@ -564,7 +564,7 @@ void OConnection::throwSQLException( const ErrorDescriptor& _rError, const Refer
             "OConnection::throwSQLException: unsupported error code combination!" );
 
         ::rtl::OUString sParameter( _rError.getParameter() );
-        if ( sParameter.getLength() )
+        if ( !sParameter.isEmpty() )
         {
             const ::rtl::OUString sError( getResources().getResourceStringWithSubstitution(
                 _rError.getResId(),
@@ -582,7 +582,7 @@ void OConnection::throwSQLException( const ErrorDescriptor& _rError, const Refer
     {
         SQLError aErrorHelper( getDriver()->getMSFactory() );
         ::rtl::OUString sParameter( _rError.getParameter() );
-        if ( sParameter.getLength() )
+        if ( !sParameter.isEmpty() )
             aErrorHelper.raiseException( _rError.getErrorCondition(), _rxContext, sParameter );
         else
             aErrorHelper.raiseException( _rError.getErrorCondition(), _rxContext);
