@@ -43,7 +43,6 @@
 #include <cppuhelper/typeprovider.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
-#include <sal/macros.h>
 
 using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star::sdbcx;
@@ -93,7 +92,7 @@ IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumnDescriptor )
 // ::com::sun::star::lang::XServiceInfo
 rtl::OUString OTableColumnDescriptor::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.sdb.OTableColumnDescriptor"));
+    return rtl::OUString("com.sun.star.sdb.OTableColumnDescriptor");
 }
 
 Sequence< ::rtl::OUString > OTableColumnDescriptor::getSupportedServiceNames(  ) throw (RuntimeException)
@@ -156,7 +155,7 @@ IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumn )
 
 rtl::OUString OTableColumn::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.sdb.OTableColumn"));
+    return rtl::OUString("com.sun.star.sdb.OTableColumn");
 }
 
 ::cppu::IPropertyArrayHelper& SAL_CALL OTableColumn::getInfoHelper()
@@ -215,7 +214,7 @@ OQueryColumn::OQueryColumn( const Reference< XPropertySet >& _rxParserColumn, co
         { PROPERTY_TABLENAME,        PROPERTY_ID_TABLENAME },
         { PROPERTY_REALNAME,         PROPERTY_ID_REALNAME }
     };
-    for ( size_t i=0; i < SAL_N_ELEMENTS( aProps ); ++i )
+    for ( size_t i=0; i < sizeof( aProps ) / sizeof( aProps[0] ); ++i )
     {
         if ( xPSI->hasPropertyByName( aProps[i].sName ) )
             setFastPropertyValue_NoBroadcast( aProps[i].nHandle, _rxParserColumn->getPropertyValue( aProps[i].sName ) );
@@ -249,7 +248,7 @@ Reference< XPropertySet > OQueryColumn::impl_determineOriginalTableColumn( const
         OSL_VERIFY( getPropertyValue( PROPERTY_CATALOGNAME ) >>= sCatalog );
         OSL_VERIFY( getPropertyValue( PROPERTY_SCHEMANAME ) >>= sSchema );
         OSL_VERIFY( getPropertyValue( PROPERTY_TABLENAME ) >>= sTable );
-        if ( !sCatalog.getLength() && !sSchema.getLength() && !sTable.getLength() )
+        if ( sCatalog.isEmpty() && sSchema.isEmpty() && sTable.isEmpty() )
             return NULL;
 
         ::rtl::OUString sComposedTableName = ::dbtools::composeTableName(
@@ -282,7 +281,7 @@ IMPLEMENT_GET_IMPLEMENTATION_ID( OQueryColumn )
 
 ::rtl::OUString SAL_CALL OQueryColumn::getImplementationName(  ) throw(RuntimeException)
 {
-    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "org.openoffice.comp.dbaccess.OQueryColumn" ) );
+    return ::rtl::OUString( "org.openoffice.comp.dbaccess.OQueryColumn"  );
 }
 
 ::cppu::IPropertyArrayHelper& SAL_CALL OQueryColumn::getInfoHelper()
@@ -317,7 +316,7 @@ void SAL_CALL OQueryColumn::getFastPropertyValue( Any& _rValue, sal_Int32 _nHand
         ::rtl::OUString sPropName;
         sal_Int16 nAttributes( 0 );
         const_cast< OQueryColumn* >( this )->getInfoHelper().fillPropertyMembersByHandle( &sPropName, &nAttributes, _nHandle );
-        OSL_ENSURE( sPropName.getLength(), "OColumnWrapper::impl_getPropertyNameFromHandle: property not found!" );
+        OSL_ENSURE( !sPropName.isEmpty(), "OColumnWrapper::impl_getPropertyNameFromHandle: property not found!" );
 
         _rValue = m_xOriginalTableColumn->getPropertyValue( sPropName );
     }
@@ -363,7 +362,7 @@ OColumnWrapper::~OColumnWrapper()
     ::rtl::OUString sPropName;
     sal_Int16 nAttributes( 0 );
     const_cast< OColumnWrapper* >( this )->getInfoHelper().fillPropertyMembersByHandle( &sPropName, &nAttributes, _nHandle );
-    OSL_ENSURE( sPropName.getLength(), "OColumnWrapper::impl_getPropertyNameFromHandle: property not found!" );
+    OSL_ENSURE( !sPropName.isEmpty(), "OColumnWrapper::impl_getPropertyNameFromHandle: property not found!" );
     return sPropName;
 }
 
@@ -440,7 +439,7 @@ IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumnDescriptorWrapper )
 // ::com::sun::star::lang::XServiceInfo
 rtl::OUString OTableColumnDescriptorWrapper::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.sdb.OTableColumnDescriptorWrapper"));
+    return rtl::OUString("com.sun.star.sdb.OTableColumnDescriptorWrapper");
 }
 
 Sequence< ::rtl::OUString > OTableColumnDescriptorWrapper::getSupportedServiceNames(  ) throw (RuntimeException)
@@ -603,7 +602,7 @@ IMPLEMENT_GET_IMPLEMENTATION_ID( OTableColumnWrapper )
 
 rtl::OUString OTableColumnWrapper::getImplementationName(  ) throw (RuntimeException)
 {
-    return rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(  "com.sun.star.sdb.OTableColumnWrapper" ));
+    return rtl::OUString("com.sun.star.sdb.OTableColumnWrapper" );
 }
 
 Sequence< ::rtl::OUString > OTableColumnWrapper::getSupportedServiceNames(  ) throw (RuntimeException)
