@@ -60,7 +60,6 @@
 #include <tools/string.hxx>
 #include <rtl/logfile.hxx>
 #include <tools/diagnose_ex.h>
-#include <tools/diagnose_ex.h>
 
 using namespace dbaccess;
 using namespace dbtools;
@@ -152,7 +151,7 @@ void OTableContainer::removeMasterContainerListener()
 }
 
 // XServiceInfo
-IMPLEMENT_SERVICE_INFO2(OTableContainer, "com.sun.star.sdb.dbaccess.OTableContainer", SERVICE_SDBCX_CONTAINER, SERVICE_SDBCX_TABLES)
+IMPLEMENT_SERVICE_INFO2(OTableContainer, "com.sun.star.sdb.dbaccess.OTableContainer", SERVICE_SDBCX_CONTAINER.ascii, SERVICE_SDBCX_TABLES.ascii)
 
 namespace
 {
@@ -216,7 +215,7 @@ connectivity::sdbcx::ObjectType OTableContainer::createObject(const ::rtl::OUStr
                                                 sTable,
                                                 ::dbtools::eInDataManipulation);
             Any aCatalog;
-            if(sCatalog.getLength())
+            if(!sCatalog.isEmpty())
                 aCatalog <<= sCatalog;
             ::rtl::OUString sType,sDescription;
             Sequence< ::rtl::OUString> aTypeFilter;
@@ -364,7 +363,7 @@ ObjectType OTableContainer::appendObject( const ::rtl::OUString& _rForName, cons
                                                     , ::rtl::OUString(PROPERTY_ROW_HEIGHT), ::rtl::OUString(PROPERTY_TEXTCOLOR)
                                                     , ::rtl::OUString(PROPERTY_TEXTLINECOLOR), ::rtl::OUString(PROPERTY_TEXTEMPHASIS)
                                                     , ::rtl::OUString(PROPERTY_TEXTRELIEF) };
-    Sequence< ::rtl::OUString> aNames(s_pTableProps,SAL_N_ELEMENTS(s_pTableProps));
+    Sequence< ::rtl::OUString> aNames(s_pTableProps,sizeof(s_pTableProps)/sizeof(s_pTableProps[0]));
     if ( bModified || !lcl_isPropertySetDefaulted(aNames,xTableDefinition) )
         ::dbaccess::notifyDataSourceModified(m_xTableDefinitions,sal_True);
 
@@ -399,18 +398,18 @@ void OTableContainer::dropObject(sal_Int32 _nPos,const ::rtl::OUString _sElement
 
                 ::rtl::OUString sType;
                 xTable->getPropertyValue(PROPERTY_TYPE)         >>= sType;
-                bIsView = sType.equalsIgnoreAsciiCase(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("VIEW")));
+                bIsView = sType.equalsIgnoreAsciiCase(::rtl::OUString("VIEW"));
             }
 
-            if(!sComposedName.getLength())
+            if(sComposedName.isEmpty())
                 ::dbtools::throwFunctionSequenceException(static_cast<XTypeProvider*>(static_cast<OFilteredContainer*>(this)));
 
-            ::rtl::OUString aSql(RTL_CONSTASCII_USTRINGPARAM("DROP "));
+            ::rtl::OUString aSql("DROP ");
 
             if ( bIsView ) // here we have a view
-                aSql += ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("VIEW "));
+                aSql += ::rtl::OUString("VIEW ");
             else
-                aSql += ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TABLE "));
+                aSql += ::rtl::OUString("TABLE ");
             aSql += sComposedName;
             Reference<XConnection> xCon = m_xConnection;
             OSL_ENSURE(xCon.is(),"Connection is null!");
