@@ -49,7 +49,6 @@
 #include <com/sun/star/uno/XNamingService.hpp>
 #include "xmlDatabase.hxx"
 #include "xmlEnums.hxx"
-#include <tools/urlobj.hxx>
 #include "xmlstrings.hrc"
 #include <xmloff/DocumentSettingsContext.hxx>
 #include "xmlStyleImport.hxx"
@@ -59,7 +58,6 @@
 #include <com/sun/star/frame/XComponentLoader.hpp>
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <com/sun/star/lang/WrappedTargetRuntimeException.hpp>
-#include <vcl/svapp.hxx>
 #include <osl/mutex.hxx>
 #include <svtools/sfxecode.hxx>
 #include <unotools/moduleoptions.hxx>
@@ -436,11 +434,11 @@ sal_Bool ODBFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
     ::comphelper::NamedValueCollection aMediaDescriptor( rDescriptor );
     if ( aMediaDescriptor.has( "URL" ) )
         sFileName = aMediaDescriptor.getOrDefault( "URL", ::rtl::OUString() );
-    if ( !sFileName.getLength() && aMediaDescriptor.has( "FileName" ) )
+    if ( sFileName.isEmpty() && aMediaDescriptor.has( "FileName" ) )
         sFileName = aMediaDescriptor.getOrDefault( "FileName", sFileName );
 
-    OSL_ENSURE( sFileName.getLength(), "ODBFilter::implImport: no URL given!" );
-    sal_Bool bRet = ( sFileName.getLength() != 0 );
+    OSL_ENSURE( !sFileName.isEmpty(), "ODBFilter::implImport: no URL given!" );
+    sal_Bool bRet = !sFileName.isEmpty();
 
     if ( bRet )
     {
@@ -557,11 +555,11 @@ void ODBFilter::SetViewSettings(const Sequence<PropertyValue>& aViewProps)
     const PropertyValue *pEnd = pIter + aViewProps.getLength();
     for (; pIter != pEnd; ++pIter)
     {
-        if ( pIter->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "Queries" ) ) )
+        if ( pIter->Name == "Queries" )
         {
             fillPropertyMap(pIter->Value,m_aQuerySettings);
         }
-        else if ( pIter->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "Tables" ) ) )
+        else if ( pIter->Name == "Tables" )
         {
             fillPropertyMap(pIter->Value,m_aTablesSettings);
         }
@@ -574,7 +572,7 @@ void ODBFilter::SetConfigurationSettings(const Sequence<PropertyValue>& aConfigP
     const PropertyValue *pEnd = pIter + aConfigProps.getLength();
     for (; pIter != pEnd; ++pIter)
     {
-        if ( pIter->Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( "layout-settings" ) ) )
+        if ( pIter->Name == "layout-settings" )
         {
             Sequence<PropertyValue> aWindows;
             pIter->Value >>= aWindows;
