@@ -31,14 +31,6 @@
 
 #include <svx/svxids.hrc>
 
-#define ITEMID_HORJUSTIFY       SID_ATTR_ALIGN_HOR_JUSTIFY
-#define ITEMID_VERJUSTIFY       SID_ATTR_ALIGN_VER_JUSTIFY
-#define ITEMID_LINEBREAK        SID_ATTR_ALIGN_LINEBREAK
-#define ITEMID_MARGIN           SID_ATTR_ALIGN_MARGIN
-#define ITEMID_NUMBERINFO       SID_ATTR_NUMBERFORMAT_INFO
-
-
-#define _ZFORLIST_DECLARE_TABLE
 #include <svx/numinf.hxx>
 #include <svx/dbaexchange.hxx>
 #include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
@@ -62,7 +54,6 @@
 #include <com/sun/star/util/Time.hpp>
 #include <com/sun/star/util/DateTime.hpp>
 #include <com/sun/star/sdbc/XResultSetUpdate.hpp>
-#include <tools/urlobj.hxx>
 #include <tools/diagnose_ex.h>
 
 #include <svl/intitem.hxx>
@@ -71,8 +62,6 @@
 
 #include <tools/multisel.hxx>
 
-#include <svx/svxids.hrc>
-
 #include <svl/numuno.hxx>
 
 #include <svl/itempool.hxx>
@@ -418,10 +407,8 @@ Any SAL_CALL SbaXGridPeer::queryInterface(const Type& _rType) throw (RuntimeExce
 //---------------------------------------------------------------------------------------
 Reference< ::com::sun::star::frame::XDispatch >  SAL_CALL SbaXGridPeer::queryDispatch(const ::com::sun::star::util::URL& aURL, const ::rtl::OUString& aTargetFrameName, sal_Int32 nSearchFlags) throw( RuntimeException )
 {
-    if  (   (aURL.Complete.equals(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:GridSlots/BrowserAttribs"))))
-        ||  (aURL.Complete.equals(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:GridSlots/RowHeight"))))
-        ||  (aURL.Complete.equals(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:GridSlots/ColumnAttribs"))))
-        ||  (aURL.Complete.equals(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:GridSlots/ColumnWidth"))))
+    if  (   ( aURL.Complete == ".uno:GridSlots/BrowserAttribs" ) || ( aURL.Complete == ".uno:GridSlots/RowHeight" )
+        ||  ( aURL.Complete == ".uno:GridSlots/ColumnAttribs" )  || ( aURL.Complete == ".uno:GridSlots/ColumnWidth" )
         )
     {
         return (::com::sun::star::frame::XDispatch*)this;
@@ -458,13 +445,13 @@ IMPL_LINK( SbaXGridPeer, OnDispatchEvent, void*, /*NOTINTERESTEDIN*/ )
 SbaXGridPeer::DispatchType SbaXGridPeer::classifyDispatchURL( const URL& _rURL )
 {
     DispatchType eURLType = dtUnknown;
-    if ( _rURL.Complete.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ".uno:GridSlots/BrowserAttribs" ) ) )
+    if ( _rURL.Complete == ".uno:GridSlots/BrowserAttribs" )
         eURLType = dtBrowserAttribs;
-    else if ( _rURL.Complete.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ".uno:GridSlots/RowHeight" ) ) )
+    else if ( _rURL.Complete == ".uno:GridSlots/RowHeight" )
         eURLType = dtRowHeight;
-    else if ( _rURL.Complete.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ".uno:GridSlots/ColumnAttribs" ) ) )
+    else if ( _rURL.Complete == ".uno:GridSlots/ColumnAttribs" )
         eURLType = dtColumnAttribs;
-    else if ( _rURL.Complete.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ".uno:GridSlots/ColumnWidth" ) ) )
+    else if ( _rURL.Complete == ".uno:GridSlots/ColumnWidth" )
         eURLType = dtColumnWidth;
     return eURLType;
 }
@@ -1027,7 +1014,7 @@ void SbaGridControl::PostExecuteRowContextMenu(sal_uInt16 nRow, const PopupMenu&
 //---------------------------------------------------------------------------------------
 void SbaGridControl::Select()
 {
-    // irgendeine Selektion hat sich geaendert ....
+    // Some selection has changed ...
     FmGridControl::Select();
 
     if (m_pMasterListener)
@@ -1281,7 +1268,7 @@ void SbaGridControl::DoColumnDrag(sal_uInt16 nColumnPos)
     {
         OSL_FAIL("SbaGridControl::DoColumnDrag : something went wrong while getting the column");
     }
-    if (0 == sField.getLength())
+    if (sField.isEmpty())
         return;
 
     OColumnTransferable* pDataTransfer = new OColumnTransferable(xDataSource, sField, xAffectedField, xActiveConnection, CTF_FIELD_DESCRIPTOR | CTF_COLUMN_DESCRIPTOR);
