@@ -334,13 +334,14 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, sal_Bool bInfoBox )
     fprintf( fp, "\n================================================================================" );
     for ( sal_uInt16 nPortion = 0; nPortion < pEE->pImpEditEngine->GetParaPortions(). Count(); nPortion++)
     {
-
-        ParaPortion* pPPortion = pEE->pImpEditEngine->GetParaPortions().GetObject(nPortion );
-        fprintf( fp, "\nParagraph %i: Length = %i, Invalid = %i\nText = '%s'", nPortion, pPPortion->GetNode()->Len(), pPPortion->IsInvalid(), rtl::OUStringToOString( *pPPortion->GetNode(), RTL_TEXTENCODING_ASCII_US ).getStr() );
+        ParaPortion* pPPortion = pEE->pImpEditEngine->GetParaPortions()[nPortion];
+        fprintf( fp, "\nParagraph %i: Length = %i, Invalid = %i\nText = '%s'",
+                 nPortion, pPPortion->GetNode()->Len(), pPPortion->IsInvalid(),
+                 rtl::OUStringToOString(pPPortion->GetNode()->GetString(), RTL_TEXTENCODING_UTF8).getStr() );
         fprintf( fp, "\nVorlage:" );
         SfxStyleSheet* pStyle = pPPortion->GetNode()->GetStyleSheet();
         if ( pStyle )
-            fprintf( fp, " %s", rtl::OUStringToOString( pStyle->GetName(), RTL_TEXTENCODING_ASCII_US ).getStr() );
+            fprintf( fp, " %s", rtl::OUStringToOString( pStyle->GetName(), RTL_TEXTENCODING_UTF8).getStr() );
         fprintf( fp, "\nParagraph attribute:" );
         DbgOutItemSet( fp, pPPortion->GetNode()->GetContentAttribs().GetItems(), sal_False, sal_False );
 
@@ -349,21 +350,21 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, sal_Bool bInfoBox )
         sal_uInt16 z;
         for ( z = 0; z < pPPortion->GetNode()->GetCharAttribs().Count(); z++ )
         {
-            EditCharAttrib* pAttr = pPPortion->GetNode()->GetCharAttribs().GetAttribs().GetObject( z );
+            const EditCharAttrib& rAttr = pPPortion->GetNode()->GetCharAttribs().GetAttribs()[z];
             rtl::OStringBuffer aCharAttribs;
             aCharAttribs.append(RTL_CONSTASCII_STRINGPARAM("\nA"));
             aCharAttribs.append(static_cast<sal_Int32>(nPortion));
             aCharAttribs.append(RTL_CONSTASCII_STRINGPARAM(":  "));
-            aCharAttribs.append(static_cast<sal_Int32>(pAttr->GetItem()->Which()));
+            aCharAttribs.append(static_cast<sal_Int32>(rAttr.GetItem()->Which()));
             aCharAttribs.append('\t');
-            aCharAttribs.append(static_cast<sal_Int32>(pAttr->GetStart()));
+            aCharAttribs.append(static_cast<sal_Int32>(rAttr.GetStart()));
             aCharAttribs.append('\t');
-            aCharAttribs.append(static_cast<sal_Int32>(pAttr->GetEnd()));
-            if ( pAttr->IsEmpty() )
+            aCharAttribs.append(static_cast<sal_Int32>(rAttr.GetEnd()));
+            if ( rAttr.IsEmpty() )
                 bZeroAttr = sal_True;
             fprintf(fp, "%s => ", aCharAttribs.getStr());
 
-            rtl::OString aDebStr = DbgOutItem( rPool, *pAttr->GetItem() );
+            rtl::OString aDebStr = DbgOutItem( rPool, *rAttr.GetItem() );
             fprintf( fp, "%s", aDebStr.getStr() );
         }
         if ( bZeroAttr )
@@ -384,7 +385,7 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, sal_Bool bInfoBox )
         sal_uLong n = 0;
         for ( z = 0; z < nTextPortions; z++ )
         {
-            TextPortion* pPortion = pPPortion->GetTextPortions().GetObject( z );
+            TextPortion* pPortion = pPPortion->GetTextPortions()[z];
             aPortionStr.append(' ');
             aPortionStr.append(static_cast<sal_Int32>(pPortion->GetLen()));
             aPortionStr.append('(');
@@ -409,7 +410,7 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, sal_Bool bInfoBox )
         sal_uInt16 nLine;
         for ( nLine = 0; nLine < pPPortion->GetLines().Count(); nLine++ )
         {
-            EditLine* pLine = pPPortion->GetLines().GetObject( nLine );
+            EditLine* pLine = pPPortion->GetLines()[nLine];
 
             rtl::OString aLine(rtl::OUStringToOString(pPPortion->GetNode()->Copy(pLine->GetStart(), pLine->GetEnd() - pLine->GetStart()), RTL_TEXTENCODING_ASCII_US));
             fprintf( fp, "\nLine %i\t>%s<", nLine, aLine.getStr() );
@@ -417,7 +418,7 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, sal_Bool bInfoBox )
         // then the internal data ...
         for ( nLine = 0; nLine < pPPortion->GetLines().Count(); nLine++ )
         {
-            EditLine* pLine = pPPortion->GetLines().GetObject( nLine );
+            EditLine* pLine = pPPortion->GetLines()[nLine];
             fprintf( fp, "\nZeile %i:\tStart: %i,\tEnd: %i", nLine, pLine->GetStart(), pLine->GetEnd() );
             fprintf( fp, "\t\tPortions: %i - %i.\tHight: %i, Ascent=%i", pLine->GetStartPortion(), pLine->GetEndPortion(), pLine->GetHeight(), pLine->GetMaxAscent() );
         }
@@ -428,7 +429,7 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, sal_Bool bInfoBox )
     if ( pEE->pImpEditEngine->GetStyleSheetPool() )
     {
         sal_uLong nStyles = pEE->pImpEditEngine->GetStyleSheetPool() ? pEE->pImpEditEngine->GetStyleSheetPool()->Count() : 0;
-        fprintf( fp, "\n\n================================================================================" );
+        fprintf( fp, "\n\n================================================================================" );
         fprintf( fp, "\n==================   Stylesheets   =============================================" );
         fprintf( fp, "\n================================================================================" );
         fprintf( fp, "\n#Template:   %lu\n", nStyles );
@@ -460,7 +461,7 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, sal_Bool bInfoBox )
     fprintf( fp, "\nMaxAutoPaperSize: %li x %li", pEE->GetMaxAutoPaperSize().Width(), pEE->GetMaxAutoPaperSize().Height() );
     fprintf( fp, "\nMinAutoPaperSize: %li x %li", pEE->GetMinAutoPaperSize().Width(), pEE->GetMinAutoPaperSize().Height() );
     fprintf( fp, "\nUpdate: %i", pEE->GetUpdateMode() );
-    fprintf( fp, "\nNumber of Views: %i", pEE->GetViewCount() );
+    fprintf( fp, "\nNumber of Views: %" SAL_PRI_SIZET "i", pEE->GetViewCount() );
     for ( sal_uInt16 nView = 0; nView < pEE->GetViewCount(); nView++ )
     {
         EditView* pV = pEE->GetView( nView );
@@ -496,19 +497,19 @@ sal_Bool ParaPortion::DbgCheckTextPortions()
 }
 #endif
 
-sal_Bool CheckOrderedList( CharAttribArray& rAttribs, sal_Bool bStart )
+bool CheckOrderedList(const CharAttribList::AttribsType& rAttribs, bool bStart)
 {
     sal_uInt16 nPrev = 0;
-    for ( sal_uInt16 nAttr = 0; nAttr < rAttribs.Count(); nAttr++ )
+    for (size_t nAttr = 0; nAttr < rAttribs.size(); ++nAttr)
     {
-        EditCharAttrib* pAttr = rAttribs[nAttr];
-        sal_uInt16 nCur = bStart ? pAttr->GetStart() : pAttr->GetEnd();
+        const EditCharAttrib& rAttr = rAttribs[nAttr];
+        sal_uInt16 nCur = bStart ? rAttr.GetStart() : rAttr.GetEnd();
         if ( nCur < nPrev )
-            return sal_False;
+            return false;
 
         nPrev = nCur;
     }
-    return sal_True;
+    return true;
 }
 
 #endif
