@@ -33,7 +33,6 @@
 #include <com/sun/star/style/XStyleFamiliesSupplier.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/io/XActiveDataSource.hpp>
-#include <tools/debug.hxx>
 #include <svl/itemprop.hxx>
 #include <svl/brdcst.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
@@ -246,7 +245,7 @@ uno::Reference< uno::XInterface > SAL_CALL SvxSimpleUnoModel::createInstance( co
             RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.TextField.DateTime")))
        )
     {
-        return (::cppu::OWeakObject * )new SvxUnoTextField( ID_EXT_DATEFIELD );
+        return (::cppu::OWeakObject * )new SvxUnoTextField( text::textfield::Type::DATE );
     }
 
     return SvxUnoTextCreateTextField( aServiceSpecifier );
@@ -471,7 +470,7 @@ void SvxWriteXML( EditEngine& rEditEngine, SvStream& rStream, const ESelection&
         }
         while( 0 );
     }
-    catch( uno::Exception& )
+    catch( const uno::Exception& )
     {
         OSL_FAIL("exception during xml export");
     }
