@@ -1002,7 +1002,7 @@ String Sane::GetOptionUnitName( int n )
     String aText;
     SANE_Unit nUnit = mppOptions[n]->unit;
     size_t nUnitAsSize = (size_t)nUnit;
-    if( nUnitAsSize > SAL_N_ELEMENTS( ppUnits ) )
+    if (nUnitAsSize >= SAL_N_ELEMENTS( ppUnits ))
         aText = String::CreateFromAscii( "[unknown units]" );
     else
         aText = String( ppUnits[ nUnit ], osl_getThreadTextEncoding() );
