@@ -123,7 +123,7 @@ ToolboxStyleItem Styles[ ] = {
     { ::com::sun::star::ui::ItemStyle::TEXT, ATTRIBUTE_ITEMSTYLE_TEXT },
 };
 
-sal_Int32 nStyleItemEntries = SAL_N_ELEMENTS( Styles );
+sal_Int32 nStyleItemEntries = sizeof (Styles) / sizeof (Styles[0]);
 
 struct ToolBarEntryProperty
 {
@@ -267,7 +267,7 @@ throw(  SAXException, RuntimeException )
                                 }
                             }
 
-                            if ( aUIName.getLength() > 0 )
+                            if ( !aUIName.isEmpty() )
                             {
                                 // Try to set UI name as a container property
                                 Reference< XPropertySet > xPropSet( m_rItemContainer, UNO_QUERY );
@@ -277,7 +277,7 @@ throw(  SAXException, RuntimeException )
                                     {
                                         xPropSet->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "UIName" )), makeAny( aUIName ) );
                                     }
-                                    catch ( UnknownPropertyException& )
+                                    catch ( const UnknownPropertyException& )
                                     {
                                     }
                                 }
@@ -307,7 +307,6 @@ throw(  SAXException, RuntimeException )
                     throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
                 }
 
-                ::rtl::OUString aAttribute;
                 sal_Bool bAttributeURL  = sal_False;
 
                 m_bToolBarItemStartFound = sal_True;
@@ -353,9 +352,9 @@ throw(  SAXException, RuntimeException )
 
                             case TB_ATTRIBUTE_VISIBLE:
                             {
-                                if ( xAttribs->getValueByIndex( n ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ATTRIBUTE_BOOLEAN_TRUE )) )
+                                if ( xAttribs->getValueByIndex( n ) == ATTRIBUTE_BOOLEAN_TRUE )
                                     bVisible = sal_True;
-                                else if ( xAttribs->getValueByIndex( n ).equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( ATTRIBUTE_BOOLEAN_FALSE )) )
+                                else if ( xAttribs->getValueByIndex( n ) == ATTRIBUTE_BOOLEAN_FALSE )
                                     bVisible = sal_False;
                                 else
                                 {
@@ -387,7 +386,7 @@ throw(  SAXException, RuntimeException )
                                 do
                                 {
                                     ::rtl::OUString aToken  = aTemp.getToken( 0, ' ', nIndex );
-                                    if ( aToken.getLength() > 0 )
+                                    if ( !aToken.isEmpty() )
                                     {
                                         sal_Int32 nHashCode = aToken.hashCode();
                                         if ( nHashCode == m_nHashCode_Style_Radio )
@@ -426,7 +425,7 @@ throw(  SAXException, RuntimeException )
                     throw SAXException( aErrorMessage, Reference< XInterface >(), Any() );
                 }
 
-                if ( aCommandURL.getLength() > 0 )
+                if ( !aCommandURL.isEmpty() )
                 {
                     Sequence< PropertyValue > aToolbarItemProp( 7 );
                     aToolbarItemProp[0].Name = m_aCommandURL;
@@ -698,7 +697,7 @@ void OWriteToolBoxDocumentHandler::WriteToolBoxDocument() throw
         {
             xPropSet->getPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "UIName" ))) >>= aUIName;
         }
-        catch ( UnknownPropertyException& )
+        catch ( const UnknownPropertyException& )
         {
         }
     }
@@ -714,7 +713,7 @@ void OWriteToolBoxDocumentHandler::WriteToolBoxDocument() throw
                          m_aAttributeType,
                          ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( XMLNS_XLINK )) );
 
-    if ( aUIName.getLength() > 0 )
+    if ( !aUIName.isEmpty() )
         pList->AddAttribute( m_aXMLToolbarNS + ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ATTRIBUTE_UINAME )),
                              m_aAttributeType,
                              aUIName );
@@ -775,7 +774,7 @@ throw ( SAXException, RuntimeException )
     ::comphelper::AttributeList* pList = new ::comphelper::AttributeList;
     Reference< XAttributeList > xList( (XAttributeList *) pList , UNO_QUERY );
 
-    if ( m_aAttributeURL.getLength() == 0 )
+    if ( m_aAttributeURL.isEmpty() )
     {
         m_aAttributeURL = m_aXMLXlinkNS;
         m_aAttributeURL += ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ATTRIBUTE_URL ));
@@ -784,7 +783,7 @@ throw ( SAXException, RuntimeException )
     // save required attribute (URL)
     pList->AddAttribute( m_aAttributeURL, m_aAttributeType, rCommandURL );
 
-    if ( rLabel.getLength() > 0 )
+    if ( !rLabel.isEmpty() )
     {
         pList->AddAttribute( m_aXMLToolbarNS + ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ATTRIBUTE_TEXT )),
                              m_aAttributeType,
@@ -798,14 +797,14 @@ throw ( SAXException, RuntimeException )
                              ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ATTRIBUTE_BOOLEAN_FALSE )) );
     }
 
-    if ( rHelpURL.getLength() > 0 )
+    if ( !rHelpURL.isEmpty() )
     {
         pList->AddAttribute( m_aXMLToolbarNS + ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ATTRIBUTE_HELPID )),
                              m_aAttributeType,
                              rHelpURL );
     }
 
-    if ( rTooltip.getLength() > 0 )
+    if ( !rTooltip.isEmpty() )
     {
         pList->AddAttribute( m_aXMLToolbarNS + ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ATTRIBUTE_TOOLTIP )),
                              m_aAttributeType,
@@ -821,7 +820,7 @@ throw ( SAXException, RuntimeException )
         {
             if ( nStyle & pStyle->nBit )
             {
-                if ( aValue.getLength() )
+                if ( !aValue.isEmpty() )
                     aValue = aValue.concat( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(" ") ) );
                 aValue += rtl::OUString::createFromAscii( pStyle->attrName );
             }
