@@ -137,8 +137,6 @@ class RecentFilesStringLength : public ::cppu::WeakImplHelper1< ::com::sun::star
 
 BackingWindow::BackingWindow( Window* i_pParent ) :
     Window( i_pParent, FwkResId( DLG_BACKING ) ),
-    maWelcome( this, WB_LEFT ),
-    maProduct( this, WB_LEFT ),
     maWriterButton( this, STC_BUTTON_STYLE ),
     maCalcButton( this, STC_BUTTON_STYLE ),
     maImpressButton( this, STC_BUTTON_STYLE ),
@@ -148,13 +146,11 @@ BackingWindow::BackingWindow( Window* i_pParent ) :
     maMathButton( this, STC_BUTTON_STYLE ),
     maTemplateButton( this, STC_BUTTON_STYLE ),
     maToolbox( this, WB_DIALOGCONTROL ),
-    maWelcomeString( FwkResId( STR_BACKING_WELCOME ) ),
-    maProductString( FwkResId( STR_BACKING_WELCOMEPRODUCT ) ),
     maOpenString( FwkResId( STR_BACKING_FILE ) ),
     maTemplateString( FwkResId( STR_BACKING_TEMPLATE ) ),
     maButtonImageSize( 10, 10 ),
     mbInitControls( false ),
-    mnLayoutStyle( 0 ),
+    mnHideExternalLinks( 0 ),
     mpAccExec( NULL ),
     mnBtnPos( 120 ),
     mnBtnTop( 150 ),
@@ -170,17 +166,17 @@ BackingWindow::BackingWindow( Window* i_pParent ) :
         {
             Sequence<Any> args(1);
             PropertyValue val(
-                rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("nodepath") ),
+                rtl::OUString( "nodepath" ),
                 0,
-                Any(rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("/org.openoffice.Office.Common/Help/StartCenter"))),
+                Any(rtl::OUString( "/org.openoffice.Office.Common/Help/StartCenter")),
                 PropertyState_DIRECT_VALUE);
             args.getArray()[0] <<= val;
             Reference<container::XNameAccess> xNameAccess(xConfig->createInstanceWithArguments(SERVICENAME_CFGREADACCESS,args), UNO_QUERY);
             if( xNameAccess.is() )
             {
                 //throws css::container::NoSuchElementException, css::lang::WrappedTargetException
-                Any value( xNameAccess->getByName(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("StartCenterLayoutStyle"))) );
-                mnLayoutStyle = value.get<sal_Int32>();
+                Any value( xNameAccess->getByName(rtl::OUString("StartCenterHideExternalLinks")) );
+                mnHideExternalLinks = value.get<sal_Int32>();
             }
         }
     }
@@ -195,8 +191,6 @@ BackingWindow::BackingWindow( Window* i_pParent ) :
     // clean up resource stack
     FreeResource();
 
-    maWelcome.SetPaintTransparent( sal_True );
-    maProduct.SetPaintTransparent( sal_True );
     EnableChildTransparentMode();
 
     SetStyle( GetStyle() | WB_DIALOGCONTROL );
@@ -208,19 +202,19 @@ BackingWindow::BackingWindow( Window* i_pParent ) :
     maToolbox.InsertItem( nItemId_TplRep, Image() );
     maToolbox.SetItemText( nItemId_TplRep, aTplRepHelpText );
     maToolbox.SetQuickHelpText( nItemId_TplRep, aTplRepHelpText );
-    maToolbox.SetItemCommand( nItemId_TplRep, String( RTL_CONSTASCII_USTRINGPARAM( ".HelpId:StartCenter:TemplateRepository" ) ) );
+    maToolbox.SetItemCommand( nItemId_TplRep, String( ".HelpId:StartCenter:TemplateRepository"  ) );
     maToolbox.ShowItem( nItemId_TplRep );
 
     maToolbox.InsertItem( nItemId_Extensions, Image() );
     maToolbox.SetQuickHelpText( nItemId_Extensions, aExtHelpText );
     maToolbox.SetItemText( nItemId_Extensions, aExtHelpText );
-    maToolbox.SetItemCommand( nItemId_Extensions, String( RTL_CONSTASCII_USTRINGPARAM( ".HelpId:StartCenter:Extensions" ) ) );
+    maToolbox.SetItemCommand( nItemId_Extensions, String( ".HelpId:StartCenter:Extensions"  ) );
     maToolbox.ShowItem( nItemId_Extensions );
 
     maToolbox.InsertItem( nItemId_Info, Image() );
     maToolbox.SetItemText( nItemId_Info, aInfoHelpText );
     maToolbox.SetQuickHelpText( nItemId_Info, aInfoHelpText );
-    maToolbox.SetItemCommand( nItemId_Info, String( RTL_CONSTASCII_USTRINGPARAM( ".HelpId:StartCenter:Info" ) ) );
+    maToolbox.SetItemCommand( nItemId_Info, String( ".HelpId:StartCenter:Info"  ) );
     maToolbox.ShowItem( nItemId_Info );
 
     // get dispatch provider
@@ -245,6 +239,9 @@ BackingWindow::BackingWindow( Window* i_pParent ) :
     maButtonImageSize.Width() += 12;
     maButtonImageSize.Height() += 12;
 
+    // set a slighly larger font than normal labels on the texts
+    maTextFont.SetSize( Size( 0, 11 ) );
+    maTextFont.SetWeight( WEIGHT_NORMAL );
 }
 
 
@@ -276,6 +273,8 @@ void BackingWindow::DataChanged( const DataChangedEvent& rDCEvt )
     {
         initBackground();
         Invalidate();
+        // fdo#34392: Resize buttons to match the new text size.
+        Resize();
     }
 }
 
@@ -322,29 +321,29 @@ void BackingWindow::prepareRecentFileMenu()
             maRecentFiles.push_back( LoadRecentFile() );
             maRecentFiles.back().aTargetURL = aURL;
 
-            sal_Int32 nArgs = aFilterOpt.getLength() ? 4 : 3;
+            sal_Int32 nArgs = aFilterOpt.isEmpty() ? 3 : 4;
             Sequence< PropertyValue >& rArgsList( maRecentFiles.back().aArgSeq );
             rArgsList.realloc( nArgs );
 
             nArgs--;
-            rArgsList[nArgs].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "FilterName" ));
+            rArgsList[nArgs].Name = rtl::OUString( "FilterName" );
             rArgsList[nArgs].Value = makeAny( aFilter );
 
-            if( aFilterOpt.getLength() )
+            if( !aFilterOpt.isEmpty() )
             {
                 nArgs--;
-                rArgsList[nArgs].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "FilterOptions" ));
+                rArgsList[nArgs].Name = rtl::OUString( "FilterOptions" );
                 rArgsList[nArgs].Value = makeAny( aFilterOpt );
             }
 
             // documents in the picklist will never be opened as templates
             nArgs--;
-            rArgsList[nArgs].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "AsTemplate" ));
+            rArgsList[nArgs].Name = rtl::OUString( "AsTemplate" );
             rArgsList[nArgs].Value = makeAny( (sal_Bool) sal_False );
 
             nArgs--;
-            rArgsList[nArgs].Name = rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Referer" ));
-            rArgsList[nArgs].Value = makeAny( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "private:user" ) ) );
+            rArgsList[nArgs].Name = rtl::OUString( "Referer" );
+            rArgsList[nArgs].Value = makeAny( rtl::OUString( "private:user"  ) );
 
             // and finally create an entry in the popupmenu
             rtl::OUString   aMenuTitle;
@@ -399,12 +398,6 @@ void BackingWindow::initBackground()
     SetBackground();
 
     bool bDark = GetSettings().GetStyleSettings().GetHighContrastMode();
-    if( bDark )
-        maWelcomeTextColor = maLabelTextColor = Color( COL_WHITE );
-    else if( mnLayoutStyle == 1 )
-        maWelcomeTextColor = maLabelTextColor = Color( COL_BLACK );
-    else
-        maWelcomeTextColor = maLabelTextColor = Color( 0x26, 0x35, 0x42 );
 
     Color aTextBGColor( bDark ? COL_BLACK : COL_WHITE );
 
@@ -438,19 +431,6 @@ void BackingWindow::initBackground()
     maToolbox.SetItemImage( nItemId_Info, BitmapEx( FwkResId( BMP_BACKING_INFO ) ) );
     maToolbox.SetItemImage( nItemId_TplRep, BitmapEx( FwkResId( BMP_BACKING_TPLREP ) ) );
 
-    maWelcome.SetControlForeground( maWelcomeTextColor );
-    maWelcome.SetBackground();
-    maProduct.SetControlForeground( maWelcomeTextColor );
-    maProduct.SetBackground();
-
-    if( mnLayoutStyle == 1 )
-    {
-        if( Application::GetSettings().GetLayoutRTL() )
-            mnBtnPos = maBackgroundRight.GetSizePixel().Width() + 40;
-        else
-            mnBtnPos = maBackgroundLeft.GetSizePixel().Width() + 40;
-    }
-
     // get icon images from fwk resource and set them on the appropriate buttons
     loadImage( FwkResId( BMP_BACKING_WRITER ), maWriterButton );
     loadImage( FwkResId( BMP_BACKING_CALC ), maCalcButton );
@@ -482,63 +462,19 @@ void BackingWindow::initControls()
     maControlRect.Bottom() -= nShadowBottom;
 
     long nYPos = 0;
-    // set bigger welcome string
-    maWelcome.SetText( maWelcomeString );
-    maTextFont = GetSettings().GetStyleSettings().GetLabelFont();
-    maTextFont.SetSize( Size( 0, 18 ) );
-    maTextFont.SetWeight( WEIGHT_BOLD );
-    maWelcome.SetFont( maTextFont );
-    // get metric to get correct width factor and adjust
-    long nW = (maWelcome.GetFontMetric().GetWidth()*95)/100;
-    maTextFont.SetSize( Size( nW, 18 ) );
 
-    maWelcome.SetFont( maTextFont );
-    maWelcome.SetControlFont( maTextFont );
-    maWelcomeSize = Size( maWelcome.GetTextWidth( maWelcomeString ), maWelcome.GetTextHeight() );
-    maWelcomeSize.Width() = (maWelcomeSize.Width() * 20)/19;
+    if( maControlRect.GetWidth() < mnBtnPos + 20 )
+        maControlRect.Right() = maControlRect.Left() + mnBtnPos + 20;
 
-    nYPos += (maWelcomeSize.Height()*3)/2;
-
-    if( maControlRect.GetWidth() < mnBtnPos + maWelcomeSize.Width() + 20 )
-        maControlRect.Right() = maControlRect.Left() + maWelcomeSize.Width() + mnBtnPos + 20;
-
-    nYPos += maWelcomeSize.Height();
-
-    // set product string
-    maTextFont.SetSize( Size( 0, 30 ) );
-    maProduct.SetFont( maTextFont );
-
-    // get metric to get correct width factor and adjust
-    nW = (maProduct.GetFontMetric().GetWidth()*95)/100;
-    maTextFont.SetSize( Size( nW, 28 ) );
-
-    maProduct.SetFont( maTextFont );
-    maProduct.SetControlFont( maTextFont );
-    maProduct.SetText( maProductString );
-    maProductSize = Size( maProduct.GetTextWidth( maProductString ), maProduct.GetTextHeight() );
-    maProductSize.Width() = (maProductSize.Width() * 20)/19;
-
-    if( maControlRect.GetWidth() < maProductSize.Width() + mnBtnPos + 10 )
-        maControlRect.Right() = maControlRect.Left() + maProductSize.Width() + mnBtnPos + 10;
-
-    if( mnLayoutStyle == 1 )
-    {
-        maWelcome.Show();
-        maProduct.Show();
-    }
-
-    nYPos += (maProductSize.Height()*3)/2;
-
-    // set a slighly larger font than normal labels on the texts
-    maTextFont.SetSize( Size( 0, 11 ) );
-    maTextFont.SetWeight( WEIGHT_NORMAL );
+    if( maControlRect.GetWidth() < mnBtnPos + 10 )
+        maControlRect.Right() = maControlRect.Left() + mnBtnPos + 10;
 
     // collect the URLs of the entries in the File/New menu
     SvtModuleOptions    aModuleOptions;
     std::set< rtl::OUString > aFileNewAppsAvailable;
     SvtDynamicMenuOptions aOpt;
     Sequence < Sequence < PropertyValue > > aNewMenu = aOpt.GetMenu( E_NEWMENU );
-    const rtl::OUString sURLKey( RTL_CONSTASCII_USTRINGPARAM( "URL" ) );
+    const rtl::OUString sURLKey( "URL"  );
 
     const Sequence< PropertyValue >* pNewMenu = aNewMenu.getConstArray();
     const Sequence< PropertyValue >* pNewMenuEnd = aNewMenu.getConstArray() + aNewMenu.getLength();
@@ -546,7 +482,7 @@ void BackingWindow::initControls()
     {
         comphelper::SequenceAsHashMap aEntryItems( *pNewMenu );
         rtl::OUString sURL( aEntryItems.getUnpackedValueOrDefault( sURLKey, rtl::OUString() ) );
-        if ( sURL.getLength() )
+        if ( !sURL.isEmpty() )
             aFileNewAppsAvailable.insert( sURL );
     }
 
@@ -572,33 +508,33 @@ void BackingWindow::initControls()
     }
 
     // layout the buttons
-    layoutButton( WRITER_URL, 0, aFileNewAppsAvailable,
+    layoutButton( WRITER_URL, 0, 0, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SWRITER,
                   maWriterButton, aMnemns );
-    layoutButton( DRAW_URL, 1, aFileNewAppsAvailable,
+    layoutButton( DRAW_URL, 1, 0, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SDRAW,
                   maDrawButton, aMnemns );
     nYPos += maButtonImageSize.Height() + 10;
-    layoutButton( CALC_URL, 0, aFileNewAppsAvailable,
+    layoutButton( CALC_URL, 0, 0, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SCALC,
                   maCalcButton, aMnemns );
-    layoutButton( BASE_URL, 1, aFileNewAppsAvailable,
+    layoutButton( BASE_URL, 1, 0, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SDATABASE,
                   maDBButton, aMnemns );
     nYPos += maButtonImageSize.Height() + 10;
-    layoutButton( IMPRESS_WIZARD_URL, 0, aFileNewAppsAvailable,
+    layoutButton( IMPRESS_WIZARD_URL, 0, 0, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SIMPRESS,
                   maImpressButton, aMnemns );
-    layoutButton( MATH_URL, 1, aFileNewAppsAvailable,
+    layoutButton( MATH_URL, 1, 0, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SMATH,
                   maMathButton, aMnemns );
 
     nYPos += 3*maButtonImageSize.Height() / 2;
 
-    layoutButton( NULL, 0, aFileNewAppsAvailable,
+    layoutButton( NULL, 0, 18, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SWRITER,
                   maOpenButton, aMnemns, maOpenString );
-    layoutButton( NULL, 1, aFileNewAppsAvailable,
+    layoutButton( NULL, 1, 0, aFileNewAppsAvailable,
                   aModuleOptions, SvtModuleOptions::E_SWRITER,
                   maTemplateButton, aMnemns, maTemplateString );
     nYPos += 10;
@@ -629,7 +565,7 @@ void BackingWindow::initControls()
     }
 
     maToolbox.SetSelectHdl( LINK( this, BackingWindow, ToolboxHdl ) );
-    if( mnLayoutStyle == 0 )
+    if( mnHideExternalLinks == 0 )
         maToolbox.Show();
 
     // scale middle map to formatted width
@@ -664,7 +600,7 @@ void BackingWindow::loadImage( const ResId& i_rId, PushButton& i_rButton )
 }
 
 void BackingWindow::layoutButton(
-                          const char* i_pURL, int nColumn,
+                          const char* i_pURL, int nColumn, int i_nExtraWidth,
                           const std::set<rtl::OUString>& i_rURLS,
                           SvtModuleOptions& i_rOpt, SvtModuleOptions::EModule i_eMod,
                           PushButton& i_rBtn,
@@ -690,8 +626,8 @@ void BackingWindow::layoutButton(
 
     long nTextWidth = i_rBtn.GetTextWidth( i_rBtn.GetText() );
 
-    nTextWidth += maButtonImageSize.Width() + 8; // add some fuzz to be on the safe side
-    if( nColumn >= 0 && nColumn < static_cast<int>(SAL_N_ELEMENTS(mnColumnWidth)) )
+    nTextWidth += maButtonImageSize.Width() + 8 + i_nExtraWidth; // add some fuzz to be on the safe side
+    if( nColumn >= 0 && nColumn < static_cast<int>(sizeof (mnColumnWidth) / sizeof (mnColumnWidth[0])) )
     {
         if( nTextWidth > mnColumnWidth[nColumn] )
             mnColumnWidth[nColumn] = nTextWidth;
@@ -704,7 +640,7 @@ void BackingWindow::layoutButton(
 
 void BackingWindow::Paint( const Rectangle& )
 {
-    Wallpaper aBack( GetSettings().GetStyleSettings().GetWorkspaceGradient() );
+    Wallpaper aBack( GetSettings().GetStyleSettings().GetWorkspaceColor() );
     Region aClip( Rectangle( Point( 0, 0 ), GetOutputSizePixel() ) );
     Rectangle aBmpRect(maControlRect);
     aBmpRect.Left()   -= nShadowLeft;
@@ -847,17 +783,12 @@ void BackingWindow::Resize()
     // #i93631# squeeze controls so they fit into the box
     // this can be necessary due to application font height which has small deviations
     // from the size set
-    const long nWDelta    = maWelcomeSize.Height();
-    const long nW2Delta   = (maWelcomeSize.Height()*3)/2;
-    const long nPDelta    = (maProductSize.Height()*3)/2;
     const long nBDelta    = maButtonImageSize.Height() + 10;
     const long nB2Delta   = 3*maButtonImageSize.Height()/2;
     const long nLastDelta = maButtonImageSize.Height();
     long nDiff = 0;
-    while( ( maControlRect.Top()   +
-                 (nWDelta - nDiff) +
-                 (nW2Delta- nDiff) +
-                 (nPDelta - nDiff) +
+    while( ( maControlRect.Top()   -
+             3 * nDiff +
              3 * (nBDelta - nDiff) +
                  (nB2Delta- nDiff) +
                  nLastDelta
@@ -866,18 +797,24 @@ void BackingWindow::Resize()
         nDiff++;
     }
 
-    long nYPos = maControlRect.Top();
-    nYPos += nW2Delta - nDiff;
-    maWelcome.SetPosSizePixel( Point( maControlRect.Left() + mnBtnPos, nYPos ),
-                                Size( maControlRect.GetWidth() - mnBtnPos - 5, (maWelcomeSize.Height()*20)/19 ) );
-    nYPos += nWDelta - nDiff;
-    maProduct.SetPosSizePixel( Point( maControlRect.Left() + mnBtnPos, nYPos ), Size( maControlRect.GetWidth() - mnBtnPos - 5, (maProductSize.Height()*20)/19 ) );
-    nYPos += nPDelta - nDiff;
+    long nYPos = maControlRect.Top() + mnBtnTop;
 
-    nYPos += nWDelta/2 - nDiff;
+    // Recompute column widths
+    mnTextColumnWidth[0] = maWriterButton.GetTextWidth( maWriterButton.GetText() ) + maButtonImageSize.Width() + 8;
+    if( mnTextColumnWidth[0] < maCalcButton.GetTextWidth( maCalcButton.GetText() ) + maButtonImageSize.Width() + 8 )
+        mnTextColumnWidth[0] = maCalcButton.GetTextWidth( maCalcButton.GetText() ) + maButtonImageSize.Width() + 8;
+    if( mnTextColumnWidth[0] < maImpressButton.GetTextWidth( maImpressButton.GetText() ) + maButtonImageSize.Width() + 8 )
+        mnTextColumnWidth[0] = maImpressButton.GetTextWidth( maImpressButton.GetText() ) + maButtonImageSize.Width() + 8;
+    if( mnTextColumnWidth[0] < maOpenButton.GetTextWidth( maOpenButton.GetText() ) + maButtonImageSize.Width() + 26 )
+        mnTextColumnWidth[0] = maOpenButton.GetTextWidth( maOpenButton.GetText() ) + maButtonImageSize.Width() + 26;
 
-    if( mnLayoutStyle != 1 )
-        nYPos = maControlRect.Top() + mnBtnTop;
+    mnTextColumnWidth[1] = maDrawButton.GetTextWidth( maDrawButton.GetText() ) + maButtonImageSize.Width() + 8;
+    if( mnTextColumnWidth[1] < maDBButton.GetTextWidth( maDBButton.GetText() ) + maButtonImageSize.Width() + 8 )
+        mnTextColumnWidth[1] = maDBButton.GetTextWidth( maDBButton.GetText() ) + maButtonImageSize.Width() + 8;
+    if( mnTextColumnWidth[1] < maMathButton.GetTextWidth( maMathButton.GetText() ) + maButtonImageSize.Width() + 8 )
+        mnTextColumnWidth[1] = maMathButton.GetTextWidth( maMathButton.GetText() ) + maButtonImageSize.Width() + 8;
+    if( mnTextColumnWidth[1] < maTemplateButton.GetTextWidth( maTemplateButton.GetText() ) + maButtonImageSize.Width() + 8 )
+        mnTextColumnWidth[1] = maTemplateButton.GetTextWidth( maTemplateButton.GetText() ) + maButtonImageSize.Width() + 8;
 
     maWriterButton.SetPosSizePixel( Point( maControlRect.Left() + mnBtnPos, nYPos ), Size( mnTextColumnWidth[0], maButtonImageSize.Height() ) );
     maDrawButton.SetPosSizePixel( Point( maControlRect.Left() + mnBtnPos + mnColumnWidth[0], nYPos ), Size( mnTextColumnWidth[1], maButtonImageSize.Height() ) );
@@ -893,7 +830,7 @@ void BackingWindow::Resize()
     maTemplateButton.SetPosSizePixel( Point( maControlRect.Left() + mnBtnPos + mnColumnWidth[0], nYPos ), Size( mnTextColumnWidth[1], maButtonImageSize.Height() ) );
 }
 
-IMPL_LINK( BackingWindow, ToolboxHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG(BackingWindow, ToolboxHdl)
 {
     const char* pNodePath = NULL;
     const char* pNode = NULL;
@@ -924,7 +861,7 @@ IMPL_LINK( BackingWindow, ToolboxHdl, void*, EMPTYARG )
             {
                 Sequence<Any> args(1);
                 PropertyValue val(
-                    rtl::OUString( RTL_CONSTASCII_USTRINGPARAM("nodepath") ),
+                    rtl::OUString( "nodepath" ),
                     0,
                     Any(rtl::OUString::createFromAscii(pNodePath)),
                     PropertyState_DIRECT_VALUE);
@@ -940,10 +877,10 @@ IMPL_LINK( BackingWindow, ToolboxHdl, void*, EMPTYARG )
 
                     Reference< com::sun::star::system::XSystemShellExecute > xSystemShellExecute(
                         comphelper::getProcessServiceFactory()->createInstance(
-                            rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.system.SystemShellExecute" ) ) ),
+                            rtl::OUString( "com.sun.star.system.SystemShellExecute"  ) ),
                         UNO_QUERY_THROW);
                     //throws css::lang::IllegalArgumentException, css::system::SystemShellExecuteException
-                    xSystemShellExecute->execute( sURL, rtl::OUString(), com::sun::star::system::SystemShellExecuteFlags::DEFAULTS);
+                    xSystemShellExecute->execute( sURL, rtl::OUString(), com::sun::star::system::SystemShellExecuteFlags::URIS_ONLY);
                 }
             }
         }
@@ -959,27 +896,27 @@ IMPL_LINK( BackingWindow, ClickHdl, Button*, pButton )
 {
     // dispatch the appropriate URL and end the dialog
     if( pButton == &maWriterButton )
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(WRITER_URL) ) );
+        dispatchURL( rtl::OUString( WRITER_URL ) );
     else if( pButton == &maCalcButton )
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(CALC_URL) ) );
+        dispatchURL( rtl::OUString( CALC_URL ) );
     else if( pButton == &maImpressButton )
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(IMPRESS_WIZARD_URL) ) );
+        dispatchURL( rtl::OUString( IMPRESS_WIZARD_URL ) );
     else if( pButton == &maDrawButton )
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(DRAW_URL) ) );
+        dispatchURL( rtl::OUString( DRAW_URL ) );
     else if( pButton == &maDBButton )
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(BASE_URL) ) );
+        dispatchURL( rtl::OUString( BASE_URL ) );
     else if( pButton == &maMathButton )
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(MATH_URL) ) );
+        dispatchURL( rtl::OUString( MATH_URL ) );
     else if( pButton == &maOpenButton )
     {
         Reference< XDispatchProvider > xFrame( mxFrame, UNO_QUERY );
 
         Sequence< com::sun::star::beans::PropertyValue > aArgs(1);
         PropertyValue* pArg = aArgs.getArray();
-        pArg[0].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Referer"));
-        pArg[0].Value <<= rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("private:user"));
+        pArg[0].Name = rtl::OUString("Referer");
+        pArg[0].Value <<= rtl::OUString("private:user");
 
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(OPEN_URL) ), rtl::OUString(), xFrame, aArgs );
+        dispatchURL( rtl::OUString( OPEN_URL ), rtl::OUString(), xFrame, aArgs );
     }
     else if( pButton == &maTemplateButton )
     {
@@ -987,10 +924,10 @@ IMPL_LINK( BackingWindow, ClickHdl, Button*, pButton )
 
         Sequence< com::sun::star::beans::PropertyValue > aArgs(1);
         PropertyValue* pArg = aArgs.getArray();
-        pArg[0].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Referer"));
-        pArg[0].Value <<= rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("private:user"));
+        pArg[0].Name = rtl::OUString("Referer");
+        pArg[0].Value <<= rtl::OUString("private:user");
 
-        dispatchURL( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(TEMPLATE_URL) ), rtl::OUString(), xFrame, aArgs );
+        dispatchURL( rtl::OUString( TEMPLATE_URL ), rtl::OUString(), xFrame, aArgs );
     }
     return 0;
 }
@@ -1067,7 +1004,7 @@ void BackingWindow::dispatchURL( const rtl::OUString& i_rURL,
     aDispatchURL.Complete = i_rURL;
 
     Reference < com::sun::star::util::XURLTransformer > xURLTransformer(
-        comphelper::getProcessServiceFactory()->createInstance( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.util.URLTransformer")) ),
+        comphelper::getProcessServiceFactory()->createInstance( rtl::OUString("com.sun.star.util.URLTransformer") ),
         com::sun::star::uno::UNO_QUERY );
     if ( xURLTransformer.is() )
     {
