@@ -121,10 +121,10 @@ AddonsToolBarManager::~AddonsToolBarManager()
 
 static sal_Bool IsCorrectContext( const ::rtl::OUString& rModuleIdentifier, const ::rtl::OUString& aContextList )
 {
-    if ( aContextList.getLength() == 0 )
+    if ( aContextList.isEmpty() )
         return sal_True;
 
-    if ( rModuleIdentifier.getLength() > 0 )
+    if ( !rModuleIdentifier.isEmpty() )
     {
         sal_Int32 nIndex = aContextList.indexOf( rModuleIdentifier );
         return ( nIndex >= 0 );
@@ -141,7 +141,7 @@ static Image RetrieveImage( Reference< com::sun::star::frame::XFrame >& rFrame,
 {
     Image aImage;
 
-    if ( aImageId.getLength() > 0 )
+    if ( !aImageId.isEmpty() )
     {
         aImage = framework::AddonsOptions().GetImageFromURL( aImageId, bBigImage );
         if ( !!aImage )
@@ -241,7 +241,7 @@ void AddonsToolBarManager::FillToolbar( const Sequence< Sequence< PropertyValue
             m_xServiceManager->createInstance( SERVICENAME_MODULEMANAGER ), UNO_QUERY_THROW );
         aModuleIdentifier = xModuleManager->identify( m_xFrame );
     }
-    catch ( Exception& )
+    catch ( const Exception& )
     {
     }
 
@@ -257,8 +257,6 @@ void AddonsToolBarManager::FillToolbar( const Sequence< Sequence< PropertyValue
     Reference< XWindow > xToolbarWindow = VCLUnoHelper::GetInterface( m_pToolBar );
     for ( sal_uInt32 n = 0; n < (sal_uInt32)rAddonToolbar.getLength(); n++ )
     {
-        rtl::OUString   aValueName;
-
         rtl::OUString   aURL;
         rtl::OUString   aTitle;
         rtl::OUString   aImageId;
@@ -340,7 +338,7 @@ void AddonsToolBarManager::FillToolbar( const Sequence< Sequence< PropertyValue
                                                                             aURL, aArgs, xComponentContext ),
                                                                         UNO_QUERY );
                         }
-                        catch ( uno::Exception& )
+                        catch ( const uno::Exception& )
                         {
                         }
                         bMustBeInit = sal_False; // factory called init already!
@@ -375,7 +373,7 @@ void AddonsToolBarManager::FillToolbar( const Sequence< Sequence< PropertyValue
                     {
                         xInit->initialize( aArgs );
                     }
-                    catch ( uno::Exception& )
+                    catch ( const uno::Exception& )
                     {
                     }
                 }
@@ -406,7 +404,7 @@ void AddonsToolBarManager::FillToolbar( const Sequence< Sequence< PropertyValue
                     {
                         xUpdatable->update();
                     }
-                    catch ( uno::Exception& )
+                    catch ( const uno::Exception& )
                     {
                     }
                 }
@@ -420,7 +418,7 @@ void AddonsToolBarManager::FillToolbar( const Sequence< Sequence< PropertyValue
     AddFrameActionListener();
 }
 
-IMPL_LINK( AddonsToolBarManager, Click, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(AddonsToolBarManager, Click)
 {
     if ( m_bDisposed )
         return 1;
@@ -438,7 +436,7 @@ IMPL_LINK( AddonsToolBarManager, Click, ToolBox*, EMPTYARG )
     return 1;
 }
 
-IMPL_LINK( AddonsToolBarManager, DoubleClick, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(AddonsToolBarManager, DoubleClick)
 {
     if ( m_bDisposed )
         return 1;
@@ -456,7 +454,7 @@ IMPL_LINK( AddonsToolBarManager, DoubleClick, ToolBox*, EMPTYARG )
     return 1;
 }
 
-IMPL_LINK( AddonsToolBarManager, Command, CommandEvent*, EMPTYARG )
+IMPL_LINK_NOARG(AddonsToolBarManager, Command)
 {
     ResetableGuard aGuard( m_aLock );
 
@@ -466,7 +464,7 @@ IMPL_LINK( AddonsToolBarManager, Command, CommandEvent*, EMPTYARG )
     return 0;
 }
 
-IMPL_LINK( AddonsToolBarManager, Select, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(AddonsToolBarManager, Select)
 {
     if ( m_bDisposed )
         return 1;
@@ -485,12 +483,12 @@ IMPL_LINK( AddonsToolBarManager, Select, ToolBox*, EMPTYARG )
     return 1;
 }
 
-IMPL_LINK( AddonsToolBarManager, Activate, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(AddonsToolBarManager, Activate)
 {
     return 1;
 }
 
-IMPL_LINK( AddonsToolBarManager, Deactivate, ToolBox*, EMPTYARG )
+IMPL_LINK_NOARG(AddonsToolBarManager, Deactivate)
 {
     return 1;
 }
