@@ -39,20 +39,16 @@
 SV_IMPL_META_FACTORY1( SvMetaModule, SvMetaExtern );
 
 SvMetaModule::SvMetaModule()
-#ifdef IDL_COMPILER
     : bImported( sal_False )
     , bIsModified( sal_False )
-#endif
 {
 }
 
-#ifdef IDL_COMPILER
 SvMetaModule::SvMetaModule( const String & rIdlFileName, sal_Bool bImp )
     : aIdlFileName( rIdlFileName )
     , bImported( bImp ), bIsModified( sal_False )
 {
 }
-#endif
 
 #define MODULE_VER      0x0001
 void SvMetaModule::Load( SvPersistStream & rStm )
@@ -69,23 +65,19 @@ void SvMetaModule::Load( SvPersistStream & rStm )
     rStm >> aTypeList;
     rStm >> aAttrList;
     // browser
-    rStm.ReadByteString( aIdlFileName );
-    rStm.ReadByteString( aHelpFileName );
-    rStm.ReadByteString( aSlotIdFile );
-    rStm.ReadByteString( aModulePrefix );
+    aIdlFileName = rStm.ReadUniOrByteString( rStm.GetStreamCharSet() );
+    aHelpFileName.setString(read_lenPrefixed_uInt8s_ToOString<sal_uInt16>(rStm));
+    aSlotIdFile.setString(read_lenPrefixed_uInt8s_ToOString<sal_uInt16>(rStm));
+    aModulePrefix.setString(read_lenPrefixed_uInt8s_ToOString<sal_uInt16>(rStm));
 
     // read compiler data
     sal_uInt16 nCmpLen;
     rStm >> nCmpLen;
-#ifdef IDL_COMPILER
     DBG_ASSERT( (nVer & IDL_WRITE_MASK) == IDL_WRITE_COMPILER,
                 "no idl compiler format" );
     rStm >> aBeginName;
     rStm >> aEndName;
     rStm >> aNextName;
-#else
-    rStm->SeekRel( nCmpLen );
-#endif
 }
 
 void SvMetaModule::Save( SvPersistStream & rStm )
@@ -98,16 +90,15 @@ void SvMetaModule::Save( SvPersistStream & rStm )
     rStm << aTypeList;
     rStm << aAttrList;
     // browser
-    rStm.WriteByteString( aIdlFileName );
-    rStm.WriteByteString( aHelpFileName );
-    rStm.WriteByteString( aSlotIdFile );
-    rStm.WriteByteString( aModulePrefix );
+    rStm.WriteUniOrByteString( aIdlFileName, rStm.GetStreamCharSet() );
+    write_lenPrefixed_uInt8s_FromOString<sal_uInt16>(rStm, aHelpFileName.getString());
+    write_lenPrefixed_uInt8s_FromOString<sal_uInt16>(rStm, aSlotIdFile.getString());
+    write_lenPrefixed_uInt8s_FromOString<sal_uInt16>(rStm, aModulePrefix.getString());
 
     // write compiler data
     sal_uInt16 nCmpLen = 0;
     sal_uLong nLenPos = rStm.Tell();
     rStm << nCmpLen;
-#ifdef IDL_COMPILER
     rStm << aBeginName;
     rStm << aEndName;
     rStm << aNextName;
@@ -116,10 +107,9 @@ void SvMetaModule::Save( SvPersistStream & rStm )
     rStm.Seek( nLenPos );
     rStm << (sal_uInt16)( nPos - nLenPos - sizeof( sal_uInt16 ) );
     rStm.Seek( nPos );
-#endif
 }
 
-sal_Bool SvMetaModule::SetName( const ByteString & rName, SvIdlDataBase * pBase )
+sal_Bool SvMetaModule::SetName( const rtl::OString& rName, SvIdlDataBase * pBase )
 {
     if( pBase )
     {
@@ -129,7 +119,6 @@ sal_Bool SvMetaModule::SetName( const ByteString & rName, SvIdlDataBase * pBase
     return SvMetaExtern::SetName( rName );
 }
 
-#ifdef IDL_COMPILER
 sal_Bool SvMetaModule::FillNextName( SvGlobalName * pName )
 {
     *pName = aNextName;
@@ -152,11 +141,11 @@ void SvMetaModule::ReadAttributesSvIdl( SvIdlDataBase & rBase,
     if( aSlotIdFile.ReadSvIdl( SvHash_SlotIdFile(), rInStm ) )
     {
         sal_uInt32 nTokPos = rInStm.Tell();
-        if( !rBase.ReadIdFile( String::CreateFromAscii( aSlotIdFile.GetBuffer() ) ) )
+        if( !rBase.ReadIdFile( String::CreateFromAscii( aSlotIdFile.getString().getStr() ) ) )
         {
-            ByteString aStr = "cannot read file: ";
-            aStr += aSlotIdFile;
-            rBase.SetError( aStr, rInStm.GetToken() );
+            rtl::OStringBuffer aStr(RTL_CONSTASCII_STRINGPARAM("cannot read file: "));
+            aStr.append(aSlotIdFile.getString());
+            rBase.SetError( aStr.makeStringAndClear(), rInStm.GetToken() );
             rBase.WriteError( rInStm );
 
             rInStm.Seek( nTokPos );
@@ -171,21 +160,21 @@ void SvMetaModule::WriteAttributesSvIdl( SvIdlDataBase & rBase,
                                          sal_uInt16 nTab )
 {
     SvMetaExtern::WriteAttributesSvIdl( rBase, rOutStm, nTab );
-    if( aTypeLibFile.Len() || aSlotIdFile.Len() || aTypeLibFile.Len() )
+    if( !aTypeLibFile.getString().isEmpty() || !aSlotIdFile.getString().isEmpty() || !aTypeLibFile.getString().isEmpty() )
     {
-        if( aHelpFileName.Len() )
+        if( !aHelpFileName.getString().isEmpty() )
         {
             WriteTab( rOutStm, nTab );
             aHelpFileName.WriteSvIdl( SvHash_HelpFile(), rOutStm, nTab +1 );
             rOutStm << ';' << endl;
         }
-        if( aSlotIdFile.Len() )
+        if( !aSlotIdFile.getString().isEmpty() )
         {
             WriteTab( rOutStm, nTab );
             aSlotIdFile.WriteSvIdl( SvHash_SlotIdFile(), rOutStm, nTab +1 );
             rOutStm << ';' << endl;
         }
-        if( aTypeLibFile.Len() )
+        if( !aTypeLibFile.getString().isEmpty() )
         {
             WriteTab( rOutStm, nTab );
             aTypeLibFile.WriteSvIdl( SvHash_TypeLibFile(), rOutStm, nTab +1 );
@@ -242,7 +231,7 @@ void SvMetaModule::ReadContextSvIdl( SvIdlDataBase & rBase,
         SvToken * pTok = rInStm.GetToken_Next();
         if( pTok->IsString() )
         {
-            DirEntry aFullName( String::CreateFromAscii( pTok->GetString().GetBuffer() ) );
+            DirEntry aFullName( String::CreateFromAscii( pTok->GetString().getStr() ) );
             rBase.StartNewFile( aFullName.GetFull() );
             if( aFullName.Find( rBase.GetPath() ) )
             {
@@ -345,14 +334,14 @@ sal_Bool SvMetaModule::ReadSvIdl( SvIdlDataBase & rBase, SvTokenStream & rInStm
     {
         pTok = rInStm.GetToken_Next();
         if( pTok->IsString() )
-             bOk = aBeginName.MakeId( String::CreateFromAscii( pTok->GetString().GetBuffer() ) );
+             bOk = aBeginName.MakeId( String::CreateFromAscii( pTok->GetString().getStr() ) );
     }
     rInStm.ReadDelemiter();
     if( bOk )
     {
         pTok = rInStm.GetToken_Next();
         if( pTok->IsString() )
-             bOk = aEndName.MakeId( String::CreateFromAscii( pTok->GetString().GetBuffer() ) );
+             bOk = aEndName.MakeId( String::CreateFromAscii( pTok->GetString().getStr() ) );
     }
     rInStm.ReadDelemiter();
     if( bOk )
@@ -377,11 +366,11 @@ sal_Bool SvMetaModule::ReadSvIdl( SvIdlDataBase & rBase, SvTokenStream & rInStm
 void SvMetaModule::WriteSvIdl( SvIdlDataBase & rBase, SvStream & rOutStm,
                                sal_uInt16 nTab )
 {
-    rOutStm << SvHash_module()->GetName().GetBuffer() << endl
+    rOutStm << SvHash_module()->GetName().getStr() << endl
             << '\"';
-    rOutStm.WriteByteString( aBeginName.GetHexName() );
+    rOutStm.WriteUniOrByteString( aBeginName.GetHexName(), rOutStm.GetStreamCharSet() );
     rOutStm << '\"' << endl << '\"';
-    rOutStm.WriteByteString( aEndName.GetHexName() );
+    rOutStm.WriteUniOrByteString( aEndName.GetHexName(), rOutStm.GetStreamCharSet() );
     rOutStm << '\"' << endl;
     SvMetaExtern::WriteSvIdl( rBase, rOutStm, nTab );
 }
@@ -396,12 +385,12 @@ void SvMetaModule::WriteSfx( SvIdlDataBase & rBase, SvStream & rOutStm )
 }
 
 void SvMetaModule::WriteHelpIds( SvIdlDataBase & rBase, SvStream & rOutStm,
-                            Table* pTable )
+                            HelpIdTable& rTable )
 {
     for( sal_uLong n = 0; n < aClassList.Count(); n++ )
     {
         SvMetaClass * pClass = aClassList.GetObject( n );
-        pClass->WriteHelpIds( rBase, rOutStm, pTable );
+        pClass->WriteHelpIds( rBase, rOutStm, rTable );
     }
 }
 
@@ -411,12 +400,12 @@ void SvMetaModule::WriteAttributes( SvIdlDataBase & rBase,
                                      WriteType nT, WriteAttribute nA )
 {
     SvMetaExtern::WriteAttributes( rBase, rOutStm, nTab, nT, nA );
-    if( aHelpFileName.Len() )
+    if( !aHelpFileName.getString().isEmpty() )
     {
         WriteTab( rOutStm, nTab );
         rOutStm << "// class SvMetaModule" << endl;
         WriteTab( rOutStm, nTab );
-        rOutStm << "helpfile(\"" << aHelpFileName.GetBuffer() << "\");" << endl;
+        rOutStm << "helpfile(\"" << aHelpFileName.getString().getStr() << "\");" << endl;
     }
 }
 
@@ -428,15 +417,15 @@ void SvMetaModule::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
     {
     case WRITE_ODL:
     {
-        if( aSlotIdFile.Len() )
+        if( !aSlotIdFile.getString().isEmpty() )
         {
             WriteTab( rOutStm, nTab );
-            rOutStm << "#include \"" << aSlotIdFile.GetBuffer() << '"' << endl << endl;
+            rOutStm << "#include \"" << aSlotIdFile.getString().getStr() << '"' << endl << endl;
         }
         SvMetaExtern::Write( rBase, rOutStm, nTab, nT, nA );
         rOutStm << endl;
         WriteTab( rOutStm, nTab );
-        rOutStm << "library " << GetName().GetBuffer() << endl;
+        rOutStm << "library " << GetName().getString().getStr() << endl;
         WriteTab( rOutStm, nTab );
         rOutStm << '{' << endl;
         WriteTab( rOutStm, nTab );
@@ -461,7 +450,7 @@ void SvMetaModule::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
     case WRITE_DOCU:
     {
         rOutStm << "SvIDL interface documentation" << endl << endl;
-        rOutStm << "<MODULE>" << endl << GetName().GetBuffer() << endl;
+        rOutStm << "<MODULE>" << endl << GetName().getString().getStr() << endl;
         WriteDescription( rOutStm );
         rOutStm << "</MODULE>" << endl << endl;
 
@@ -471,10 +460,10 @@ void SvMetaModule::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
             SvMetaClass * pClass = aClassList.GetObject( n );
             if( !pClass->IsShell() )
             {
-                rOutStm << pClass->GetName().GetBuffer();
+                rOutStm << pClass->GetName().getString().getStr();
                 SvMetaClass* pSC = pClass->GetSuperClass();
                 if( pSC )
-                    rOutStm << " : " << pSC->GetName().GetBuffer();
+                    rOutStm << " : " << pSC->GetName().getString().getStr();
 
                 // imported classes
                 const SvClassElementMemberList& rClassList = pClass->GetClassList();
@@ -482,11 +471,11 @@ void SvMetaModule::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
                 {
                     rOutStm << " ( ";
 
-                    for( sal_uLong m=0; m<rClassList.Count(); m++ )
+                    for( sal_uLong m=0; m<rClassList.Count(); ++m )
                     {
                         SvClassElement *pEle = rClassList.GetObject(m);
                         SvMetaClass *pCl = pEle->GetClass();
-                        rOutStm << pCl->GetName().GetBuffer();
+                        rOutStm << pCl->GetName().getString().getStr();
                         if ( m+1 == rClassList.Count() )
                             rOutStm << " )";
                         else
@@ -518,37 +507,4 @@ void SvMetaModule::Write( SvIdlDataBase & rBase, SvStream & rOutStm,
     }
 }
 
-void SvMetaModule::WriteSrc( SvIdlDataBase & rBase, SvStream & rOutStm,
-                             Table * pTable )
-{
-    if( aSlotIdFile.Len() )
-        rOutStm << "//#include <" << aSlotIdFile.GetBuffer() << '>' << endl;
-    for( sal_uLong n = 0; n < aClassList.Count(); n++ )
-    {
-        aClassList.GetObject( n )->WriteSrc( rBase, rOutStm, pTable );
-    }
-}
-
-void SvMetaModule::WriteHxx( SvIdlDataBase & rBase, SvStream & rOutStm,
-                             sal_uInt16 nTab )
-{
-    for( sal_uLong n = 0; n < aClassList.Count(); n++ )
-    {
-        SvMetaClass * pClass = aClassList.GetObject( n );
-        pClass->WriteHxx( rBase, rOutStm, nTab );
-    }
-}
-
-void SvMetaModule::WriteCxx( SvIdlDataBase & rBase, SvStream & rOutStm,
-                             sal_uInt16 nTab )
-{
-    for( sal_uLong n = 0; n < aClassList.Count(); n++ )
-    {
-        SvMetaClass * pClass = aClassList.GetObject( n );
-        pClass->WriteCxx( rBase, rOutStm, nTab );
-    }
-}
-
-#endif // IDL_COMPILER
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
