@@ -367,7 +367,7 @@ sal_Bool SAL_CALL SpellChecker::isValid( const OUString& rWord, const Locale& rL
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
-     if (rLocale == Locale()  ||  !rWord.getLength())
+     if (rLocale == Locale()  ||  rWord.isEmpty())
         return sal_True;
 
     if (!hasLocale( rLocale ))
@@ -488,7 +488,7 @@ Reference< XSpellAlternatives > SAL_CALL SpellChecker::spell(
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
-     if (rLocale == Locale()  ||  !rWord.getLength())
+     if (rLocale == Locale()  ||  rWord.isEmpty())
         return NULL;
 
     if (!hasLocale( rLocale ))
