@@ -32,6 +32,7 @@
 
 #include <string.h>
 #include <memory>
+#include <boost/scoped_ptr.hpp>
 #include <unotools/collatorwrapper.hxx>
 #include <unotools/transliterationwrapper.hxx>
 #include <com/sun/star/sheet/NamedRangeFlag.hpp>
@@ -68,7 +69,7 @@ ScRangeData::ScRangeData( ScDocument* pDok,
                           RangeType nType,
                           const FormulaGrammar::Grammar eGrammar ) :
                 aName       ( rName ),
-                aUpperName  ( ScGlobal::pCharClass->upper( rName ) ),
+                aUpperName  ( ScGlobal::pCharClass->uppercase( rName ) ),
                 pCode       ( NULL ),
                 aPos        ( rAddress ),
                 eType       ( nType ),
@@ -99,7 +100,7 @@ ScRangeData::ScRangeData( ScDocument* pDok,
                           const ScAddress& rAddress,
                           RangeType nType ) :
                 aName       ( rName ),
-                aUpperName  ( ScGlobal::pCharClass->upper( rName ) ),
+                aUpperName  ( ScGlobal::pCharClass->uppercase( rName ) ),
                 pCode       ( new ScTokenArray( rArr ) ),
                 aPos        ( rAddress ),
                 eType       ( nType ),
@@ -110,25 +111,14 @@ ScRangeData::ScRangeData( ScDocument* pDok,
                 mnMaxRow    (-1),
                 mnMaxCol    (-1)
 {
-    if( !pCode->GetCodeError() )
-    {
-        pCode->Reset();
-        FormulaToken* p = pCode->GetNextReference();
-        if( p )// genau eine Referenz als erstes
-        {
-            if( p->GetType() == svSingleRef )
-                eType = eType | RT_ABSPOS;
-            else
-                eType = eType | RT_ABSAREA;
-        }
-    }
+    InitCode();
 }
 
 ScRangeData::ScRangeData( ScDocument* pDok,
                           const rtl::OUString& rName,
                           const ScAddress& rTarget ) :
                 aName       ( rName ),
-                aUpperName  ( ScGlobal::pCharClass->upper( rName ) ),
+                aUpperName  ( ScGlobal::pCharClass->uppercase( rName ) ),
                 pCode       ( new ScTokenArray() ),
                 aPos        ( rTarget ),
                 eType       ( RT_NAME ),
@@ -300,7 +290,7 @@ void ScRangeData::UpdateSymbol( rtl::OUStringBuffer& rBuffer, const ScAddress& r
 
 void ScRangeData::UpdateReference(  UpdateRefMode eUpdateRefMode,
                                     const ScRange& r,
-                                    SCsCOL nDx, SCsROW nDy, SCsTAB nDz )
+                                    SCsCOL nDx, SCsROW nDy, SCsTAB nDz, bool bLocal )
 {
     bool bChanged = false;
 
@@ -312,7 +302,7 @@ void ScRangeData::UpdateReference(  UpdateRefMode eUpdateRefMode,
         aComp.SetGrammar(pDoc->GetGrammar());
         const bool bRelRef = aComp.UpdateNameReference( eUpdateRefMode, r,
                                                     nDx, nDy, nDz,
-                                                    bChanged, bSharedFormula);
+                                                    bChanged, bSharedFormula, bLocal);
         if (bSharedFormula)
         {
             if (bRelRef)
@@ -596,34 +586,6 @@ sal_uInt32 ScRangeData::GetUnoType() const
     return nUnoType;
 }
 
-// bei TransferTab von einem in ein anderes Dokument anpassen,
-// um Referenzen auf die eigene Tabelle mitzubekommen
-
-void ScRangeData::TransferTabRef( SCTAB nOldTab, SCTAB nNewTab )
-{
-    long nTabDiff = (long)nNewTab - nOldTab;
-    long nPosDiff = (long)nNewTab - aPos.Tab();
-    aPos.SetTab( nNewTab );
-    ScToken* t;
-    pCode->Reset();
-    while ( ( t = static_cast<ScToken*>(pCode->GetNextReference()) ) != NULL )
-    {
-        ScSingleRefData& rRef1 = t->GetSingleRef();
-        if ( rRef1.IsTabRel() )
-            rRef1.nTab = sal::static_int_cast<SCsTAB>( rRef1.nTab + nPosDiff );
-        else
-            rRef1.nTab = sal::static_int_cast<SCsTAB>( rRef1.nTab + nTabDiff );
-        if ( t->GetType() == svDoubleRef )
-        {
-            ScSingleRefData& rRef2 = t->GetDoubleRef().Ref2;
-            if ( rRef2.IsTabRel() )
-                rRef2.nTab = sal::static_int_cast<SCsTAB>( rRef2.nTab + nPosDiff );
-            else
-                rRef2.nTab = sal::static_int_cast<SCsTAB>( rRef2.nTab + nTabDiff );
-        }
-    }
-}
-
 void ScRangeData::ReplaceRangeNamesInUse( const IndexMap& rMap )
 {
     bool bCompile = false;
@@ -712,6 +674,29 @@ void ScRangeData::ValidateTabRefs()
     }
 }
 
+void ScRangeData::SetCode( ScTokenArray& rArr )
+{
+    boost::scoped_ptr<ScTokenArray> pOldCode( pCode); // old pCode will be deleted
+    pCode = new ScTokenArray( rArr );
+    InitCode();
+}
+
+void ScRangeData::InitCode()
+{
+    if( !pCode->GetCodeError() )
+    {
+        pCode->Reset();
+        FormulaToken* p = pCode->GetNextReference();
+        if( p )   // exact one reference at first
+        {
+            if( p->GetType() == svSingleRef )
+                eType = eType | RT_ABSPOS;
+            else
+                eType = eType | RT_ABSAREA;
+        }
+    }
+}
+
 
 extern "C"
 int SAL_CALL ScRangeData_QsortNameCompare( const void* p1, const void* p2 )
@@ -796,7 +781,7 @@ const ScRangeData* ScRangeName::findByUpperName(const OUString& rName) const
     return itr == maData.end() ? NULL : itr->second;
 }
 
-ScRangeData* ScRangeName::findByIndex(sal_uInt16 i)
+ScRangeData* ScRangeName::findByIndex(sal_uInt16 i) const
 {
     if (!i)
         // index should never be zero.
@@ -807,11 +792,11 @@ ScRangeData* ScRangeName::findByIndex(sal_uInt16 i)
 }
 
 void ScRangeName::UpdateReference(
-    UpdateRefMode eUpdateRefMode, const ScRange& rRange, SCsCOL nDx, SCsROW nDy, SCsTAB nDz)
+    UpdateRefMode eUpdateRefMode, const ScRange& rRange, SCsCOL nDx, SCsROW nDy, SCsTAB nDz, bool bLocal)
 {
     DataType::iterator itr = maData.begin(), itrEnd = maData.end();
     for (; itr != itrEnd; ++itr)
-        itr->second->UpdateReference(eUpdateRefMode, rRange, nDx, nDy, nDz);
+        itr->second->UpdateReference(eUpdateRefMode, rRange, nDx, nDy, nDz, bLocal);
 }
 
 void ScRangeName::UpdateTabRef(SCTAB nTable, sal_uInt16 nFlag, SCTAB nNewTable, SCTAB nNewSheets)
@@ -894,6 +879,7 @@ bool ScRangeName::insert(ScRangeData* p)
     }
 
     rtl::OUString aName(p->GetUpperName());
+    erase(aName); // ptr_map won't insert it if a duplicate name exists.
     pair<DataType::iterator, bool> r = maData.insert(aName, p);
     if (r.second)
     {
@@ -908,7 +894,12 @@ bool ScRangeName::insert(ScRangeData* p)
 
 void ScRangeName::erase(const ScRangeData& r)
 {
-    DataType::iterator itr = maData.find(r.GetUpperName());
+    erase(r.GetUpperName());
+}
+
+void ScRangeName::erase(const rtl::OUString& rName)
+{
+    DataType::iterator itr = maData.find(rName);
     if (itr != maData.end())
         erase(itr);
 }
