@@ -90,7 +90,7 @@ void ScDrawShell::GetHLinkState( SfxItemSet& rSet )             //  Hyperlink
     {
         SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
         ScMacroInfo* pInfo = ScDrawLayer::GetMacroInfo( pObj );
-        if ( pInfo && (pInfo->GetHlink().getLength() > 0) )
+        if ( pInfo && !pInfo->GetHlink().isEmpty() )
         {
             aHLinkItem.SetURL( pInfo->GetHlink() );
             aHLinkItem.SetInsertMode(HLINK_FIELD);
@@ -122,7 +122,7 @@ void ScDrawShell::GetHLinkState( SfxItemSet& rSet )             //  Hyperlink
                     if(xInfo->hasPropertyByName( sPropLabel ))
                     {
                         aAny = xPropSet->getPropertyValue( sPropLabel );
-                        if ( (aAny >>= sTmp) && sTmp.getLength() )
+                        if ( (aAny >>= sTmp) && !sTmp.isEmpty() )
                         {
                             aHLinkItem.SetName(sTmp);
                         }
@@ -131,7 +131,7 @@ void ScDrawShell::GetHLinkState( SfxItemSet& rSet )             //  Hyperlink
                     if(xInfo->hasPropertyByName( sPropTargetURL ))
                     {
                         aAny = xPropSet->getPropertyValue( sPropTargetURL );
-                        if ( (aAny >>= sTmp) && sTmp.getLength() )
+                        if ( (aAny >>= sTmp) && !sTmp.isEmpty() )
                         {
                             aHLinkItem.SetURL(sTmp);
                         }
@@ -140,7 +140,7 @@ void ScDrawShell::GetHLinkState( SfxItemSet& rSet )             //  Hyperlink
                     if(xInfo->hasPropertyByName( sPropTargetFrame ))
                     {
                         aAny = xPropSet->getPropertyValue( sPropTargetFrame );
-                        if ( (aAny >>= sTmp) && sTmp.getLength() )
+                        if ( (aAny >>= sTmp) && !sTmp.isEmpty() )
                         {
                             aHLinkItem.SetTargetFrame(sTmp);
                         }
@@ -500,7 +500,7 @@ void ScDrawShell::ExecDrawFunc( SfxRequest& rReq )
 
                     if(SC_LAYER_INTERN != pSelected->GetLayer())
                     {
-                        String aName(pSelected->GetName());
+                        rtl::OUString aName = pSelected->GetName();
 
                         SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
                         OSL_ENSURE(pFact, "Dialogdiet fail!");
@@ -512,14 +512,16 @@ void ScDrawShell::ExecDrawFunc( SfxRequest& rReq )
                         if(RET_OK == pDlg->Execute())
                         {
                             ScDocShell* pDocSh = pViewData->GetDocShell();
-                            pDlg->GetName(aName);
+                            String aTmp;
+                            pDlg->GetName(aTmp);
+                            aName = aTmp;
 
-                            if(aName != pSelected->GetName())
+                            if (!aName.equals(pSelected->GetName()))
                             {
                                 // handle name change
                                 const sal_uInt16 nObjType(pSelected->GetObjIdentifier());
 
-                                if(OBJ_GRAF == nObjType && 0L == aName.Len())
+                                if (OBJ_GRAF == nObjType && aName.isEmpty())
                                 {
                                     //  graphics objects must have names
                                     //  (all graphics are supposed to be in the navigator)
