@@ -52,10 +52,10 @@ namespace scripting_runtimemgr
 {
 
 const sal_Char* const LANGUAGE_TO_RESOLVE_ON[] = { "All" }; // should be configurable
-OUString nrs_implName(RTL_CONSTASCII_USTRINGPARAM(
-    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" ));
-OUString nrs_serviceName(RTL_CONSTASCII_USTRINGPARAM(
-    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" ));
+OUString nrs_implName(
+    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" );
+OUString nrs_serviceName(
+    "drafts.com.sun.star.script.framework.runtime.DefaultScriptNameResolver" );
 Sequence< OUString > nrs_serviceNames = Sequence< OUString >( &nrs_serviceName, 1 );
 
 const char* const SCRIPTSTORAGEMANAGER_SERVICE =
@@ -144,7 +144,7 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
                 Reference< XInterface > () );
         }
     }
-    catch ( Exception & e )
+    catch ( const Exception & e )
     {
         OUString temp = OUSTR(
             "ScriptNameResolverImpl::resolve : problem with getPropertyValue" );
@@ -169,10 +169,10 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
 
 
     OSL_TRACE( "ScriptNameResolverImpl::resolve Starting..." );
-    OUString docString(RTL_CONSTASCII_USTRINGPARAM("location=document"));
-    OUString userString(RTL_CONSTASCII_USTRINGPARAM("location=user"));
-    OUString shareString(RTL_CONSTASCII_USTRINGPARAM("location=share"));
-    OUString filesysString(RTL_CONSTASCII_USTRINGPARAM("location=filesystem"));
+    OUString docString("location=document");
+    OUString userString("location=user");
+    OUString shareString("location=share");
+    OUString filesysString("location=filesystem");
 
     // initialise vector with doc, user and share
 
@@ -212,15 +212,15 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
         {
             filesysURL = getFilesysURL( scriptURI );
         }
-        catch ( lang::IllegalArgumentException & e )
+        catch ( const lang::IllegalArgumentException & e )
         {
             OUString temp = OUSTR( "ScriptNameResolverImpl::resolve: " );
             throw RuntimeException( temp.concat( e.Message ), Reference< XInterface >() );
         }
         Reference< XInterface > xInterface(
             m_xMultiComFac->createInstanceWithContext(
-                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                    "com.sun.star.ucb.SimpleFileAccess" )),
+                ::rtl::OUString(
+                    "com.sun.star.ucb.SimpleFileAccess" ),
                 m_xContext
             ),
             UNO_SET_THROW
@@ -245,7 +245,7 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
                     filesysScriptStorageID, ::rtl::OUStringToOString(
                         filesysURL, RTL_TEXTENCODING_ASCII_US ).pData->buffer );
         }
-        catch ( RuntimeException & e )
+        catch ( const RuntimeException & e )
         {
             OUString temp = OUSTR( "ScriptNameResolverImpl::resolve: " );
             throw RuntimeException( temp.concat( e.Message ), Reference< XInterface >() );
@@ -262,7 +262,7 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
         // b) an illegal location
 
         // detect illegal location
-        if (  scriptURI.indexOf( OUString(RTL_CONSTASCII_USTRINGPARAM("location=")) ) != -1 )
+        if (  scriptURI.indexOf( OUString("location=") ) != -1 )
         {
             OSL_TRACE(
                 "ScriptNameResolver::resolve, throwing IllegalArgException" );
@@ -292,41 +292,41 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
             }
 
         }
-        catch ( css::security::AccessControlException  & e )
+        catch ( css::security::AccessControlException  & )
         {
             // no execute permission
             OSL_TRACE( "ScriptNameResolverImpl::resolve : AccessControlException " );
             continue;
         }
-        catch ( beans::UnknownPropertyException & e )
+        catch ( const beans::UnknownPropertyException & e )
         {
             OUString temp = OUSTR(
                 "ScriptNameResolverImpl::resolve : UnknownPropertyException" );
             throw RuntimeException( temp.concat( e.Message ),
                 Reference< XInterface > () );
         }
-        catch ( beans::PropertyVetoException  & e )
+        catch ( const beans::PropertyVetoException  & e )
         {
             OUString temp = OUSTR(
                 "ScriptNameResolverImpl::resolve : PropertyVetoException " );
             throw RuntimeException( temp.concat( e.Message ),
                 Reference< XInterface > () );
         }
-        catch ( lang::IllegalArgumentException  & e )
+        catch ( const lang::IllegalArgumentException  & e )
         {
             OUString temp = OUSTR(
                 "ScriptNameResolverImpl::resolve : IllegalArgumentException " );
             throw lang::IllegalArgumentException( temp.concat( e.Message ),
                 Reference< XInterface > (), e.ArgumentPosition );
         }
-        catch ( lang::WrappedTargetException & e )
+        catch ( const lang::WrappedTargetException & e )
         {
         OUString temp = OUSTR(
                 "ScriptNameResolverImpl::resolve : WrappedTargetException " );
             throw RuntimeException( temp.concat( e.Message ),
                 Reference< XInterface > () );
         }
-        catch ( Exception & e )
+        catch ( const Exception & e )
         {
             OSL_TRACE(
                 "Exception thrown by storage %d, failed to match uri: %s",
@@ -362,7 +362,7 @@ throw ( lang::IllegalArgumentException, script::CannotConvertException, RuntimeE
                 storage::XScriptInfoAccess > ( xScriptStorage, UNO_QUERY_THROW );
             Sequence< Reference< storage::XScriptInfo > > results =
                 xScriptInfoAccess->getAllImplementations( );
-            Reference < lang::XEventListener > xEL_ScriptStorageMgr(( xScriptStorageMgr ,UNO_QUERY_THROW );
+            Reference < lang::XEventListener > xEL_ScriptStorageMgr( xScriptStorageMgr ,UNO_QUERY_THROW );
             lang::EventObject event( results[ 0 ] );
             xEL_ScriptStorageMgr->disposing( event );
         }
@@ -416,7 +416,7 @@ SAL_THROW ( ( lang::IllegalArgumentException, css::security::AccessControlExcept
     try
     {
         OUString permissionURI = docURI;
-        OUString filesysString(RTL_CONSTASCII_USTRINGPARAM("location=filesystem"));
+        OUString filesysString("location=filesystem");
         if ( scriptURI.indexOf( filesysString ) != -1 )
         {
             // in the case of filesys scripts we're checking whether the
@@ -426,7 +426,7 @@ SAL_THROW ( ( lang::IllegalArgumentException, css::security::AccessControlExcept
             {
                 permissionURI = getFilesysURL( scriptURI );
             }
-            catch ( lang::IllegalArgumentException & e )
+            catch ( const lang::IllegalArgumentException & e )
             {
                 OUString temp = OUSTR( "ScriptNameResolverImpl::resolveFromURI: " );
                 throw RuntimeException( temp.concat( e.Message ), Reference< XInterface >() );
@@ -449,7 +449,7 @@ SAL_THROW ( ( lang::IllegalArgumentException, css::security::AccessControlExcept
         // that information was in the uri
         resolvedScriptInfo = results[ 0 ];
     }
-    catch ( css::security::AccessControlException & ace )
+    catch ( const css::security::AccessControlException & ace )
     {
         OUString temp = OUSTR(
             "ScriptRuntimeManager::resolveURIFromStorageID AccessControlException: " );
@@ -457,7 +457,7 @@ SAL_THROW ( ( lang::IllegalArgumentException, css::security::AccessControlExcept
                                               Reference< XInterface > (),
                                                 ace.LackingPermission );
     }
-    catch ( lang::IllegalArgumentException & iae )
+    catch ( const lang::IllegalArgumentException & iae )
     {
         OUString temp = OUSTR(
             "ScriptRuntimeManager::resolveURIFromStorageID IllegalArgumentException: " );
@@ -465,14 +465,14 @@ SAL_THROW ( ( lang::IllegalArgumentException, css::security::AccessControlExcept
                                               Reference< XInterface > (),
                                               iae.ArgumentPosition );
     }
-    catch ( RuntimeException & re )
+    catch ( const RuntimeException & re )
     {
         OUString temp = OUSTR(
             "ScriptRuntimeManager::resolveURIFromStorageID RuntimeException: " );
         throw RuntimeException( temp.concat( re.Message ),
                                 Reference< XInterface > () );
     }
-    catch ( Exception & e )
+    catch ( const Exception & e )
     {
         OUString temp = OUSTR(
             "ScriptNameResolverImpl::resolveURIFromStorageID : Exception caught - RuntimeException rethrown" );
@@ -502,7 +502,7 @@ const ::rtl::OUString & permissionURI ) SAL_THROW ( ( RuntimeException, css::sec
         Reference< XInterface > xInterface( m_xContext->getValueByName(
                     OUString::createFromAscii( SCRIPTSTORAGEMANAGER_SERVICE ) ), UNO_QUERY_THROW );
         // check that we have permissions for this storage
-        Reference< dcsssf::security::XScriptSecurity > xScriptSecurity( xInterface, UNO_QUERY_THROW );
+        Reference< ::drafts::com::sun::star::script::framework::security::XScriptSecurity > xScriptSecurity( xInterface, UNO_QUERY_THROW );
         scripting_constants::ScriptingConstantsPool& scriptingConstantsPool =
                 scripting_constants::ScriptingConstantsPool::instance();
         // if we dealing with a document storage (ie. not user or share
@@ -511,7 +511,7 @@ const ::rtl::OUString & permissionURI ) SAL_THROW ( ( RuntimeException, css::sec
             ( sid != scriptingConstantsPool.SHARED_STORAGE_ID ) )
         {
             xScriptSecurity->checkPermission( permissionURI,
-                OUString(RTL_CONSTASCII_USTRINGPARAM("execute")) );
+                OUString("execute") );
             // if we get here, the checkPermission hasn't thrown an
             // AccessControlException, ie. permission has been granted
             OSL_TRACE( "ScriptNameResolverImpl::getStorageInstance: got execute permission for ID=%d", sid );
@@ -520,23 +520,23 @@ const ::rtl::OUString & permissionURI ) SAL_THROW ( ( RuntimeException, css::sec
         Reference< XInterface > xScriptStorage( ScriptStorageManager->getScriptStorage( sid ), UNO_SET_THROW );
         xScriptInfoAccess.set( xScriptStorage, UNO_QUERY_THROW );
     }
-    catch ( lang::IllegalArgumentException & e )
+    catch ( const lang::IllegalArgumentException & e )
     {
         OUString temp = OUSTR( "ScriptNameResolverImpl::getStorageInstance: " );
         throw lang::IllegalArgumentException( temp.concat( e.Message ),
             Reference< XInterface >(), e.ArgumentPosition );
     }
-    catch ( css::security::AccessControlException & e )
+    catch ( const css::security::AccessControlException & e )
     {
         OUString temp = OUSTR( "ScriptNameResolverImpl::getStorageInstance: AccessControlException " );
         throw css::security::AccessControlException( temp.concat( e.Message ), Reference< XInterface >(), e.LackingPermission );
     }
-    catch ( RuntimeException & re )
+    catch ( const RuntimeException & re )
     {
         OUString temp = OUSTR( "ScriptNameResolverImpl::getStorageInstance: " );
         throw RuntimeException( temp.concat( re.Message ), Reference< XInterface >() );
     }
-    catch ( Exception & e )
+    catch ( const Exception & e )
     {
         OUString temp = OUSTR( "ScriptNameResolverImpl::getStorageInstance: " );
         throw RuntimeException( temp.concat( e.Message ), Reference< XInterface >() );
@@ -550,7 +550,7 @@ throw( lang::IllegalArgumentException )
 {
         OUString filePath;
         OUString fileName;
-        OUString filesysString(RTL_CONSTASCII_USTRINGPARAM("location=filesystem"));
+        OUString filesysString("location=filesystem");
         sal_Int32 locationPos = scriptURI.indexOf( filesysString );
         // expect location=filesys:file:///foo/bar/myscript.bsh etc
         // except the file url at this point is encoded
@@ -567,7 +567,7 @@ throw( lang::IllegalArgumentException )
                                 endOfLocn - locationPos - filesysStrLen );
         }
         //file name shoul also be encoded so again ok to search for '&'
-        OUString functionKey(RTL_CONSTASCII_USTRINGPARAM("function="));
+        OUString functionKey("function=");
         sal_Int32 functionKeyLength = functionKey.getLength();
         sal_Int32 functionNamePos = scriptURI.indexOf( functionKey );
         if ( functionNamePos > 0 )
@@ -612,13 +612,13 @@ SAL_THROW( ( Exception ) )
 }
 
 //*************************************************************************
-Sequence< OUString > scriptnri_getSupportedServiceNames() SAL_THROW( () )
+Sequence< OUString > scriptnri_getSupportedServiceNames() SAL_THROW(())
 {
     return nrs_serviceNames;
 }
 
 //*************************************************************************
-OUString scriptnri_getImplementationName() SAL_THROW( () )
+OUString scriptnri_getImplementationName() SAL_THROW(())
 {
     return nrs_implName;
 }
