@@ -31,7 +31,6 @@
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/style/XStyle.hpp>
 
-#include <osl/mutex.hxx>
 #include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <comphelper/serviceinfohelper.hxx>
@@ -45,6 +44,7 @@
 #include <svl/smplhint.hxx>
 #include <svl/itemset.hxx>
 
+#include <svx/sdr/properties/attributeproperties.hxx>
 #include <svx/xflbmtit.hxx>
 #include <svx/xflbstit.hxx>
 #include <editeng/bulitem.hxx>
@@ -161,7 +161,7 @@ void SdStyleSheet::SetApiName( const OUString& rApiName )
 
 rtl::OUString SdStyleSheet::GetApiName() const
 {
-    if( msApiName.getLength() )
+    if( !msApiName.isEmpty() )
         return msApiName;
     else
         return GetName();
@@ -209,7 +209,7 @@ sal_Bool SdStyleSheet::SetParent(const String& rParentName)
         {
             if( rParentName.Len() )
             {
-                SfxStyleSheetBase* pStyle = rPool.Find(rParentName, nFamily);
+                SfxStyleSheetBase* pStyle = pPool->Find(rParentName, nFamily);
                 if (pStyle)
                 {
                     bResult = sal_True;
@@ -357,13 +357,16 @@ sal_Bool SdStyleSheet::IsUsed() const
                 continue;
 
             // NULL-Pointer ist im Listener-Array erlaubt
-            if (pListener && pListener->ISA(SdrAttrObj))
+            if (pListener)
             {
-                bResult = ((SdrAttrObj*)pListener)->IsInserted();
-            }
-            else if (pListener && pListener->ISA(SfxStyleSheet))
-            {
-                bResult = ((SfxStyleSheet*)pListener)->IsUsed();
+                if (pListener->ISA(sdr::properties::AttributeProperties))
+                {
+                    bResult = true;
+                }
+                else if (pListener->ISA(SfxStyleSheet))
+                {
+                    bResult = ((SfxStyleSheet*)pListener)->IsUsed();
+                }
             }
             if (bResult)
                 break;
@@ -402,7 +405,7 @@ SdStyleSheet* SdStyleSheet::GetRealStyleSheet() const
     String aRealStyle;
     String aSep( RTL_CONSTASCII_USTRINGPARAM( SD_LT_SEPARATOR ));
     SdStyleSheet* pRealStyle = NULL;
-    SdDrawDocument* pDoc = ((SdStyleSheetPool&) rPool).GetDoc();
+    SdDrawDocument* pDoc = ((SdStyleSheetPool*)pPool)->GetDoc();
 
     ::sd::DrawViewShell* pDrawViewShell = 0;
 
@@ -433,7 +436,7 @@ SdStyleSheet* SdStyleSheet::GetRealStyleSheet() const
         {
             // Noch keine Seite vorhanden
             // Dieses kann beim Aktualisieren vonDokumentvorlagen vorkommen
-            SfxStyleSheetIterator aIter(&rPool, SD_STYLE_FAMILY_MASTERPAGE);
+            SfxStyleSheetIterator aIter(pPool, SD_STYLE_FAMILY_MASTERPAGE);
             SfxStyleSheetBase* pSheet = aIter.First();
             if( pSheet )
                 aRealStyle = pSheet->GetName();
@@ -479,12 +482,12 @@ SdStyleSheet* SdStyleSheet::GetRealStyleSheet() const
     }
 
     aRealStyle += aInternalName;
-    pRealStyle = static_cast< SdStyleSheet* >( rPool.Find(aRealStyle, SD_STYLE_FAMILY_MASTERPAGE) );
+    pRealStyle = static_cast< SdStyleSheet* >( pPool->Find(aRealStyle, SD_STYLE_FAMILY_MASTERPAGE) );
 
 #ifdef DBG_UTIL
     if( !pRealStyle )
     {
-        SfxStyleSheetIterator aIter(&rPool, SD_STYLE_FAMILY_MASTERPAGE);
+        SfxStyleSheetIterator aIter(pPool, SD_STYLE_FAMILY_MASTERPAGE);
         if( aIter.Count() > 0 )
             // StyleSheet not found, but pool already loaded
             DBG_ASSERT(pRealStyle, "Internal StyleSheet not found");
@@ -540,7 +543,7 @@ SdStyleSheet* SdStyleSheet::GetPseudoStyleSheet() const
         }
     }
 
-    pPseudoStyle = static_cast<SdStyleSheet*>(rPool.Find(aStyleName, SD_STYLE_FAMILY_PSEUDO));
+    pPseudoStyle = static_cast<SdStyleSheet*>(pPool->Find(aStyleName, SD_STYLE_FAMILY_PSEUDO));
     DBG_ASSERT(pPseudoStyle, "PseudoStyleSheet nicht gefunden");
 
     return pPseudoStyle;
@@ -616,7 +619,7 @@ void SdStyleSheet::AdjustToFontHeight(SfxItemSet& rSet, sal_Bool bOnlyMissingIte
             const SvxLRSpaceItem& rLRItem = (const SvxLRSpaceItem&)pCurSet->Get(EE_PARA_LRSPACE);
             double fIndentFraction = double(rLRItem.GetTxtLeft()) / nOldHeight;
             SvxLRSpaceItem aNewLRItem(rLRItem);
-            aNewLRItem.SetTxtLeft((sal_uInt16)(fIndentFraction * nNewHeight));
+            aNewLRItem.SetTxtLeft(fIndentFraction * nNewHeight);
             double fFirstIndentFraction = double(rLRItem.GetTxtFirstLineOfst()) / nOldHeight;
             aNewLRItem.SetTxtFirstLineOfst((short)(fFirstIndentFraction * nNewHeight));
             rSet.Put(aNewLRItem);
@@ -671,7 +674,7 @@ void SdStyleSheet::SetHelpId( const String& r, sal_uLong nId )
 
     if( (nId >= HID_PSEUDOSHEET_OUTLINE1) && ( nId <= HID_PSEUDOSHEET_OUTLINE9 ) )
     {
-        msApiName = OUString( RTL_CONSTASCII_USTRINGPARAM("outline") );
+        msApiName = "outline";
         msApiName += OUString( (sal_Unicode)( '1' + (nId - HID_PSEUDOSHEET_OUTLINE1) ) );
     }
     else
@@ -727,11 +730,11 @@ OUString SdStyleSheet::GetFamilyString( SfxStyleFamily eFamily )
     switch( eFamily )
     {
     case SD_STYLE_FAMILY_CELL:
-        return OUString( RTL_CONSTASCII_USTRINGPARAM( "cell" ) );
+        return OUString( "cell" );
     default:
         OSL_FAIL( "SdStyleSheet::GetFamilyString(), illegal family!" );
     case SD_STYLE_FAMILY_GRAPHICS:
-        return OUString( RTL_CONSTASCII_USTRINGPARAM( "graphics" ) );
+        return OUString( "graphics" );
     }
 }
 
@@ -747,7 +750,7 @@ void SdStyleSheet::throwIfDisposed() throw (RuntimeException)
 
 SdStyleSheet* SdStyleSheet::CreateEmptyUserStyle( SfxStyleSheetBasePool& rPool, SfxStyleFamily eFamily )
 {
-    OUString aPrefix( RTL_CONSTASCII_USTRINGPARAM("user") );
+    OUString aPrefix( "user" );
     OUString aName;
     sal_Int32 nIndex = 1;
     do
@@ -822,12 +825,9 @@ void SAL_CALL SdStyleSheet::dispose(  ) throw (RuntimeException)
         {
             throw;
         }
-        catch (Exception & exc)
+        catch (const Exception & exc)
         {
-            throw RuntimeException(
-                OUString( RTL_CONSTASCII_USTRINGPARAM(
-                              "unexpected UNO exception caught: ") ) +
-                exc.Message, Reference< XInterface >() );
+            throw RuntimeException( "unexpected UNO exception caught: "  +  exc.Message, Reference< XInterface >() );
         }
     }
 }
@@ -912,7 +912,7 @@ void SdStyleSheet::notifyModifyListener()
 
 OUString SAL_CALL SdStyleSheet::getImplementationName() throw(RuntimeException)
 {
-    return OUString( RTL_CONSTASCII_USTRINGPARAM( "SdStyleSheet" ) );
+    return OUString( "SdStyleSheet" );
 }
 
 // --------------------------------------------------------------------
@@ -929,16 +929,16 @@ Sequence< OUString > SAL_CALL SdStyleSheet::getSupportedServiceNames() throw(Run
     Sequence< OUString > aNameSequence( 10 );
     OUString* pStrings = aNameSequence.getArray();
 
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.style.Style" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.FillProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.LineProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.ShadowProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.ConnectorProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.MeasureProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.style.ParagraphProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.style.CharacterProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.TextProperties" ) );
-    *pStrings++ = OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.Text" ) );
+    *pStrings++ = "com.sun.star.style.Style";
+    *pStrings++ = "com.sun.star.drawing.FillProperties";
+    *pStrings++ = "com.sun.star.drawing.LineProperties";
+    *pStrings++ = "com.sun.star.drawing.ShadowProperties";
+    *pStrings++ = "com.sun.star.drawing.ConnectorProperties";
+    *pStrings++ = "com.sun.star.drawing.MeasureProperties";
+    *pStrings++ = "com.sun.star.style.ParagraphProperties";
+    *pStrings++ = "com.sun.star.style.CharacterProperties";
+    *pStrings++ = "com.sun.star.drawing.TextProperties";
+    *pStrings++ = "com.sun.star.drawing.Text";
 
     return aNameSequence;
 }
@@ -1011,7 +1011,7 @@ void SAL_CALL SdStyleSheet::setParentStyle( const OUString& rParentName  ) throw
     SolarMutexGuard aGuard;
     throwIfDisposed();
 
-    if( rParentName.getLength() )
+    if( !rParentName.isEmpty() )
     {
         const SfxStyles& rStyles = mxPool->GetStyles();
 
@@ -1153,7 +1153,7 @@ Any SAL_CALL SdStyleSheet::getPropertyValue( const OUString& PropertyName ) thro
             if( nFamily == SD_STYLE_FAMILY_MASTERPAGE )
             {
                 const OUString aLayoutName( GetName() );
-                aAny <<= aLayoutName.copy( 0, aLayoutName.indexOf(OUString( RTL_CONSTASCII_USTRINGPARAM(SD_LT_SEPARATOR) ) ) );
+                aAny <<= aLayoutName.copy( 0, aLayoutName.indexOf(OUString( SD_LT_SEPARATOR) ) );
             }
             else
             {
