@@ -93,7 +93,7 @@ rtl::OUString InsertSeparator( OptimizerDialog& rOptimizerDialog, const OUString
     Sequence< rtl::OUString >   aNames( pNames, nCount );
     Sequence< Any >             aValues( pValues, nCount );
 
-    rOptimizerDialog.insertControlModel( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.UnoControlFixedLineModel" ) ),
+    rOptimizerDialog.insertControlModel( OUString( "com.sun.star.awt.UnoControlFixedLineModel"  ),
         rControlName, aNames, aValues );
     return rControlName;
 }
@@ -513,7 +513,7 @@ void OptimizerDialog::UpdateControlStatesPage2()
         aResolutionText = aResolutionItemList[ 2 ];
     else if ( getString( STR_IMAGE_RESOLUTION_3 ).getToken( 0, ';', nI3 ).toInt32() == nImageResolution )
         aResolutionText = aResolutionItemList[ 3 ];
-    if ( !aResolutionText.getLength() )
+    if ( aResolutionText.isEmpty() )
         aResolutionText = OUString::valueOf( nImageResolution );
 
     setControlProperty( TKGet( TK_RadioButton0Pg1 ), TKGet( TK_State ), Any( (sal_Int16)( bJPEGCompression != sal_True ) ) );
@@ -574,7 +574,7 @@ void OptimizerDialog::InitPage3()
         Reference< XShapes > xShapes( xDrawPages->getByIndex( i ), UNO_QUERY_THROW );
         for ( sal_Int32 j = 0; j < xShapes->getCount(); j++ )
         {
-            const OUString sOLE2Shape( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.OLE2Shape" ) );
+            const OUString sOLE2Shape( "com.sun.star.drawing.OLE2Shape"  );
             Reference< XShape > xShape( xShapes->getByIndex( j ), UNO_QUERY_THROW );
             if ( xShape->getShapeType() == sOLE2Shape )
                 nOLECount++;
@@ -606,7 +606,7 @@ static OUString ImpValueOfInMB( const sal_Int64& rVal, sal_Unicode nSeparator =
         aVal.setLength( nX + 2 );
         aVal[nX] = nSeparator;
     }
-    aVal.append( OUString(RTL_CONSTASCII_USTRINGPARAM(" MB")) );
+    aVal.append( OUString(" MB") );
     return aVal.makeStringAndClear();
 }
 
@@ -681,7 +681,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
             }
         }
     }
-    if ( aCustomShowName.getLength() )
+    if ( !aCustomShowName.isEmpty() )
     {
         std::vector< Reference< XDrawPage > > vNonUsedPageList;
         PageCollector::CollectNonCustomShowPages( mxController->getModel(), aCustomShowName, vNonUsedPageList );
@@ -689,7 +689,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
     }
     if ( GetConfigProperty( TK_DeleteHiddenSlides, sal_False ) )
     {
-        if ( aCustomShowName.getLength() )
+        if ( !aCustomShowName.isEmpty() )
         {
             std::vector< Reference< XDrawPage > > vUsedPageList;
             PageCollector::CollectCustomShowPages( mxController->getModel(), aCustomShowName, vUsedPageList );
@@ -698,7 +698,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
             {
                 Reference< XPropertySet > xPropSet( *aIter, UNO_QUERY_THROW );
                 sal_Bool bVisible = sal_True;
-                const OUString sVisible( RTL_CONSTASCII_USTRINGPARAM( "Visible" ) );
+                const OUString sVisible( "Visible"  );
                 if ( xPropSet->getPropertyValue( sVisible ) >>= bVisible )
                 {
                     if (!bVisible )
@@ -717,7 +717,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
                 Reference< XPropertySet > xPropSet( xDrawPage, UNO_QUERY_THROW );
 
                 sal_Bool bVisible = sal_True;
-                const OUString sVisible( RTL_CONSTASCII_USTRINGPARAM( "Visible" ) );
+                const OUString sVisible( "Visible"  );
                 if ( xPropSet->getPropertyValue( sVisible ) >>= bVisible )
                 {
                     if (!bVisible )
@@ -743,7 +743,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
     if ( nDeletedSlides > 1 )
     {
         OUString aStr( getString( STR_DELETE_SLIDES ) );
-        OUString aPlaceholder( RTL_CONSTASCII_USTRINGPARAM( "%SLIDES" ) );
+        OUString aPlaceholder( "%SLIDES"  );
         sal_Int32 i = aStr.indexOf( aPlaceholder, 0 );
         if ( i >= 0 )
             aStr = aStr.replaceAt( i, aPlaceholder.getLength(), OUString::valueOf( nDeletedSlides ) );
@@ -761,9 +761,9 @@ void OptimizerDialog::UpdateControlStatesPage4()
     if ( nGraphics > 1 )
     {
         OUString aStr( getString( STR_OPTIMIZE_IMAGES ) );
-        OUString aImagePlaceholder( RTL_CONSTASCII_USTRINGPARAM( "%IMAGES" ) );
-        OUString aQualityPlaceholder( RTL_CONSTASCII_USTRINGPARAM( "%QUALITY" ) );
-        OUString aResolutionPlaceholder( RTL_CONSTASCII_USTRINGPARAM( "%RESOLUTION" ) );
+        OUString aImagePlaceholder( "%IMAGES"  );
+        OUString aQualityPlaceholder( "%QUALITY"  );
+        OUString aResolutionPlaceholder( "%RESOLUTION"  );
         sal_Int32 i = aStr.indexOf( aImagePlaceholder, 0 );
         if ( i >= 0 )
             aStr = aStr.replaceAt( i, aImagePlaceholder.getLength(), OUString::valueOf( nGraphics ) );
@@ -789,7 +789,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
             Reference< XShapes > xShapes( xDrawPages->getByIndex( i ), UNO_QUERY_THROW );
             for ( sal_Int32 j = 0; j < xShapes->getCount(); j++ )
             {
-                const OUString sOLE2Shape( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.drawing.OLE2Shape" ) );
+                const OUString sOLE2Shape( "com.sun.star.drawing.OLE2Shape"  );
                 Reference< XShape > xShape( xShapes->getByIndex( j ), UNO_QUERY_THROW );
                 if ( xShape->getShapeType() == sOLE2Shape )
                     nOLEReplacements++;
@@ -798,7 +798,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
         if ( nOLEReplacements > 1 )
         {
             OUString aStr( getString( STR_CREATE_REPLACEMENT ) );
-            OUString aPlaceholder( RTL_CONSTASCII_USTRINGPARAM( "%OLE" ) );
+            OUString aPlaceholder( "%OLE"  );
             sal_Int32 i = aStr.indexOf( aPlaceholder, 0 );
             if ( i >= 0 )
                 aStr = aStr.replaceAt( i, aPlaceholder.getLength(), OUString::valueOf( nOLEReplacements ) );
@@ -835,7 +835,7 @@ void OptimizerDialog::UpdateControlStatesPage4()
     }
     sal_Unicode nSeparator = '.';
     OUString aStr( getString( STR_FILESIZESEPARATOR ) );
-    if ( aStr.getLength() )
+    if ( !aStr.isEmpty() )
         nSeparator = aStr[ 0 ];
     setControlProperty( TKGet( TK_FixedText7Pg4 ), TKGet( TK_Label ), Any( ImpValueOfInMB( nCurrentFileSize, nSeparator ) ) );
     setControlProperty( TKGet( TK_FixedText8Pg4 ), TKGet( TK_Label ), Any( ImpValueOfInMB( nEstimatedFileSize, nSeparator ) ) );
@@ -870,7 +870,7 @@ void OptimizerDialog::InitPage4()
         Sequence< rtl::OUString >   aNames( pNames, nCount );
         Sequence< Any >             aValues( pValues, nCount );
 
-        Reference< XMultiPropertySet > xMultiPropertySet( insertControlModel( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.awt.UnoControlProgressBarModel" ) ),
+        Reference< XMultiPropertySet > xMultiPropertySet( insertControlModel( OUString( "com.sun.star.awt.UnoControlProgressBarModel"  ),
             TKGet( TK_Progress ), aNames, aValues ), UNO_QUERY );
     }
     Reference< XTextListener > xTextListener;
@@ -917,7 +917,7 @@ void OptimizerDialog::InitPage4()
         if ( i == rList.size() )
             aSettingsName = aTemp;
     }
-    while( !aSettingsName.getLength() );
+    while( aSettingsName.isEmpty() );
 
     setControlProperty( TKGet( TK_ComboBox0Pg4 ), TKGet( TK_Text ), Any( aSettingsName ) );
     setControlProperty( TKGet( TK_RadioButton0Pg4 ), TKGet( TK_Enabled ), Any( !mbIsReadonly ) );
