@@ -144,7 +144,7 @@ static VBAConstantNameMap s_aRegisteredVBAConstants;
     if( xProps.is() ) try
     {
         ::rtl::OUString aConstName;
-        xProps->getPropertyValue( ::rtl::OUString( "VBAGlobalConstantName"  ) ) >>= aConstName;
+        xProps->getPropertyValue( ::rtl::OUString( "ThisVBADocObj"  ) ) >>= aConstName;
         return ::rtl::OUStringToOString( aConstName, RTL_TEXTENCODING_ASCII_US );
     }
     catch (const uno::Exception&) // not supported
