@@ -647,8 +647,8 @@ void SmNode::DumpAsDot(std::ostream &out, String* label, int number, int& id, in
     //Dump subnodes
     int myid = id;
     const SmNode *pNode;
-    USHORT nSize = GetNumSubNodes();
-    for (USHORT i = 0; i < nSize;  i++)
+    sal_uInt16 nSize = GetNumSubNodes();
+    for (sal_uInt16 i = 0; i < nSize;  i++)
         if (NULL != (pNode = GetSubNode(i)))
             pNode->DumpAsDot(out, NULL, i, ++id, myid);
 
@@ -2824,46 +2824,46 @@ void SmAttributNode::CreateTextFromNode(String &rText)
             case 0xAF: // MACRON
                 APPEND(rText,"overline ");
                 break;
-            case 0x2d9: // DOT ABOVE
+            case MS_DOT: // DOT ABOVE
                 APPEND(rText,"dot ");
                 break;
             case 0x2dc: // SMALL TILDE
                 APPEND(rText,"widetilde ");
                 break;
-            case 0xA8: // DIAERESIS
+            case MS_DDOT: // DIAERESIS
                 APPEND(rText,"ddot ");
                 break;
             case 0xE082:
                 break;
             case 0xE09B:
-            case 0x20DB: // COMBINING THREE DOTS ABOVE
+            case MS_DDDOT: // COMBINING THREE DOTS ABOVE
                 APPEND(rText,"dddot ");
                 break;
-            case 0x301: // COMBINING ACUTE ACCENT
+            case MS_ACUTE: // COMBINING ACUTE ACCENT
                 APPEND(rText,"acute ");
                 break;
-            case 0x300: // COMBINING GRAVE ACCENT
+            case MS_GRAVE: // COMBINING GRAVE ACCENT
                 APPEND(rText,"grave ");
                 break;
-            case 0x30C: // COMBINING CARON
+            case MS_CHECK: // COMBINING CARON
                 APPEND(rText,"check ");
                 break;
-            case 0x306: // COMBINING BREVE
+            case MS_BREVE: // COMBINING BREVE
                 APPEND(rText,"breve ");
                 break;
-            case 0x30A: // COMBINING RING ABOVE
+            case MS_CIRCLE: // COMBINING RING ABOVE
                 APPEND(rText,"circle ");
                 break;
-            case 0x20D7: // COMBINING RIGHT ARROW ABOVE
+            case MS_VEC: // COMBINING RIGHT ARROW ABOVE
                 APPEND(rText,"vec ");
                 break;
-            case 0x303: // COMBINING TILDE
+            case MS_TILDE: // COMBINING TILDE
                 APPEND(rText,"tilde ");
                 break;
-            case 0x302: // COMBINING CIRCUMFLEX ACCENT
+            case MS_HAT: // COMBINING CIRCUMFLEX ACCENT
                 APPEND(rText,"hat ");
                 break;
-            case 0x304: // COMBINING MACRON
+            case MS_BAR: // COMBINING MACRON
                 APPEND(rText,"bar ");
                 break;
             default:
