@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-#include <tools/debug.hxx>
 #include <tools/urlobj.hxx>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/xml/sax/XDocumentHandler.hpp>
@@ -51,7 +50,6 @@
 #include "xmloff/HatchStyle.hxx"
 #include "xmloff/ImageStyle.hxx"
 #include "xmloff/MarkerStyle.hxx"
-#include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/embed/XTransactedObject.hpp>
 #include <comphelper/processfactory.hxx>
 #include <unotools/streamwrap.hxx>
@@ -265,7 +263,7 @@ bool SvxXMLXTableExportComponent::save(
                 xSubStorage = ::comphelper::OStorageHelper::GetStorageFromURL( rURL, eCreate );
             else
             {
-                pMedium = new SfxMedium( rURL, STREAM_WRITE | STREAM_TRUNC, sal_True );
+                pMedium = new SfxMedium( rURL, STREAM_WRITE | STREAM_TRUNC );
                 pMedium->IsRemote();
 
                 SvStream* pStream = pMedium->GetOutStream();
