@@ -1325,10 +1325,16 @@ void SwDoc::UpdateExpFlds( SwTxtFld* pUpdtFld, bool bUpdRefFlds )
                     // This section will be hidden, but it wasn't before
                     if (nShownSections == 1)
                     {
-                        // This would be the last section, so set its condition to false, and avoid hiding it.
-                        rtl::OUString aCond(RTL_CONSTASCII_USTRINGPARAM("0"));
-                        pSect->SetCondition(aCond);
-                        bHide = false;
+                        // Is the last node part of a section?
+                        SwPaM aPam(GetNodes());
+                        aPam.Move(fnMoveForward, fnGoDoc);
+                        if (aPam.Start()->nNode.GetNode().StartOfSectionNode()->IsSectionNode())
+                        {
+                            // This would be the last section, so set its condition to false, and avoid hiding it.
+                            rtl::OUString aCond(RTL_CONSTASCII_USTRINGPARAM("0"));
+                            pSect->SetCondition(aCond);
+                            bHide = false;
+                        }
                     }
                     nShownSections--;
                 }
