@@ -35,6 +35,8 @@
 #include <com/sun/star/i18n/ScriptType.hdl>
 
 #include <docsh.hxx>
+#include <viewsh.hxx>
+#include <viewopt.hxx>
 #include <ndtxt.hxx>
 #include <fmtpdsc.hxx>
 #include <section.hxx>
@@ -60,6 +62,7 @@
 #include "ww8par.hxx"
 
 #include <comphelper/string.hxx>
+#include <rtl/oustringostreaminserter.hxx>
 #include <svtools/rtfkeywd.hxx>
 #include <unotools/configmgr.hxx>
 
@@ -81,7 +84,7 @@ using sw::mark::IMark;
 #if defined(UNX)
 const sal_Char RtfExport::sNewLine = '\012';
 #else
-const sal_Char RtfExport::sNewLine[] = "\015\012";
+const sal_Char* const RtfExport::sNewLine = "\015\012";
 #endif
 
 // the default text encoding for the export, if it doesn't fit unicode will
@@ -139,7 +142,7 @@ bool RtfExport::CollapseScriptsforWordOk( sal_uInt16 nScript, sal_uInt16 nWhich
 
 void RtfExport::AppendBookmarks( const SwTxtNode& rNode, xub_StrLen nAktPos, xub_StrLen nLen )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     std::vector< OUString > aStarts;
     std::vector< OUString > aEnds;
@@ -148,7 +151,7 @@ void RtfExport::AppendBookmarks( const SwTxtNode& rNode, xub_StrLen nAktPos, xub
     if ( GetBookmarks( rNode, nAktPos, nAktPos + nLen, aMarks ) )
     {
         for ( IMarkVector::const_iterator it = aMarks.begin(), end = aMarks.end();
-                it < end; ++it )
+                it != end; ++it )
         {
             IMark* pMark = (*it);
             xub_StrLen nStart = pMark->GetMarkStart().nContent.GetIndex();
@@ -167,7 +170,7 @@ void RtfExport::AppendBookmarks( const SwTxtNode& rNode, xub_StrLen nAktPos, xub
 
 void RtfExport::AppendBookmark( const OUString& rName, bool /*bSkip*/ )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     std::vector<OUString> aStarts;
     std::vector<OUString> aEnds;
@@ -180,7 +183,7 @@ void RtfExport::AppendBookmark( const OUString& rName, bool /*bSkip*/ )
 
 void RtfExport::WriteChar( sal_Unicode )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     /* WriteChar() has nothing to do for rtf. */
 }
@@ -197,8 +200,8 @@ static bool IsExportNumRule( const SwNumRule& rRule, sal_uInt8* pEnd = 0 )
 
     for( nLvl = 0; nLvl < nEnd; ++nLvl )
         if( SVX_NUM_NUMBER_NONE != ( pNFmt = &rRule.Get( nLvl ))
-                ->GetNumberingType() || pNFmt->GetPrefix().Len() ||
-                (pNFmt->GetSuffix().Len() && pNFmt->GetSuffix() != aDotStr ))
+                ->GetNumberingType() || !pNFmt->GetPrefix().isEmpty() ||
+                (!pNFmt->GetSuffix().isEmpty() && !pNFmt->GetSuffix().equals(aDotStr)) )
             break;
 
     if( pEnd )
@@ -210,11 +213,11 @@ void RtfExport::BuildNumbering()
 {
     const SwNumRuleTbl& rListTbl = pDoc->GetNumRuleTbl();
 
-    for( sal_uInt16 n = rListTbl.Count()+1; n; )
+    for( sal_uInt16 n = rListTbl.size()+1; n; )
     {
         SwNumRule* pRule;
         --n;
-        if( n == rListTbl.Count() )
+        if( n == rListTbl.size() )
             pRule = (SwNumRule*)pDoc->GetOutlineNumRule();
         else
         {
@@ -230,7 +233,7 @@ void RtfExport::BuildNumbering()
 
 void RtfExport::WriteNumbering()
 {
-    OSL_TRACE("%s start", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " start");
 
     if ( !pUsedNumTbl )
         return; // no numbering is used
@@ -243,12 +246,12 @@ void RtfExport::WriteNumbering()
     NumberingDefinitions();
     Strm() << '}';
 
-    OSL_TRACE("%s end", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " end");
 }
 
 void RtfExport::WriteRevTab()
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     int nRevAuthors = pDoc->GetRedlineTbl().Count();
 
@@ -282,7 +285,7 @@ void RtfExport::WriteRevTab()
 void RtfExport::WriteHeadersFooters( sal_uInt8 nHeadFootFlags,
         const SwFrmFmt& rFmt, const SwFrmFmt& rLeftFmt, const SwFrmFmt& rFirstPageFmt, sal_uInt8 /*nBreakCode*/ )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     // headers
     if ( nHeadFootFlags & nsHdFtFlags::WW8_HEADER_EVEN )
@@ -307,19 +310,19 @@ void RtfExport::WriteHeadersFooters( sal_uInt8 nHeadFootFlags,
 
 void RtfExport::OutputField( const SwField* pFld, ww::eField eFldType, const String& rFldCmd, sal_uInt8 nMode )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     m_pAttrOutput->WriteField_Impl( pFld, eFldType, rFldCmd, nMode );
 }
 
 void RtfExport::WriteFormData( const ::sw::mark::IFieldmark& /*rFieldmark*/ )
 {
-    OSL_TRACE("TODO: %s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", "TODO: " << OSL_THIS_FUNC);
 }
 
 void RtfExport::WriteHyperlinkData( const ::sw::mark::IFieldmark& /*rFieldmark*/ )
 {
-    OSL_TRACE("TODO: %s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", "TODO: " << OSL_THIS_FUNC);
 }
 
 void RtfExport::DoComboBox(const rtl::OUString& /*rName*/,
@@ -328,14 +331,14 @@ void RtfExport::DoComboBox(const rtl::OUString& /*rName*/,
                              const rtl::OUString& /*rSelected*/,
                              uno::Sequence<rtl::OUString>& /*rListItems*/)
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     // this is handled in RtfAttributeOutput::OutputFlyFrame_Impl
 }
 
 void RtfExport::DoFormText(const SwInputField* pFld )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     ::rtl::OUString sResult = pFld->ExpandField(pDoc->IsClipBoard());
     ::rtl::OUString sHelp( pFld->GetHelp() );
@@ -343,18 +346,18 @@ void RtfExport::DoFormText(const SwInputField* pFld )
     ::rtl::OUString sStatus = pFld->GetToolTip();
     m_pAttrOutput->RunText().append("{" OOO_STRING_SVTOOLS_RTF_FIELD "{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_FLDINST "{ FORMTEXT }");
     m_pAttrOutput->RunText().append("{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_FORMFIELD " {" OOO_STRING_SVTOOLS_RTF_FFTYPE "0" );
-    if( sHelp.getLength() )
+    if( !sHelp.isEmpty() )
         m_pAttrOutput->RunText().append( OOO_STRING_SVTOOLS_RTF_FFOWNHELP );
-    if( sStatus.getLength() )
+    if( !sStatus.isEmpty() )
         m_pAttrOutput->RunText().append( OOO_STRING_SVTOOLS_RTF_FFOWNSTAT );
     m_pAttrOutput->RunText().append( OOO_STRING_SVTOOLS_RTF_FFTYPETXT  "0" );
 
-    if( sName.getLength() )
+    if( !sName.isEmpty() )
         m_pAttrOutput->RunText().append( "{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_FFNAME " ").append( OutString( sName, eDefaultEncoding )).append( "}" );
-    if( sHelp.getLength() )
+    if( !sHelp.isEmpty() )
         m_pAttrOutput->RunText().append( "{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_FFHELPTEXT " ").append( OutString( sHelp, eDefaultEncoding )).append( "}" );
     m_pAttrOutput->RunText().append( "{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_FFDEFTEXT " ").append( OutString( sResult, eDefaultEncoding )).append( "}" );
-    if( sStatus.getLength() )
+    if( !sStatus.isEmpty() )
         m_pAttrOutput->RunText().append( "{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_FFSTATTEXT " ").append( OutString( sStatus, eDefaultEncoding )).append( "}");
     m_pAttrOutput->RunText().append( "}}}{" OOO_STRING_SVTOOLS_RTF_FLDRSLT " " );
     m_pAttrOutput->RunText().append( OutString( sResult, eDefaultEncoding )).append( "}}" );
@@ -362,7 +365,7 @@ void RtfExport::DoFormText(const SwInputField* pFld )
 
 sal_uLong RtfExport::ReplaceCr( sal_uInt8 )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     // Completely unused for Rtf export... only here for code sharing
     // purpose with binary export
@@ -379,22 +382,22 @@ void RtfExport::WriteFonts()
 
 void RtfExport::WriteStyles()
 {
-    OSL_TRACE("%s start", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " start");
     pStyles->OutputStylesTable();
-    OSL_TRACE("%s end", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " end");
 }
 
 void RtfExport::WriteMainText()
 {
-    OSL_TRACE("%s start", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " start");
     pCurPam->GetPoint()->nNode = pDoc->GetNodes().GetEndOfContent().StartOfSectionNode()->GetIndex();
     WriteText();
-    OSL_TRACE("%s end", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " end");
 }
 
 void RtfExport::WriteInfo()
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
     Strm() << '{' << OOO_STRING_SVTOOLS_RTF_INFO;
 
     SwDocShell *pDocShell(pDoc->GetDocShell());
@@ -430,7 +433,7 @@ void RtfExport::WriteInfo()
 
 void RtfExport::WritePageDescTable()
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     // Write page descriptions (page styles)
     sal_uInt16 nSize = pDoc->GetPageDescCnt();
@@ -503,6 +506,13 @@ void RtfExport::ExportDocument_Impl()
     WriteInfo();
     // Default TabSize
     Strm() << m_pAttrOutput->m_aTabStop.makeStringAndClear().getStr() << sNewLine;
+    // Zoom
+    ViewShell *pViewShell(pDoc->GetCurrentViewShell());
+    if (pViewShell && pViewShell->GetViewOptions()->GetZoomType() == SVX_ZOOM_PERCENT)
+    {
+        Strm() << OOO_STRING_SVTOOLS_RTF_VIEWSCALE;
+        OutULong(pViewShell->GetViewOptions()->GetZoom());
+    }
     // Page description
     WritePageDescTable();
 
@@ -687,7 +697,7 @@ void RtfExport::PrepareNewPageDesc( const SfxItemSet* pSet,
         const SwNode& rNd, const SwFmtPageDesc* pNewPgDescFmt,
         const SwPageDesc* pNewPgDesc )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
     const SwSectionFmt* pFmt = GetSectionFormat( rNd );
     const sal_uLong nLnNm = GetSectionLineNo( pSet, rNd );
 
@@ -707,7 +717,7 @@ bool RtfExport::DisallowInheritingOutlineNumbering( const SwFmt& rFmt )
 {
     bool bRet( false );
 
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     if (SFX_ITEM_SET != rFmt.GetItemState(RES_PARATR_NUMRULE, false))
     {
@@ -716,7 +726,7 @@ bool RtfExport::DisallowInheritingOutlineNumbering( const SwFmt& rFmt )
             if (((const SwTxtFmtColl*)pParent)->IsAssignedToListLevelOfOutlineStyle())
             {
                 // Level 9 disables the outline
-                Strm() << OOO_STRING_SVTOOLS_RTF_LEVEL << 9;
+                Strm() << OOO_STRING_SVTOOLS_RTF_LEVEL << sal_Int32(9);
 
                 bRet = true;
             }
@@ -728,21 +738,21 @@ bool RtfExport::DisallowInheritingOutlineNumbering( const SwFmt& rFmt )
 
 void RtfExport::OutputGrfNode( const SwGrfNode& )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     /* noop, see RtfAttributeOutput::FlyFrameGraphic */
 }
 
 void RtfExport::OutputOLENode( const SwOLENode& )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     /* noop, see RtfAttributeOutput::FlyFrameOLE */
 }
 
 void RtfExport::OutputLinkedOLE( const rtl::OUString& )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 }
 
 void RtfExport::OutputTextNode( const SwTxtNode& rNode )
@@ -753,7 +763,7 @@ void RtfExport::OutputTextNode( const SwTxtNode& rNode )
 
 void RtfExport::AppendSection( const SwPageDesc* pPageDesc, const SwSectionFmt* pFmt, sal_uLong nLnNum )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
 
     m_pSections->AppendSection( pPageDesc, pFmt, nLnNum );
     AttrOutput().SectionBreak( msword::PageBreak, m_pSections->CurrentSectionInfo() );
@@ -874,27 +884,13 @@ OString RtfExport::OutChar(sal_Unicode c, int *pUCMode, rtl_TextEncoding eDestEn
             if (c >= ' ' && c <= '~')
                 aBuf.append((sal_Char)c);
             else {
-                //If we can't convert to the dest encoding, or if
-                //its an uncommon multibyte sequence which most
-                //readers won't be able to handle correctly, then
-                //If we can't convert to the dest encoding, then
-                //export as unicode
                 OUString sBuf(&c, 1);
                 OString sConverted;
-                sal_uInt32 nFlags =
-                    RTL_UNICODETOTEXT_FLAGS_UNDEFINED_ERROR |
-                    RTL_UNICODETOTEXT_FLAGS_INVALID_ERROR;
-                bool bWriteAsUnicode = !(sBuf.convertToString(&sConverted,
-                            eDestEnc, nFlags))
-                    || (RTL_TEXTENCODING_UTF8==eDestEnc); // #i43933# do not export UTF-8 chars in RTF;
-                if (bWriteAsUnicode)
-                    sBuf.convertToString(&sConverted,
-                            eDestEnc, OUSTRING_TO_OSTRING_CVTFLAGS);
+                sBuf.convertToString(&sConverted, eDestEnc, OUSTRING_TO_OSTRING_CVTFLAGS);
                 const sal_Int32 nLen = sConverted.getLength();
 
-                if (bWriteAsUnicode && pUCMode)
+                if (pUCMode)
                 {
-                    // then write as unicode - character
                     if (*pUCMode != nLen)
                     {
                         aBuf.append("\\uc");
@@ -931,8 +927,7 @@ OString RtfExport::OutChar(sal_Unicode c, int *pUCMode, rtl_TextEncoding eDestEn
 
 OString RtfExport::OutString(const String &rStr, rtl_TextEncoding eDestEnc)
 {
-    OSL_TRACE("%s, rStr = '%s'", OSL_THIS_FUNC,
-            OUStringToOString( OUString( rStr ), eDestEnc ).getStr());
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << ", rStr = '" << OUString(rStr) << "'");
     OStringBuffer aBuf;
     int nUCMode = 1;
     for (xub_StrLen n = 0; n < rStr.Len(); ++n)
@@ -959,7 +954,7 @@ sal_uInt16 RtfExport::GetColor( const Color& rColor ) const
 {
     for (RtfColorTbl::const_iterator it=m_aColTbl.begin() ; it != m_aColTbl.end(); ++it )
         if ((*it).second == rColor) {
-            OSL_TRACE("%s returning %d (%d,%d,%d)", OSL_THIS_FUNC, (*it).first, rColor.GetRed(), rColor.GetGreen(), rColor.GetBlue());
+            SAL_INFO("sw.rtf", OSL_THIS_FUNC << " returning " << (*it).first << " (" << rColor.GetRed() << "," << rColor.GetGreen() << "," << rColor.GetBlue() << ")");
             return (*it).first;
         }
     OSL_FAIL( "No such Color in m_aColTbl!" );
@@ -1159,7 +1154,7 @@ const String* RtfExport::GetRedline( sal_uInt16 nId )
 
 void RtfExport::OutPageDescription( const SwPageDesc& rPgDsc, sal_Bool bWriteReset, sal_Bool bCheckForFirstPage )
 {
-    OSL_TRACE("%s start", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " start");
     const SwPageDesc *pSave = pAktPageDesc;
 
     pAktPageDesc = &rPgDsc;
@@ -1209,7 +1204,7 @@ void RtfExport::OutPageDescription( const SwPageDesc& rPgDsc, sal_Bool bWriteRes
     AttrOutput().SectionPageNumbering(pAktPageDesc->GetNumType().GetNumberingType(), 0);
 
     pAktPageDesc = pSave;
-    OSL_TRACE("%s end", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " end");
 }
 
 void RtfExport::WriteHeaderFooter(const SfxPoolItem& rItem, bool bHeader)
@@ -1227,7 +1222,7 @@ void RtfExport::WriteHeaderFooter(const SfxPoolItem& rItem, bool bHeader)
             return;
     }
 
-    OSL_TRACE("%s start", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " start");
 
     const sal_Char* pStr = (bHeader ? OOO_STRING_SVTOOLS_RTF_HEADER : OOO_STRING_SVTOOLS_RTF_FOOTER);
     /* is this a title page? */
@@ -1240,16 +1235,16 @@ void RtfExport::WriteHeaderFooter(const SfxPoolItem& rItem, bool bHeader)
     WriteHeaderFooterText(pAktPageDesc->GetMaster(), bHeader);
     Strm() << '}';
 
-    OSL_TRACE("%s end", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " end");
 }
 
 void RtfExport::WriteHeaderFooter(const SwFrmFmt& rFmt, bool bHeader, const sal_Char* pStr, bool bTitlepg)
 {
-    OSL_TRACE("%s start", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " start");
 
     m_pAttrOutput->WriteHeaderFooter_Impl( rFmt, bHeader, pStr, bTitlepg );
 
-    OSL_TRACE("%s end", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC << " end");
 }
 
 /// Glue class to call RtfExport as an internal filter, needed by copy&paste support.
@@ -1266,7 +1261,7 @@ class SwRTFWriter : public Writer
 
 SwRTFWriter::SwRTFWriter( const String& rFltName, const String & rBaseURL )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
     SetBaseURL( rBaseURL );
     // export outline nodes, only (send outline to clipboard/presentation)
     m_bOutOutlineOnly = 'O' == rFltName.GetChar( 0 );
@@ -1277,7 +1272,7 @@ SwRTFWriter::~SwRTFWriter()
 
 sal_uLong SwRTFWriter::WriteStream()
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
     RtfExport aExport( NULL, pDoc, new SwPaM( *pCurPam->End(), *pCurPam->Start() ), pCurPam, this, m_bOutOutlineOnly );
     aExport.ExportDocument( true );
     return 0;
@@ -1285,7 +1280,7 @@ sal_uLong SwRTFWriter::WriteStream()
 
 extern "C" SAL_DLLPUBLIC_EXPORT void SAL_CALL ExportRTF( const String& rFltName, const String& rBaseURL, WriterRef& xRet )
 {
-    OSL_TRACE("%s", OSL_THIS_FUNC);
+    SAL_INFO("sw.rtf", OSL_THIS_FUNC);
     xRet = new SwRTFWriter( rFltName, rBaseURL );
 }
 
