@@ -49,7 +49,7 @@
 
 using namespace ::com::sun::star;
 
-extern sal_Bool bNoInterrupt;       // in mainwn.cxx
+extern bool bNoInterrupt;       // in mainwn.cxx
 
 #define MINMOVE ((sal_uInt16)m_pSh->GetOut()->PixelToLogic(Size(m_pSh->GetDrawView()->GetMarkHdlSizePixel()/2,0)).Width())
 
@@ -121,7 +121,7 @@ sal_Bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
     {
         if (IsCreateObj() && (eHit == SDRHIT_UNMARKEDOBJECT || eHit == SDRHIT_NONE || m_pSh->IsDrawCreate()))
         {
-            bNoInterrupt = sal_True;
+            bNoInterrupt = true;
             m_pWin->CaptureMouse();
 
             m_aStartPos = m_pWin->PixelToLogic(rMEvt.GetPosPixel());
@@ -147,7 +147,7 @@ sal_Bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
                 /******************************************************************
                 * Handle draggen
                 ******************************************************************/
-                bNoInterrupt = sal_True;
+                bNoInterrupt = true;
                 bReturn = pSdrView->BegDragObj(m_aStartPos, (OutputDevice*) NULL, aVEvt.pHdl);
                 m_pWin->SetDrawAction(sal_True);
             }
@@ -156,7 +156,7 @@ sal_Bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
                 /******************************************************************
                 * Klebepunkt einfuegen
                 ******************************************************************/
-                bNoInterrupt = sal_True;
+                bNoInterrupt = true;
                 bReturn = pSdrView->BegInsObjPoint(m_aStartPos, rMEvt.IsMod1());
                 m_pWin->SetDrawAction(sal_True);
             }
@@ -207,7 +207,7 @@ sal_Bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
 
                     if (pHdl)
                     {
-                        bNoInterrupt = sal_True;
+                        bNoInterrupt = true;
                         pSdrView->MarkPoint(*pHdl);
                     }
                 }
@@ -222,12 +222,12 @@ sal_Bool SwDrawBase::MouseButtonDown(const MouseEvent& rMEvt)
                     if (pSdrView->HasMarkablePoints())
                         pSdrView->UnmarkAllPoints();
 
-                    bNoInterrupt = sal_False;
+                    bNoInterrupt = false;
                     // Drag im edtwin verwenden
                     return sal_False;
                 }
 
-                bNoInterrupt = sal_True;
+                bNoInterrupt = true;
 
                 if (m_pSh->IsObjSelected())
                 {
@@ -523,7 +523,7 @@ void SwDrawBase::Deactivate()
     m_pWin->SetDrawAction(sal_False);
 
     m_pWin->ReleaseMouse();
-    bNoInterrupt = sal_False;
+    bNoInterrupt = false;
 
     if(m_pWin->GetApplyTemplate())
         m_pWin->SetApplyTemplate(SwApplyTemplate());
