@@ -521,21 +521,6 @@ void MultiSelection::Remove( long nIndex )
 
 // -----------------------------------------------------------------------
 
-void MultiSelection::Append( long nCount )
-{
-    long nPrevLast = aTotRange.Max();
-    aTotRange.Max() += nCount;
-    if ( bSelectNew )
-    {
-        nSelCount += nCount;
-        aSels.push_back( new Range( nPrevLast+1, nPrevLast + nCount ) );
-        if ( aSels.size() > 1 )
-            ImplMergeSubSelections( aSels.size() - 2, aSels.size() );
-    }
-}
-
-// -----------------------------------------------------------------------
-
 long MultiSelection::ImplFwdUnselected()
 {
     if ( !bCurValid )
@@ -554,23 +539,6 @@ long MultiSelection::ImplFwdUnselected()
 
 // -----------------------------------------------------------------------
 
-long MultiSelection::ImplBwdUnselected()
-{
-    if ( !bCurValid )
-        return SFX_ENDOFSELECTION;
-
-    if ( aSels[ nCurSubSel ]->Max() < nCurIndex )
-        return nCurIndex;
-
-    nCurIndex = aSels[ nCurSubSel-- ]->Min() - 1;
-    if ( nCurIndex >= 0 )
-        return nCurIndex;
-    else
-        return SFX_ENDOFSELECTION;
-}
-
-// -----------------------------------------------------------------------
-
 long MultiSelection::FirstSelected( sal_Bool bInverse )
 {
     bInverseCur = bInverse;
@@ -637,36 +605,6 @@ long MultiSelection::NextSelected()
 
 // -----------------------------------------------------------------------
 
-long MultiSelection::PrevSelected()
-{
-    if ( !bCurValid )
-        return SFX_ENDOFSELECTION;
-
-    if ( bInverseCur )
-    {
-        --nCurIndex;
-        return ImplBwdUnselected();
-    }
-    else
-    {
-        // is the previous index in the current sub selection too?
-        if ( nCurIndex > aSels[ nCurSubSel ]->Min() )
-            return --nCurIndex;
-
-        // are there previous sub selections?
-        if ( nCurSubSel > 0 )
-        {
-            --nCurSubSel;
-            return nCurIndex = aSels[ nCurSubSel ]->Max();
-        }
-
-        // we are at the beginning!
-        return SFX_ENDOFSELECTION;
-    }
-}
-
-// -----------------------------------------------------------------------
-
 void MultiSelection::SetTotalRange( const Range& rTotRange )
 {
     aTotRange = rTotRange;
