@@ -29,6 +29,8 @@
 
 #include <boost/bind.hpp>
 
+#include "officecfg/Office/Common.hxx"
+
 #include "vcl/print.hxx"
 #include <sal/macros.h>
 
@@ -321,7 +323,8 @@ sal_uLong AquaSalInfoPrinter::GetCapabilities( const ImplJobSetup*, sal_uInt16 i
         case PRINTER_CAPABILITIES_SETPAPER:
             return 1;
         case PRINTER_CAPABILITIES_EXTERNALDIALOG:
-            return useSystemPrintDialog() ? 1 : 0;
+            return officecfg::Office::Common::Misc::UseSystemPrintDialog::get()
+                ? 1 : 0;
         case PRINTER_CAPABILITIES_PDF:
             return 1;
         case PRINTER_CAPABILITIES_USEPULLMODEL:
@@ -370,7 +373,7 @@ static Size getPageSize( vcl::PrinterController& i_rController, sal_Int32 i_nPag
     uno::Sequence< PropertyValue > aPageParms( i_rController.getPageParameters( i_nPage ) );
     for( sal_Int32 nProperty = 0, nPropertyCount = aPageParms.getLength(); nProperty < nPropertyCount; ++nProperty )
     {
-        if( aPageParms[ nProperty ].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "PageSize" ) ) )
+        if ( aPageParms[ nProperty ].Name == "PageSize" )
         {
             awt::Size aSize;
             aPageParms[ nProperty].Value >>= aSize;
@@ -516,7 +519,10 @@ sal_Bool AquaSalInfoPrinter::StartJob( const rtl::OUString* i_pFileName,
             if( pPrintOperation )
             {
                 NSObject* pReleaseAfterUse = nil;
-                bool bShowPanel = (! i_rController.isDirectPrint() && useSystemPrintDialog() && i_rController.isShowDialogs() );
+                bool bShowPanel = !i_rController.isDirectPrint()
+                    && (officecfg::Office::Common::Misc::UseSystemPrintDialog::
+                        get())
+                    && i_rController.isShowDialogs();
                 [pPrintOperation setShowsPrintPanel: bShowPanel ? YES : NO ];
                 [pPrintOperation setShowsProgressPanel: bShowProgressPanel ? YES : NO];
 
