@@ -240,7 +240,7 @@ sal_Bool IosSalFrame::PostEvent( void *pData )
 }
 
 // -----------------------------------------------------------------------
-void IosSalFrame::SetTitle(const XubString& /* rTitle */)
+void IosSalFrame::SetTitle(const rtl::OUString& /* rTitle */)
 {
 }
 
@@ -502,8 +502,8 @@ sal_Bool IosSalFrame::GetWindowState( SalFrameState* pState )
                      SAL_FRAMESTATE_MASK_HEIGHT            |
                      SAL_FRAMESTATE_MASK_STATE;
 
-    CGRect aStateRect = [mpWindow frame];
 #if 0 // ???
+    CGRect aStateRect = [mpWindow frame];
     aStateRect = [UIWindow contentRectForFrameRect: aStateRect styleMask: mnStyleMask];
     CocoaTouchToVCL( aStateRect );
     pState->mnX         = long(aStateRect.origin.x);
@@ -617,7 +617,7 @@ void IosSalFrame::EndExtTextInput( sal_uInt16 )
 
 // -----------------------------------------------------------------------
 
-XubString IosSalFrame::GetKeyName( sal_uInt16 nKeyCode )
+rtl::OUString IosSalFrame::GetKeyName( sal_uInt16 nKeyCode )
 {
     static std::map< sal_uInt16, rtl::OUString > aKeyMap;
     if( aKeyMap.empty() )
@@ -704,13 +704,6 @@ XubString IosSalFrame::GetKeyName( sal_uInt16 nKeyCode )
 
 // -----------------------------------------------------------------------
 
-XubString IosSalFrame::GetSymbolKeyName( const XubString&, sal_uInt16 nKeyCode )
-{
-    return GetKeyName( nKeyCode );
-}
-
-// -----------------------------------------------------------------------
-
 void IosSalFrame::getResolution( long& o_rDPIX, long& o_rDPIY )
 {
     if( ! mpGraphics )
@@ -742,7 +735,6 @@ void IosSalFrame::UpdateSettings( AllSettings& rSettings )
     aStyleSettings.SetDialogColor( aBackgroundColor );
     aStyleSettings.SetLightBorderColor( aBackgroundColor );
     Color aShadowColor( aStyleSettings.GetShadowColor() );
-    aStyleSettings.SetDarkShadowColor( aShadowColor );
     aShadowColor.IncreaseLuminance( 32 );
     aStyleSettings.SetShadowColor( aShadowColor );
 
@@ -812,8 +804,8 @@ void IosSalFrame::SetPosSize(long /*nX*/, long /*nY*/, long /*nWidth*/, long /*n
         nEvent = (nEvent == SALEVENT_MOVE) ? SALEVENT_MOVERESIZE : SALEVENT_RESIZE;
     }
 
-    CGRect aFrameRect = [mpWindow frame];
 #if 0 // ???
+    CGRect aFrameRect = [mpWindow frame];
     CGRect aContentRect = [NSWindow contentRectForFrameRect: aFrameRect styleMask: mnStyleMask];
 
     // position is always relative to parent frame
@@ -965,11 +957,6 @@ void IosSalFrame::SetBackgroundBitmap( SalBitmap* )
     //TODO: implement
 }
 
-SalBitmap* IosSalFrame::SnapShot()
-{
-    return mpGraphics ? mpGraphics->getBitmap( 0, 0, maGeometry.nWidth, maGeometry.nHeight ) : NULL;
-}
-
 SalFrame* IosSalFrame::GetParent() const
 {
     return mpParent;
@@ -1003,7 +990,7 @@ void IosSalFrame::UpdateFrameGeometry()
         maScreenRect = [pScreen frame];
         NSArray* pScreens = [NSScreen screens];
         if( pScreens )
-            maGeometry.nScreenNumber = [pScreens indexOfObject: pScreen];
+            maGeometry.nDisplayScreenNumber = [pScreens indexOfObject: pScreen];
     }
 
     CGRect aFrameRect = [mpWindow frame];
