@@ -26,9 +26,6 @@
  *
  ************************************************************************/
 
-
-//#include "svsys.h"
-
 #include "comphelper/processfactory.hxx"
 
 #include "osl/module.h"
@@ -426,8 +423,6 @@ const KeyCode*  Application::GetReservedKeyCode( sal_uLong i )
 
 void Application::Execute()
 {
-    DBG_STARTAPPEXECUTE();
-
     ImplSVData* pSVData = ImplGetSVData();
     pSVData->maAppData.mbInAppExecute = sal_True;
 
@@ -435,8 +430,6 @@ void Application::Execute()
         Application::Yield();
 
     pSVData->maAppData.mbInAppExecute = sal_False;
-
-    DBG_ENDAPPEXECUTE();
 }
 
 // -----------------------------------------------------------------------
@@ -561,13 +554,6 @@ sal_Bool Application::IsInModalMode()
 
 // -----------------------------------------------------------------------
 
-sal_uInt16 Application::GetModalModeCount()
-{
-    return ImplGetSVData()->maAppData.mnModalMode;
-}
-
-// -----------------------------------------------------------------------
-
 sal_uInt16 Application::GetDispatchLevel()
 {
     return ImplGetSVData()->maAppData.mnDispatchLevel;
@@ -776,12 +762,12 @@ void Application::NotifyAllWindows( DataChangedEvent& rDCEvt )
     Window*     pFrame = pSVData->maWinData.mpFirstFrame;
     while ( pFrame )
     {
-        pFrame->NotifyAllChilds( rDCEvt );
+        pFrame->NotifyAllChildren( rDCEvt );
 
         Window* pSysWin = pFrame->mpWindowImpl->mpFrameData->mpFirstOverlap;
         while ( pSysWin )
         {
-            pSysWin->NotifyAllChilds( rDCEvt );
+            pSysWin->NotifyAllChildren( rDCEvt );
             pSysWin = pSysWin->mpWindowImpl->mpNextOverlap;
         }
 
@@ -1014,24 +1000,6 @@ void Application::RemoveMouseAndKeyEvents( Window* pWin )
 
 // -----------------------------------------------------------------------
 
-sal_Bool Application::IsProcessedMouseOrKeyEvent( sal_uLong nEventId )
-{
-    const SolarMutexGuard aGuard;
-
-    // find event
-    ::std::list< ImplPostEventPair >::iterator aIter( aPostedEventList.begin() );
-
-    while( aIter != aPostedEventList.end() )
-    {
-        if( (*aIter).second->mnEventId == nEventId )
-            return sal_False;
-
-        else
-            ++aIter;
-    }
-    return sal_True;
-}
-
 sal_uLong Application::PostUserEvent( const Link& rLink, void* pCaller )
 {
     sal_uLong nEventId;
@@ -1292,10 +1260,10 @@ bool Application::IsUnifiedDisplay()
     return pSys ? pSys->IsUnifiedDisplay() : true;
 }
 
-unsigned int Application::GetDisplayDefaultScreen()
+unsigned int Application::GetDisplayBuiltInScreen()
 {
     SalSystem* pSys = ImplGetSalSystem();
-    return pSys ? pSys->GetDisplayDefaultScreen() : 0;
+    return pSys ? pSys->GetDisplayBuiltInScreen() : 0;
 }
 
 Rectangle Application::GetScreenPosSizePixel( unsigned int nScreen )
@@ -1324,7 +1292,7 @@ unsigned long calcDistSquare( const Point& i_rPoint, const Rectangle& i_rRect )
 unsigned int Application::GetBestScreen( const Rectangle& i_rRect )
 {
     if( !IsUnifiedDisplay() )
-        return GetDisplayDefaultScreen();
+        return GetDisplayBuiltInScreen();
 
     const unsigned int nScreens = GetScreenCount();
     unsigned int nBestMatchScreen = 0;
@@ -1390,21 +1358,6 @@ void Application::RemoveAccel( Accelerator* pAccel )
 
 // -----------------------------------------------------------------------
 
-sal_Bool Application::CallAccel( const KeyCode& rKeyCode, sal_uInt16 nRepeat )
-{
-    ImplSVData* pSVData = ImplGetSVData();
-
-    if ( pSVData->maAppData.mpAccelMgr )
-    {
-        if ( pSVData->maAppData.mpAccelMgr->IsAccelKey( rKeyCode, nRepeat ) )
-            return sal_True;
-    }
-
-    return sal_False;
-}
-
-// -----------------------------------------------------------------------
-
 void Application::SetHelp( Help* pHelp )
 {
     ImplGetSVData()->maAppData.mpHelp = pHelp;
@@ -1583,15 +1536,30 @@ sal_uInt16 Application::GetSystemWindowMode()
 
 // -----------------------------------------------------------------------
 
+#ifdef DISABLE_DYNLOADING
+
+extern "C" { UnoWrapperBase* CreateUnoWrapper(); }
+
+#else
+
 extern "C" { static void SAL_CALL thisModule() {} }
 
+#endif
+
 UnoWrapperBase* Application::GetUnoWrapper( sal_Bool bCreateIfNotExist )
 {
     ImplSVData* pSVData = ImplGetSVData();
     static sal_Bool bAlreadyTriedToCreate = sal_False;
     if ( !pSVData->mpUnoWrapper && bCreateIfNotExist && !bAlreadyTriedToCreate )
     {
-        ::rtl::OUString aLibName = ::vcl::unohelper::CreateLibraryName( "tk", sal_True );
+#ifndef DISABLE_DYNLOADING
+        ::rtl::OUString aLibName = ::vcl::unohelper::CreateLibraryName(
+#ifdef LIBO_MERGELIBS
+                                                                       "merged",
+#else
+                                                                       "tk",
+#endif
+                                                                       sal_True );
         oslModule hTkLib = osl_loadModuleRelative(
             &thisModule, aLibName.pData, SAL_LOADMODULE_DEFAULT );
         if ( hTkLib )
@@ -1604,6 +1572,9 @@ UnoWrapperBase* Application::GetUnoWrapper( sal_Bool bCreateIfNotExist )
             }
         }
         DBG_ASSERT( pSVData->mpUnoWrapper, "UnoWrapper could not be created!" );
+#else
+        pSVData->mpUnoWrapper = CreateUnoWrapper();
+#endif
         bAlreadyTriedToCreate = sal_True;
     }
     return pSVData->mpUnoWrapper;
@@ -1703,46 +1674,6 @@ void ImplFreeEventHookData()
 
 // -----------------------------------------------------------------------
 
-sal_uIntPtr Application::AddEventHook( VCLEventHookProc pProc, void* pData )
-{
-    ImplSVData*     pSVData = ImplGetSVData();
-    ImplEventHook*  pEventHookData = new ImplEventHook;
-    pEventHookData->mpUserData = pData;
-    pEventHookData->mpProc     = pProc;
-    pEventHookData->mpNext     = pSVData->maAppData.mpFirstEventHook;
-    pSVData->maAppData.mpFirstEventHook = pEventHookData;
-    return (sal_uIntPtr)pEventHookData;
-}
-
-// -----------------------------------------------------------------------
-
-void Application::RemoveEventHook( sal_uIntPtr nId )
-{
-    ImplSVData*     pSVData = ImplGetSVData();
-    ImplEventHook*  pFindEventHookData = (ImplEventHook*)nId;
-    ImplEventHook*  pPrevEventHookData = NULL;
-    ImplEventHook*  pEventHookData = pSVData->maAppData.mpFirstEventHook;
-    while ( pEventHookData )
-    {
-        if ( pEventHookData == pFindEventHookData )
-        {
-            if ( pPrevEventHookData )
-                pPrevEventHookData->mpNext = pFindEventHookData->mpNext;
-            else
-                pSVData->maAppData.mpFirstEventHook = pFindEventHookData->mpNext;
-            delete pFindEventHookData;
-            break;
-        }
-
-        pPrevEventHookData = pEventHookData;
-        pEventHookData = pEventHookData->mpNext;
-    }
-
-    DBG_ASSERT( pEventHookData, "Application::RemoveEventHook() - EventHook is not added" );
-}
-
-// -----------------------------------------------------------------------
-
 long Application::CallEventHooks( NotifyEvent& rEvt )
 {
     ImplSVData*     pSVData = ImplGetSVData();
@@ -1789,7 +1720,7 @@ bool Application::IsHeadlessModeRequested()
     for (sal_uInt32 i = 0; i < n; ++i) {
         rtl::OUString arg;
         rtl_getAppCommandArg(i, &arg.pData);
-        if (arg.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("--headless"))) {
+        if ( arg == "--headless" ) {
             return true;
         }
     }
@@ -1805,7 +1736,7 @@ void Application::ShowNativeErrorBox(const String& sTitle  ,
             sTitle,
             sMessage,
             SALSYSTEM_SHOWNATIVEMSGBOX_BTNCOMBI_OK,
-            SALSYSTEM_SHOWNATIVEMSGBOX_BTN_OK);
+            SALSYSTEM_SHOWNATIVEMSGBOX_BTN_OK, false);
     if (btn != SALSYSTEM_SHOWNATIVEMSGBOX_BTN_OK) {
         OSL_TRACE("ShowNativeMessageBox returned %d", btn);
     }
@@ -1884,17 +1815,8 @@ TYPEINIT0(ApplicationProperty)
 
 // ------------------------------------------------------------------------
 
-static PropertyHandler* pHandler=NULL;
-
-void Application::Property( ApplicationProperty& rProp )
+void Application::Property( ApplicationProperty& /*rProp*/ )
 {
-    if ( pHandler )
-        pHandler->Property( rProp );
-}
-
-void Application::SetPropertyHandler( PropertyHandler* p )
-{
-    pHandler = p;
 }
 
 void Application::AppEvent( const ApplicationEvent& /*rAppEvent*/ )
