@@ -71,7 +71,6 @@ void MessBox::ImplInitMessBoxData()
     mpFixedImage        = NULL;
     mnSoundType         = 0;
     mbHelpBtn           = sal_False;
-    mbSound             = sal_True;
     mpCheckBox          = NULL;
     mbCheck             = sal_False;
 }
@@ -157,14 +156,6 @@ void MessBox::ImplInitButtons()
 
 // -----------------------------------------------------------------------
 
-MessBox::MessBox( WindowType ) :
-    ButtonDialog( WINDOW_MESSBOX )
-{
-    ImplInitMessBoxData();
-}
-
-// -----------------------------------------------------------------------
-
 MessBox::MessBox( Window* pParent, WinBits nStyle,
                   const XubString& rTitle, const XubString& rMessage ) :
     ButtonDialog( WINDOW_MESSBOX ),
@@ -223,7 +214,7 @@ MessBox::~MessBox()
 
 void MessBox::ImplPosControls()
 {
-    if ( GetHelpId().getLength() )
+    if ( !GetHelpId().isEmpty() )
     {
         if ( !mbHelpBtn )
         {
@@ -424,7 +415,7 @@ void MessBox::StateChanged( StateChangedType nType )
     if ( nType == STATE_CHANGE_INITSHOW )
     {
         ImplPosControls();
-        if ( mbSound && mnSoundType )
+        if ( mnSoundType )
             Sound::Beep( (SoundType)(mnSoundType-1), this );
     }
     ButtonDialog::StateChanged( nType );
@@ -447,15 +438,6 @@ void MessBox::SetCheckBoxState( sal_Bool bCheck )
 
 // -----------------------------------------------------------------------
 
-void MessBox::SetDefaultCheckBoxText()
-{
-    ResMgr* pResMgr = ImplGetResMgr();
-    if( pResMgr )
-        maCheckBoxText = XubString( ResId( SV_STDTEXT_DONTHINTAGAIN, *pResMgr ) );
-}
-
-// -----------------------------------------------------------------------
-
 Size MessBox::GetOptimalSize(WindowSizeType eType) const
 {
     switch( eType ) {
@@ -538,7 +520,7 @@ void WarningBox::SetDefaultCheckBoxText()
 {
     ResMgr* pResMgr = ImplGetResMgr();
     if( pResMgr )
-        maCheckBoxText = XubString( ResId( SV_STDTEXT_DONTWARNAGAIN, *pResMgr ) );
+        maCheckBoxText = ResId(SV_STDTEXT_DONTWARNAGAIN, *pResMgr).toString();
 }
 
 // -----------------------------------------------------------------------
@@ -582,7 +564,16 @@ ErrorBox::ErrorBox( Window* pParent, const ResId& rResId ) :
 
 Image ErrorBox::GetStandardImage()
 {
-    ImplInitMsgBoxImageList();
+    try
+    {
+        ImplInitMsgBoxImageList();
+    }
+    catch (const ::com::sun::star::uno::Exception &)
+    {
+        // During early bootstrap we can have no initialized
+        // ucb and hence no ability to get this image, so nop.
+        return Image();
+    }
     return ImplGetSVData()->maWinData.mpMsgBoxImgList->GetImage( 1 );
 }
 
@@ -620,7 +611,7 @@ void QueryBox::SetDefaultCheckBoxText()
 {
     ResMgr* pResMgr = ImplGetResMgr();
     if( pResMgr )
-        maCheckBoxText = XubString( ResId( SV_STDTEXT_DONTASKAGAIN, *pResMgr ) );
+        maCheckBoxText = ResId(SV_STDTEXT_DONTASKAGAIN, *pResMgr).toString();
 }
 
 // -----------------------------------------------------------------------
