@@ -172,11 +172,11 @@ CUPSWrapper::CUPSWrapper()
         : m_pLib( NULL ),
           m_bPPDThreadRunning( false )
 {
-    OUString aLib( RTL_CONSTASCII_USTRINGPARAM( CUPS_LIB_NAME ) );
+    OUString aLib( CUPS_LIB_NAME  );
     m_pLib = osl_loadModule( aLib.pData, SAL_LOADMODULE_LAZY );
     if( ! m_pLib )
     {
-        aLib = OUString( RTL_CONSTASCII_USTRINGPARAM( SAL_MODULENAME( "cups" ) ) );
+        aLib = OUString( SAL_MODULENAME( "cups"  ) );
         m_pLib = osl_loadModule( aLib.pData, SAL_LOADMODULE_LAZY );
     }
 
@@ -289,7 +289,7 @@ struct GetPPDAttribs
 
     ~GetPPDAttribs()
     {
-        if( m_aResult.getLength() )
+        if( !m_aResult.isEmpty() )
             unlink( m_aResult.getStr() );
     }
 
@@ -600,7 +600,7 @@ void CUPSManager::initialize()
         if( m_aCUPSDestMap.find( it->first ) != m_aCUPSDestMap.end() )
             continue;
 
-        if( it->second.m_aInfo.m_aFeatures.getLength() > 0 )
+        if( !it->second.m_aInfo.m_aFeatures.isEmpty() )
             continue;
         aRemovePrinters.push_back( it->first );
     }
@@ -686,7 +686,7 @@ const PPDParser* CUPSManager::createCUPSParser( const OUString& rPrinter )
                 #if OSL_DEBUG_LEVEL > 1
                 fprintf( stderr, "PPD for %s is %s\n", OUStringToOString( aPrinter, osl_getThreadTextEncoding() ).getStr(), aPPDFile.getStr() );
                 #endif
-                if( aPPDFile.getLength() )
+                if( !aPPDFile.isEmpty() )
                 {
                     rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
                     OUString aFileName( OStringToOUString( aPPDFile, aEncoding ) );
@@ -1100,11 +1100,11 @@ const char* CUPSManager::authenticateUser( const char* /*pIn*/ )
 {
     const char* pRet = NULL;
 
-    OUString aLib(RTL_CONSTASCII_USTRINGPARAM( _XSALSET_LIBNAME ));
+    OUString aLib(_XSALSET_LIBNAME );
     oslModule pLib = osl_loadModule( aLib.pData, SAL_LOADMODULE_LAZY );
     if( pLib )
     {
-        OUString aSym( RTL_CONSTASCII_USTRINGPARAM( "Sal_authenticateQuery" ) );
+        OUString aSym( "Sal_authenticateQuery"  );
         bool (*getpw)( const OString& rServer, OString& rUser, OString& rPw) =
             (bool(*)(const OString&,OString&,OString&))osl_getFunctionSymbol( pLib, aSym.pData );
         if( getpw )
