@@ -412,14 +412,6 @@ X11SalObject::Show( sal_Bool bVisible )
     mbVisible = bVisible;
 }
 
-// -----------------------------------------------------------------------
-
-void X11SalObject::Enable( sal_Bool )
-{
-}
-
-// -----------------------------------------------------------------------
-
 void X11SalObject::GrabFocus()
 {
     if( mbVisible )
@@ -431,18 +423,6 @@ void X11SalObject::GrabFocus()
 
 // -----------------------------------------------------------------------
 
-void X11SalObject::SetBackground()
-{
-}
-
-// -----------------------------------------------------------------------
-
-void X11SalObject::SetBackground( SalColor )
-{
-}
-
-// -----------------------------------------------------------------------
-
 const SystemChildData* X11SalObject::GetSystemData() const
 {
     return &maSystemChildData;
