@@ -34,6 +34,7 @@
 #include <com/sun/star/drawing/PointSequenceSequence.hpp>
 #include <com/sun/star/drawing/XShape.hpp>
 #include <com/sun/star/graphic/XGraphic.hpp>
+#include <com/sun/star/graphic/GraphicProvider.hpp>
 #include <com/sun/star/graphic/XGraphicProvider.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
@@ -49,6 +50,7 @@
 
 #include <cppuhelper/implbase1.hxx>
 #include <rtl/ustrbuf.hxx>
+#include <rtl/oustringostreaminserter.hxx>
 
 #include <dmapper/DomainMapper.hxx>
 #include <doctok/resourceids.hxx>
@@ -256,6 +258,7 @@ public:
 
     ::rtl::OUString sName;
     ::rtl::OUString sAlternativeText;
+    ::rtl::OUString title;
 
     GraphicImport_Impl(GraphicImportType eImportType, DomainMapper&   rDMapper) :
         nXSize(0)
@@ -792,6 +795,10 @@ void GraphicImport::lcl_attribute(Id nName, Value & val)
             //alternative text
             m_pImpl->sAlternativeText = val.getString();
         break;
+        case NS_ooxml::LN_CT_NonVisualDrawingProps_title:
+            //alternative text
+            m_pImpl->title = val.getString();
+        break;
         case NS_ooxml::LN_CT_GraphicalObjectFrameLocking_noChangeAspect://90644;
             //disallow aspect ratio change - ignored
         break;
@@ -889,10 +896,10 @@ void GraphicImport::lcl_attribute(Id nName, Value & val)
                             ( xShape, uno::UNO_QUERY_THROW );
 
                         rtl::OUString sUrl;
-                        xShapeProps->getPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("GraphicURL")) ) >>= sUrl;
+                        xShapeProps->getPropertyValue( rtl::OUString("GraphicURL") ) >>= sUrl;
 
                         ::com::sun::star::beans::PropertyValues aMediaProperties( 1 );
-                        aMediaProperties[0].Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("URL"));
+                        aMediaProperties[0].Name = rtl::OUString("URL");
                         aMediaProperties[0].Value <<= sUrl;
 
                         m_xGraphicObject = createGraphicObject( aMediaProperties );
@@ -905,13 +912,17 @@ void GraphicImport::lcl_attribute(Id nName, Value & val)
                             uno::Reference< beans::XPropertySet > xGraphProps( m_xGraphicObject,
                                     uno::UNO_QUERY );
                             awt::Size aSize = xShape->getSize( );
-                            xGraphProps->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Height")),
+                            xGraphProps->setPropertyValue( rtl::OUString("Height"),
                                    uno::makeAny( aSize.Height ) );
-                            xGraphProps->setPropertyValue( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Width")),
+                            xGraphProps->setPropertyValue( rtl::OUString("Width"),
                                    uno::makeAny( aSize.Width ) );
+
+                            // We need to drop the shape here somehow
+                            uno::Reference< lang::XComponent > xShapeComponent( xShape, uno::UNO_QUERY );
+                            xShapeComponent->dispose( );
                         }
                     }
-                    catch( const beans::UnknownPropertyException )
+                    catch( const beans::UnknownPropertyException & )
                     {
                         // It isn't a graphic image
                     }
@@ -937,7 +948,6 @@ void GraphicImport::lcl_attribute(Id nName, Value & val)
                              uno::makeAny
                              (m_pImpl->rDomainMapper.GetCurrentTextRange()));
 
-                        awt::Point aPoint(m_xShape->getPosition());
                         awt::Size aSize(m_xShape->getSize());
 
                         if (m_pImpl->isXSizeValid())
@@ -1160,6 +1170,7 @@ void GraphicImport::lcl_sprm(Sprm & rSprm)
         case NS_ooxml::LN_CT_WrapPath_lineTo: // 90925;
         case NS_ooxml::LN_graphic_graphic:
         case NS_ooxml::LN_pic_pic:
+        case NS_ooxml::LN_dgm_relIds:
         {
             writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
             if( pProperties.get())
@@ -1275,12 +1286,7 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
     uno::Reference< text::XTextContent > xGraphicObject;
     try
     {
-        uno::Reference< graphic::XGraphicProvider > xGraphicProvider(
-                            m_xComponentContext->getServiceManager()->createInstanceWithContext(
-                                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.graphic.GraphicProvider")),
-                                m_xComponentContext),
-                            uno::UNO_QUERY_THROW );
-
+        uno::Reference< graphic::XGraphicProvider > xGraphicProvider( graphic::GraphicProvider::create(m_xComponentContext) );
         uno::Reference< graphic::XGraphic > xGraphic = xGraphicProvider->queryGraphic( aMediaProperties );
 
         if(xGraphic.is())
@@ -1288,7 +1294,7 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
             PropertyNameSupplier& rPropNameSupplier = PropertyNameSupplier::GetPropertyNameSupplier();
 
             uno::Reference< beans::XPropertySet > xGraphicObjectProperties(
-            m_xTextFactory->createInstance(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.TextGraphicObject"))),
+            m_xTextFactory->createInstance(::rtl::OUString("com.sun.star.text.TextGraphicObject")),
                 uno::UNO_QUERY_THROW);
             xGraphicObjectProperties->setPropertyValue(rPropNameSupplier.GetName(PROP_GRAPHIC), uno::makeAny( xGraphic ));
             xGraphicObjectProperties->setPropertyValue(rPropNameSupplier.GetName(PROP_ANCHOR_TYPE),
@@ -1319,8 +1325,10 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
             }
 
             // setting properties for all types
-            xGraphicObjectProperties->setPropertyValue(rPropNameSupplier.GetName( PROP_TITLE ),
+            xGraphicObjectProperties->setPropertyValue(rPropNameSupplier.GetName( PROP_DESCRIPTION ),
                 uno::makeAny( m_pImpl->sAlternativeText ));
+            xGraphicObjectProperties->setPropertyValue(rPropNameSupplier.GetName( PROP_TITLE ),
+                uno::makeAny( m_pImpl->title ));
             if( m_pImpl->bPositionProtected )
                 xGraphicObjectProperties->setPropertyValue(rPropNameSupplier.GetName( PROP_POSITION_PROTECTED ),
                     uno::makeAny(true));
@@ -1493,8 +1501,7 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
                     }
                     catch (const uno::Exception& e)
                     {
-                        clog << __FILE__ << ":" << __LINE__ << " failed. Message :";
-                        clog << rtl::OUStringToOString (e.Message, RTL_TEXTENCODING_UTF8).getStr() << endl;
+                        SAL_WARN("writerfilter", "failed. Message :" << e.Message);
                     }
                 }
 
@@ -1507,22 +1514,22 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
                         uno::makeAny( awt::Size( m_pImpl->getXSize(), m_pImpl->getYSize() )));
                 try
                 {
-                    if( m_pImpl->sName.getLength() )
+                    if( !m_pImpl->sName.isEmpty() )
                     {
                         uno::Reference< container::XNamed > xNamed( xGraphicObjectProperties, uno::UNO_QUERY_THROW );
                         xNamed->setName( m_pImpl->sName );
                     }
                 }
-                catch( const uno::Exception& )
+                catch( const uno::Exception& e )
                 {
+                    SAL_WARN("writerfilter", "failed. Message :" << e.Message);
                 }
             }
         }
     }
     catch( const uno::Exception& e )
     {
-        clog << __FILE__ << ":" << __LINE__ << " failed. Message :" ;
-        clog << rtl::OUStringToOString( e.Message, RTL_TEXTENCODING_UTF8 ).getStr( )  << endl;
+        SAL_WARN("writerfilter", "failed. Message :" << e.Message);
     }
     return xGraphicObject;
 }
