@@ -1317,6 +1317,9 @@ void OOXMLFastContextHandlerProperties::lcl_endFastElement
     {
         if (isForwardEvents())
         {
+            SAL_WARN_IF(!mpStream, "writerfilter", "no stream to set properties on");
+            if (!mpStream)
+                return;
             mpStream->props(mpPropertySet);
         }
     }
@@ -2451,6 +2454,9 @@ void OOXMLFastContextHandlerMath::process()
     comphelper::EmbeddedObjectContainer container;
     rtl::OUString aName;
     uno::Reference< embed::XEmbeddedObject > ref = container.CreateEmbeddedObject( name.GetByteSequence(), aName );
+    assert(ref.is());
+    if (!ref.is())
+        return;
     uno::Reference< uno::XInterface > component( ref->getComponent(), uno::UNO_QUERY );
 // gcc4.4 (and 4.3 and possibly older) have a problem with dynamic_cast directly to the target class,
 // so help it with an intermediate cast. I'm not sure what exactly the problem is, seems to be unrelated
