@@ -31,6 +31,8 @@
 #include <rtl/ustrbuf.hxx>
 #include <sax/tools/converter.hxx>
 #include <xmloff/xmluconv.hxx>
+#include <xmloff/xmlexp.hxx>
+#include <xmloff/xmlimp.hxx>
 #include <tools/gen.hxx>
 #include <basegfx/vector/b2dvector.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
@@ -39,7 +41,6 @@
 #include <basegfx/polygon/b2dpolypolygon.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
 #include <basegfx/tools/unotools.hxx>
-#include <tools/string.hxx>
 
 using ::rtl::OUString;
 using ::rtl::OUStringBuffer;
@@ -158,7 +159,7 @@ void Imp_PutNumberCharWithSpace(OUString& rStr, sal_Int32 nValue)
     const sal_Int32 aLen(rStr.getLength());
     if(aLen)
         if(Imp_IsOnNumberChar(rStr, aLen - 1, false) && nValue >= 0)
-            rStr += String(sal_Unicode(' '));
+            rStr += rtl::OUString(static_cast<sal_Unicode>(' '));
     Imp_PutNumberChar(rStr, nValue);
 }
 
@@ -418,14 +419,14 @@ const OUString& SdXMLImExTransform2D::GetExportString(const SvXMLUnitConverter&
         {
             case IMP_SDXMLEXP_TRANSOBJ2D_ROTATE :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "rotate (" ));
+                aNewString += OUString( "rotate (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DRotate*)pObj)->mfRotate);
                 aNewString += aClosingBrace;
                 break;
             }
             case IMP_SDXMLEXP_TRANSOBJ2D_SCALE      :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "scale (" ));
+                aNewString += OUString( "scale (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DScale*)pObj)->maScale.getX());
                 aNewString += aEmptySpace;
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DScale*)pObj)->maScale.getY());
@@ -434,7 +435,7 @@ const OUString& SdXMLImExTransform2D::GetExportString(const SvXMLUnitConverter&
             }
             case IMP_SDXMLEXP_TRANSOBJ2D_TRANSLATE  :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "translate (" ));
+                aNewString += OUString( "translate (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DTranslate*)pObj)->maTranslate.getX(), true);
                 aNewString += aEmptySpace;
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DTranslate*)pObj)->maTranslate.getY(), true);
@@ -443,21 +444,21 @@ const OUString& SdXMLImExTransform2D::GetExportString(const SvXMLUnitConverter&
             }
             case IMP_SDXMLEXP_TRANSOBJ2D_SKEWX      :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "skewX (" ));
+                aNewString += OUString( "skewX (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DSkewX*)pObj)->mfSkewX);
                 aNewString += aClosingBrace;
                 break;
             }
             case IMP_SDXMLEXP_TRANSOBJ2D_SKEWY      :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "skewY (" ));
+                aNewString += OUString( "skewY (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DSkewY*)pObj)->mfSkewY);
                 aNewString += aClosingBrace;
                 break;
             }
             case IMP_SDXMLEXP_TRANSOBJ2D_MATRIX :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "matrix (" ));
+                aNewString += OUString( "matrix (" );
 
                 // a
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj2DMatrix*)pObj)->maMatrix.get(0, 0));
@@ -512,17 +513,17 @@ void SdXMLImExTransform2D::SetString(const OUString& rNew, const SvXMLUnitConver
     msString = rNew;
     EmptyList();
 
-    if(msString.getLength())
+    if(!msString.isEmpty())
     {
         const OUString aStr(msString.getStr(), (sal_uInt16)msString.getLength());
         const sal_Int32 nLen(aStr.getLength());
 
-        const OUString aString_rotate(RTL_CONSTASCII_USTRINGPARAM( "rotate" ));
-        const OUString aString_scale(RTL_CONSTASCII_USTRINGPARAM( "scale" ));
-        const OUString aString_translate(RTL_CONSTASCII_USTRINGPARAM( "translate" ));
-        const OUString aString_skewX(RTL_CONSTASCII_USTRINGPARAM( "skewX" ));
-        const OUString aString_skewY(RTL_CONSTASCII_USTRINGPARAM( "skewY" ));
-        const OUString aString_matrix(RTL_CONSTASCII_USTRINGPARAM( "matrix" ));
+        const OUString aString_rotate( "rotate" );
+        const OUString aString_scale( "scale" );
+        const OUString aString_translate( "translate" );
+        const OUString aString_skewX( "skewX" );
+        const OUString aString_skewY( "skewY" );
+        const OUString aString_matrix( "matrix" );
 
         sal_Int32 nPos(0);
 
@@ -857,28 +858,28 @@ const OUString& SdXMLImExTransform3D::GetExportString(const SvXMLUnitConverter&
         {
             case IMP_SDXMLEXP_TRANSOBJ3D_ROTATE_X   :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "rotatex (" ));
+                aNewString += OUString( "rotatex (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DRotateX*)pObj)->mfRotateX);
                 aNewString += aClosingBrace;
                 break;
             }
             case IMP_SDXMLEXP_TRANSOBJ3D_ROTATE_Y   :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "rotatey (" ));
+                aNewString += OUString( "rotatey (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DRotateY*)pObj)->mfRotateY);
                 aNewString += aClosingBrace;
                 break;
             }
             case IMP_SDXMLEXP_TRANSOBJ3D_ROTATE_Z   :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "rotatez (" ));
+                aNewString += OUString( "rotatez (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DRotateZ*)pObj)->mfRotateZ);
                 aNewString += aClosingBrace;
                 break;
             }
             case IMP_SDXMLEXP_TRANSOBJ3D_SCALE      :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "scale (" ));
+                aNewString += OUString( "scale (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DScale*)pObj)->maScale.getX());
                 aNewString += aEmptySpace;
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DScale*)pObj)->maScale.getY());
@@ -889,7 +890,7 @@ const OUString& SdXMLImExTransform3D::GetExportString(const SvXMLUnitConverter&
             }
             case IMP_SDXMLEXP_TRANSOBJ3D_TRANSLATE  :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "translate (" ));
+                aNewString += OUString( "translate (" );
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DTranslate*)pObj)->maTranslate.getX(), true);
                 aNewString += aEmptySpace;
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DTranslate*)pObj)->maTranslate.getY(), true);
@@ -900,7 +901,7 @@ const OUString& SdXMLImExTransform3D::GetExportString(const SvXMLUnitConverter&
             }
             case IMP_SDXMLEXP_TRANSOBJ3D_MATRIX :
             {
-                aNewString += OUString(RTL_CONSTASCII_USTRINGPARAM( "matrix (" ));
+                aNewString += OUString( "matrix (" );
 
                 // a
                 Imp_PutDoubleChar(aNewString, rConv, ((ImpSdXMLExpTransObj3DMatrix*)pObj)->maMatrix.get(0, 0));
@@ -986,17 +987,17 @@ void SdXMLImExTransform3D::SetString(const OUString& rNew, const SvXMLUnitConver
     msString = rNew;
     EmptyList();
 
-    if(msString.getLength())
+    if(!msString.isEmpty())
     {
         const OUString aStr(msString.getStr(), (sal_uInt16)msString.getLength());
         const sal_Int32 nLen(aStr.getLength());
 
-        const OUString aString_rotatex(RTL_CONSTASCII_USTRINGPARAM( "rotatex" ));
-        const OUString aString_rotatey(RTL_CONSTASCII_USTRINGPARAM( "rotatey" ));
-        const OUString aString_rotatez(RTL_CONSTASCII_USTRINGPARAM( "rotatez" ));
-        const OUString aString_scale(RTL_CONSTASCII_USTRINGPARAM( "scale" ));
-        const OUString aString_translate(RTL_CONSTASCII_USTRINGPARAM( "translate" ));
-        const OUString aString_matrix(RTL_CONSTASCII_USTRINGPARAM( "matrix" ));
+        const OUString aString_rotatex( "rotatex" );
+        const OUString aString_rotatey( "rotatey" );
+        const OUString aString_rotatez( "rotatez" );
+        const OUString aString_scale( "scale" );
+        const OUString aString_translate( "translate" );
+        const OUString aString_matrix( "matrix" );
 
         sal_Int32 nPos(0);
 
@@ -1250,7 +1251,7 @@ SdXMLImExViewBox::SdXMLImExViewBox(const OUString& rNew, const SvXMLUnitConverte
     mnW( 1000L ),
     mnH( 1000L )
 {
-    if(msString.getLength())
+    if(!msString.isEmpty())
     {
         const OUString aStr(msString.getStr(), (sal_uInt16)msString.getLength());
         const sal_Int32 nLen(aStr.getLength());
@@ -1356,12 +1357,12 @@ SdXMLImExPointsElement::SdXMLImExPointsElement(drawing::PointSequence* pPoints,
 
             // X and comma
             Imp_PutNumberChar(aNewString, nX);
-            aNewString += String(sal_Unicode(','));
+            aNewString += rtl::OUString(static_cast<sal_Unicode>(','));
 
             // Y and space (not for last)
             Imp_PutNumberChar(aNewString, nY);
             if(a + 1 != nCnt)
-                aNewString += String(sal_Unicode(' '));
+                aNewString += rtl::OUString(static_cast<sal_Unicode>(' '));
 
             // next point
             pArray++;
@@ -1470,10 +1471,17 @@ SdXMLImExPointsElement::SdXMLImExPointsElement(const OUString& rNew,
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-SdXMLImExSvgDElement::SdXMLImExSvgDElement(const SdXMLImExViewBox& rViewBox)
+SdXMLImExSvgDElement::SdXMLImExSvgDElement(const SdXMLImExViewBox& rViewBox,
+                                           const SvXMLExport&      rExport)
 :   mrViewBox( rViewBox ),
     mbIsClosed( false ),
     mbIsCurve( false ),
+    // fdo#47406 - handle writing svg:d path slightly different for
+    // old odf versions and ODF1.2 compat mode - since ~all the legacy
+    // ODF ecosystem interprets relative svg:d paths incorrectly,
+    // write out absolute paths in those cases.
+    mbRelative( rExport.getDefaultVersion() >= SvtSaveOptions::ODFVER_012 &&
+                rExport.getDefaultVersion() != SvtSaveOptions::ODFVER_012_EXT_COMPAT ),
     mnLastX( 0L ),
     mnLastY( 0L ),
     maPoly()
@@ -1536,7 +1544,7 @@ void SdXMLImExSvgDElement::AddPolygon(
     drawing::FlagSequence* pFlags,
     const awt::Point& rObjectPos,
     const awt::Size& rObjectSize,
-    bool bClosed, bool bRelative)
+    bool bClosed)
 {
     // Leaving the export stuff for the while, should eventually also
     // consolidated with basegfx svg support
@@ -1607,6 +1615,7 @@ void SdXMLImExSvgDElement::AddPolygon(
 
         // bezier poly, handle curves
         bool  bDidWriteStart(false);
+        sal_Int32 nStartX(0), nStartY(0);
 
         for(sal_Int32 a(0L); a < nCnt; a++)
         {
@@ -1722,7 +1731,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                                             if(bPrevPointIsSymmetric)
                                             {
                                                 // write a shorthand/smooth quadratic curveto entry (T)
-                                                if(bRelative)
+                                                if(mbRelative)
                                                 {
                                                     if(aLastCommand != sal_Unicode('t'))
                                                         aNewString += OUString(sal_Unicode('t'));
@@ -1752,7 +1761,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                                                     mrViewBox, bScale, bTranslate);
 
                                                 // write a quadratic curveto entry (Q)
-                                                if(bRelative)
+                                                if(mbRelative)
                                                 {
                                                     if(aLastCommand != sal_Unicode('q'))
                                                         aNewString += OUString(sal_Unicode('q'));
@@ -1814,10 +1823,10 @@ void SdXMLImExSvgDElement::AddPolygon(
                                             if(bPrevPointIsSmooth)
                                             {
                                                 // write a shorthand/smooth quadratic curveto entry (T)
-                                                if(bRelative)
+                                                if(mbRelative)
                                                 {
                                                     if(aLastCommand != sal_Unicode('t'))
-                                                        aNewString += String(sal_Unicode('t'));
+                                                        aNewString += rtl::OUString(static_cast<sal_Unicode>('t'));
 
                                                     Imp_PutNumberCharWithSpace(aNewString, nX - mnLastX);
                                                     Imp_PutNumberCharWithSpace(aNewString, nY - mnLastY);
@@ -1827,7 +1836,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                                                 else
                                                 {
                                                     if(aLastCommand != sal_Unicode('T'))
-                                                        aNewString += String(sal_Unicode('T'));
+                                                        aNewString += rtl::OUString(static_cast<sal_Unicode>('T'));
 
                                                     Imp_PutNumberCharWithSpace(aNewString, nX);
                                                     Imp_PutNumberCharWithSpace(aNewString, nY);
@@ -1844,10 +1853,10 @@ void SdXMLImExSvgDElement::AddPolygon(
                                                     mrViewBox, bScale, bTranslate);
 
                                                 // write a quadratic curveto entry (Q)
-                                                if(bRelative)
+                                                if(mbRelative)
                                                 {
                                                     if(aLastCommand != sal_Unicode('q'))
-                                                        aNewString += String(sal_Unicode('q'));
+                                                        aNewString += rtl::OUString(static_cast<sal_Unicode>('q'));
 
                                                     Imp_PutNumberCharWithSpace(aNewString, nX1 - mnLastX);
                                                     Imp_PutNumberCharWithSpace(aNewString, nY1 - mnLastY);
@@ -1859,7 +1868,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                                                 else
                                                 {
                                                     if(aLastCommand != sal_Unicode('Q'))
-                                                        aNewString += String(sal_Unicode('Q'));
+                                                        aNewString += rtl::OUString(static_cast<sal_Unicode>('Q'));
 
                                                     Imp_PutNumberCharWithSpace(aNewString, nX1);
                                                     Imp_PutNumberCharWithSpace(aNewString, nY1);
@@ -1903,10 +1912,10 @@ void SdXMLImExSvgDElement::AddPolygon(
                                         if(bPrevPointIsSymmetric)
                                         {
                                             // write a shorthand/smooth curveto entry (S)
-                                            if(bRelative)
+                                            if(mbRelative)
                                             {
                                                 if(aLastCommand != sal_Unicode('s'))
-                                                    aNewString += String(sal_Unicode('s'));
+                                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('s'));
 
                                                 Imp_PutNumberCharWithSpace(aNewString, nX2 - mnLastX);
                                                 Imp_PutNumberCharWithSpace(aNewString, nY2 - mnLastY);
@@ -1918,7 +1927,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                                             else
                                             {
                                                 if(aLastCommand != sal_Unicode('S'))
-                                                    aNewString += String(sal_Unicode('S'));
+                                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('S'));
 
                                                 Imp_PutNumberCharWithSpace(aNewString, nX2);
                                                 Imp_PutNumberCharWithSpace(aNewString, nY2);
@@ -1937,10 +1946,10 @@ void SdXMLImExSvgDElement::AddPolygon(
                                                 mrViewBox, bScale, bTranslate);
 
                                             // write a curveto entry (C)
-                                            if(bRelative)
+                                            if(mbRelative)
                                             {
                                                 if(aLastCommand != sal_Unicode('c'))
-                                                    aNewString += String(sal_Unicode('c'));
+                                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('c'));
 
                                                 Imp_PutNumberCharWithSpace(aNewString, nX1 - mnLastX);
                                                 Imp_PutNumberCharWithSpace(aNewString, nY1 - mnLastY);
@@ -1954,7 +1963,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                                             else
                                             {
                                                 if(aLastCommand != sal_Unicode('C'))
-                                                    aNewString += String(sal_Unicode('C'));
+                                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('C'));
 
                                                 Imp_PutNumberCharWithSpace(aNewString, nX1);
                                                 Imp_PutNumberCharWithSpace(aNewString, nY1);
@@ -1993,10 +2002,10 @@ void SdXMLImExSvgDElement::AddPolygon(
                         // write as normal point
                         if(mnLastX == nX)
                         {
-                            if(bRelative)
+                            if(mbRelative)
                             {
                                 if(aLastCommand != sal_Unicode('v'))
-                                    aNewString += String(sal_Unicode('v'));
+                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('v'));
 
                                 Imp_PutNumberCharWithSpace(aNewString, nY - mnLastY);
 
@@ -2005,7 +2014,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                             else
                             {
                                 if(aLastCommand != sal_Unicode('V'))
-                                    aNewString += String(sal_Unicode('V'));
+                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('V'));
 
                                 Imp_PutNumberCharWithSpace(aNewString, nY);
 
@@ -2014,10 +2023,10 @@ void SdXMLImExSvgDElement::AddPolygon(
                         }
                         else if(mnLastY == nY)
                         {
-                            if(bRelative)
+                            if(mbRelative)
                             {
                                 if(aLastCommand != sal_Unicode('h'))
-                                    aNewString += String(sal_Unicode('h'));
+                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('h'));
 
                                 Imp_PutNumberCharWithSpace(aNewString, nX - mnLastX);
 
@@ -2026,7 +2035,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                             else
                             {
                                 if(aLastCommand != sal_Unicode('H'))
-                                    aNewString += String(sal_Unicode('H'));
+                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('H'));
 
                                 Imp_PutNumberCharWithSpace(aNewString, nX);
 
@@ -2035,10 +2044,10 @@ void SdXMLImExSvgDElement::AddPolygon(
                         }
                         else
                         {
-                            if(bRelative)
+                            if(mbRelative)
                             {
                                 if(aLastCommand != sal_Unicode('l'))
-                                    aNewString += String(sal_Unicode('l'));
+                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('l'));
 
                                 Imp_PutNumberCharWithSpace(aNewString, nX - mnLastX);
                                 Imp_PutNumberCharWithSpace(aNewString, nY - mnLastY);
@@ -2048,7 +2057,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                             else
                             {
                                 if(aLastCommand != sal_Unicode('L'))
-                                    aNewString += String(sal_Unicode('L'));
+                                    aNewString += rtl::OUString(static_cast<sal_Unicode>('L'));
 
                                 Imp_PutNumberCharWithSpace(aNewString, nX);
                                 Imp_PutNumberCharWithSpace(aNewString, nY);
@@ -2060,9 +2069,9 @@ void SdXMLImExSvgDElement::AddPolygon(
                     else
                     {
                         // write as start point
-                        if(bRelative)
+                        if(mbRelative)
                         {
-                            aNewString += String(sal_Unicode('m'));
+                            aNewString += rtl::OUString(static_cast<sal_Unicode>('m'));
 
                             Imp_PutNumberCharWithSpace(aNewString, nX - mnLastX);
                             Imp_PutNumberCharWithSpace(aNewString, nY - mnLastY);
@@ -2071,7 +2080,7 @@ void SdXMLImExSvgDElement::AddPolygon(
                         }
                         else
                         {
-                            aNewString += String(sal_Unicode('M'));
+                            aNewString += rtl::OUString(static_cast<sal_Unicode>('M'));
 
                             Imp_PutNumberCharWithSpace(aNewString, nX);
                             Imp_PutNumberCharWithSpace(aNewString, nY);
@@ -2081,6 +2090,8 @@ void SdXMLImExSvgDElement::AddPolygon(
 
                         // remember start written
                         bDidWriteStart = true;
+                        nStartX = nX;
+                        nStartY = nY;
                     }
 
                     // remember new last position
@@ -2097,10 +2108,17 @@ void SdXMLImExSvgDElement::AddPolygon(
         // close path if closed poly
         if(bClosed)
         {
-            if(bRelative)
-                aNewString += String(sal_Unicode('z'));
+            if(mbRelative)
+                aNewString += rtl::OUString(static_cast<sal_Unicode>('z'));
             else
-                aNewString += String(sal_Unicode('Z'));
+                aNewString += rtl::OUString(static_cast<sal_Unicode>('Z'));
+
+            // update current point - we're back at the start
+            if( bDidWriteStart )
+            {
+                mnLastX = nStartX;
+                mnLastY = nStartY;
+            }
         }
 
         // append new string
@@ -2112,18 +2130,30 @@ SdXMLImExSvgDElement::SdXMLImExSvgDElement(const OUString& rNew,
     const SdXMLImExViewBox& rViewBox,
     const awt::Point& rObjectPos,
     const awt::Size& rObjectSize,
-    const SvXMLUnitConverter& /*rConv*/)
+    const SvXMLImport& rImport)
 :   msString( rNew ),
     mrViewBox( rViewBox ),
     mbIsClosed( false ),
     mbIsCurve( false ),
+    mbRelative( true ),
     mnLastX( 0L ),
     mnLastY( 0L ),
     maPoly()
 {
+    bool bWrongPositionAfterZ( false );
+	sal_Int32 nUPD( 0 );
+	sal_Int32 nBuildId( 0 );
+	if ( rImport.getBuildIds( nUPD, nBuildId ) &&
+       ( ( nUPD == 641 ) || ( nUPD == 645 ) || ( nUPD == 680 ) || ( nUPD == 300 ) ||
+         ( nUPD == 310 ) || ( nUPD == 320 ) || ( nUPD == 330 ) || ( nUPD == 340 ) ||
+         ( nUPD == 350 && nBuildId < 202 ) ) )
+    {
+        bWrongPositionAfterZ = true;
+    }
+
     // convert string to polygon
     basegfx::B2DPolyPolygon aPoly;
-    basegfx::tools::importFromSvgD(aPoly,msString);
+    basegfx::tools::importFromSvgD(aPoly,msString,bWrongPositionAfterZ);
 
     mbIsCurve = aPoly.areControlPointsUsed();
     mbIsClosed = aPoly.isClosed();
